-- ==========================================================================
-- Licensed Materials - Property of IBM
-- "Restricted Materials of IBM"
--
-- 5724-C01
-- 5698-WAZ
--
-- (C) COPYRIGHT IBM CORP. 2003,2004 ALL RIGHTS RESERVED.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- ==========================================================================
--
-- File Information: wsappsvr/src/tedw_apps_etl/fixpack_v1103/izy/cdw/dml/izy_cdw_data.sql, waspac, waspac_512, 200403261523
-- 
-- Revision: 1.19
-- 
-- Date: 3/24/04 14:27:33
-- 
-- Description: This is the IBM Tivoli Monitoring for WebSphere file for inserting 
--              new static data into the TEDW TWH_CDW database tables. This file
--              is the delta from version 5.1.0 to install with the TEDW application
--              patcher.   
-- 
--  ==========================================================================
--  Change Activity:
--  $D0 107811 01/09/03  lmd  new file: Add support for WAS z/OS 
--  $D1 115192 06/02/03  lmd  fixpack_V1102 - add support for WAS 5.0
--  $D2 116059 06/11/03  lmd  Add resource.Name to attrTyp_transl for ETL1
--  $D3 119841 09/02/03 lmd   Add 'current timezone' to all dates
--  $D4 IY51267 12/10/03 lmd  fixpack_3 v1103 -WebSphere 5.0 modeling changes 
--  $D5 128430  03/05/04 lmd  Some total metrics should be min/max/avg     
--  ==========================================================================
-- 
-- All data is initially inserted into a temporary table that has
-- the same columns as the target table in the CDW.
-- That table is then inserted into the CDW table with a "where not exists"
-- clause. This insures that duplicate data is not inserted and an
-- error is not generated for trying to insert duplicate data.
--
--#iftag fixpack_1                                                     

-- Update measurement source name to reflect new version of PAC (V5.1.1)
update TWG.MSrc ms
   SET ms.MSrc_Nm = 'IBM Tivoli Monitoring for Web Infrastructure, Version 5.1.1: WebSphere Application Server'
     where
      (ms.MSrc_Cd='IZY')
  ;                                

--
-- create a temporary table for ITM for WebSphere measurement types
--

declare global temporary table IZY_MsmtTyp (
       MUnit_Cd          CHAR(6) NOT NULL,
       MSrc_Cd		    CHAR(6) NOT NULL,
       MsmtTyp_Nm           VARCHAR(120) NOT NULL,
       MsmtTyp_Ds           VARCHAR(254)
) 
with replace on commit preserve rows not logged
;

insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'MSec', 'IZY', 'Average_EJB_CPU_Time', 'Average CPU time per EJB request. (This measurement is collected in the z/OS environment only.)');
insert into session.IZY_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'MSec', 'IZY', 'Average_Servlet_CPU_Time', 'Average CPU time per servlet request. (This measurement is collected in the z/OS environment only.)');


-- insert the ITM for WebSphere measurement types into the generic schema 
-- if not exist already

insert into TWG.MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) 
select 
 m.MUnit_Cd,
 m.MSrc_Cd,
 m.MsmtTyp_Nm,
 m.MsmtTyp_Ds
from 
 session.IZY_MsmtTyp m
where not exists
( select 1 from
  TWG.MsmtTyp t
  where
  t.MsmtTyp_Nm=m.MsmtTyp_Nm
)
  ;

-- Update the ITM for WebSphere measurement types
-- add z/OS environment info to measurement description
update  TWG.MsmtTyp mt
   SET mt.MsmtTyp_Ds =  'Average percent of the connection pool that is in use. (This measurement is not collected in the z/OS environment.)'
      WHERE mt.MsmtTyp_Nm = 'Average_connection_pool_percent_used';
-- Correct Munit_Cd from QTY to Qpm to more accurately reflect data value
update  TWG.MsmtTyp mt
   SET mt.MUnit_Cd = 'Qpm'
   WHERE mt.MsmtTyp_Nm = 'EJB_request_rate';
-- Correct description to remove 'in the cycle'
update  TWG.MsmtTyp mt
   SET  mt.MsmtTyp_Ds = 'Average number of concurrently active beans (entity and stateful)'
   WHERE mt.MsmtTyp_Nm =  'Average_concurrent_EJB_requests';
-- Correct description to remove 'per cycle'
update  TWG.MsmtTyp mt
   SET  mt.MsmtTyp_Ds = 'Servlet errors'
      WHERE mt.MsmtTyp_Nm = 'Servlet_error_rate';
-- Correct Munit_Cd from SEC to Msec 
update  TWG.MsmtTyp mt
   SET mt.MUnit_Cd = 'MSec'
      WHERE mt.MsmtTyp_Nm =  'Transaction_response_time';
-- Change Munit_Cd from QTY to Qpm since it is requests per minute
update  TWG.MsmtTyp mt
   SET mt.MUnit_Cd = 'Qpm'
      WHERE mt.MsmtTyp_Nm = 'Transaction_request_rate';
-- add z/OS environment info to measurement description
update  TWG.MsmtTyp mt
   SET mt.MsmtTyp_Ds = 'Transaction time outs to total transactions. (This measurement is not collected in the z/OS environment.)'
      WHERE mt.MsmtTyp_Nm = 'Transaction_exceptions';


-- create a temporary table for ITM for WebSphere measurement rules
declare global temporary table IZY_MsmtRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       MsmtTyp_ID           INTEGER NOT NULL
) 
with replace on commit preserve rows not logged
;

insert into session.IZY_MsmtRul
select 'IZY_EJB', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_EJB_CPU_Time'
);

insert into session.IZY_MsmtRul
select 'IZY_WEB_APPL', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_Servlet_CPU_Time'
);                     

insert into session.IZY_MsmtRul
select 'IZY_SERVLET', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_Servlet_CPU_Time'
);

insert into session.IZY_MsmtRul
select 'IZY_APPL_SERVER', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_EJB_CPU_Time', 
   'Average_Servlet_CPU_Time'
);   
               

-- insert the measurement rule into the generic schema 
-- if not exist already

insert into TWG.MsmtRul (CompTyp_Cd, MsmtTyp_ID) 
select 
 m.CompTyp_Cd,
 m.MsmtTyp_ID
from 
 session.IZY_MsmtRul m
where not exists
( select 1 from
  TWG.MsmtRul t
  where
  t.CompTyp_Cd=m.CompTyp_Cd and
  t.MsmtTyp_ID=m.MsmtTyp_ID)
  ;


-- Update description for our measurement group (fixed capitalization)
Update TWG.MGrp mg
   SET mg.MGrp_Nm =  'IBM WebSphere Application Server States'
      WHERE mg.MGrp_Cd = 'IZY_ST';

---------------------------------------------------------
-- create a temporary table for measurement group member 
---------------------------------------------------------
declare global temporary table IZY_MGrpMbr (
       MGrp_Cd              CHAR(6) NOT NULL,
       MGrpTyp_Cd           CHAR(6) NOT NULL,
       MsmtTyp_ID           INTEGER NOT NULL
       
)
with replace on commit preserve rows not logged
;

-- insert the following two new zOS only measurements, and correct EJB_request rate
-- 'Average_EJB_CPU_Time', 'Average_Servlet_CPU_Time'
insert into session.IZY_MGrpMbr
select 'MAX_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='IZY' and 
MsmtTyp_Nm in (              
-- 5.1.1 EJB_request_rate changed to min/max/avg from total
   'EJB_request_rate',                         
   'Average_EJB_CPU_Time', 
   'Average_Servlet_CPU_Time'
);

insert into session.IZY_MGrpMbr
select 'MIN_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='IZY' and
MsmtTyp_Nm in (
-- 5.1.1 EJB_request_rate changed to min/max/avg from total
   'EJB_request_rate',                               
   'Average_EJB_CPU_Time', 
   'Average_Servlet_CPU_Time'
);

insert into session.IZY_MGrpMbr
select 'AVG_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='IZY' and 
MsmtTyp_Nm in (
-- 5.1.1 EJB_request_rate changed to min/max/avg from total
   'EJB_request_rate',                               
   'Average_EJB_CPU_Time', 
   'Average_Servlet_CPU_Time'
);

insert into TWG.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
select 
 m.MGrp_Cd,
 m.MGrpTyp_Cd,
 m.MsmtTyp_ID
from 
 session.IZY_MGrpMbr m
where not exists
( select 1 from
  TWG.MGrpMbr t
  where
  t.MGrpTyp_Cd=m.MGrpTyp_Cd and
  t.MGrp_Cd=m.MGrp_Cd and
  t.MsmtTyp_ID=m.MsmtTyp_ID)
  ;  

-- 'EJB_request_rate' is a min, max and average value; remove from total
DELETE  from TWG.MGrpMbr mg
 where 
   mg.MGrp_Cd = 'TOT_E' and
   mg.MsmtTyp_ID = 
      (SELECT mt.MsmtTyp_ID FROM TWG.MsmtTyp mt  WHERE mt.MsmtTyp_Nm = 'EJB_request_rate')
;

--------------------------------------------------------------------------------------------------
-- Expire existing attribute rules for AdminServer; converting to use common standard TWH attributes
--------------------------------------------------------------------------------------------------
-- @D3C - added 'current timezone'
UPDATE TWG.AttrRul t
  SET t.AttrRul_End_DtTm =  current timestamp - CURRENT timezone 
WHERE (t.CompTyp_Cd = 'IZY_ADMIN_SERVER') AND
      (t.AttrTyp_Cd IN ('IZY_OS_TYPE', 'IZY_POLICY_REGION', 'IZY_WAS_VERSION'))
; 

--------------------------------------
-- temporary table for AttrRul 
---------------------------------------
declare global temporary table IZY_AttrRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrRul_Strt_DtTm    TIMESTAMP NOT NULL,
       AttrRul_End_DtTm     TIMESTAMP NOT NULL,
       AttrRul_Dom_Ind      CHAR NOT NULL
)
with replace on commit preserve rows not logged
;   

-- @D3C - added 'current timezone'
insert into session.IZY_AttrRul values ('IZY_ADMIN_SERVER','VERSION', current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.IZY_AttrRul values ('IZY_ADMIN_SERVER','OS_NAME', current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into session.IZY_AttrRul values ('IZY_ADMIN_SERVER','TME_POLICY_REGION', current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');

insert into TWG.AttrRul (CompTyp_Cd, AttrTyp_Cd, AttrRul_Strt_DtTm, AttrRul_End_DtTm, AttrRul_Dom_Ind)
select 
 t.CompTyp_Cd ,
 t.AttrTyp_Cd ,
 t.AttrRul_Strt_DtTm ,
 t.AttrRul_End_DtTm ,
 t.AttrRul_Dom_Ind 
from 
 session.IZY_AttrRul t
where not exists
( select 1 from
  TWG.AttrRul m
  where
  t.CompTyp_Cd = m.CompTyp_Cd and
  t.AttrTyp_Cd = m.AttrTyp_Cd
  )
; 
   

----------------------------------------------
-- Translation tables
----------------------------------------------
--------------------------------------------------
-- Need to link the ITM for WAS Resource to the compTyp_cd 
----------------------------------------------

declare global temporary table IZY_Resource_Transl (
Resource		varchar(128) not null,
CompTyp_Cd		varchar(17) not null
)
with replace on commit preserve rows not logged
;

insert into session.IZY_Resource_Transl values ('WebSphereASRemoteAdminServer','IZY_ADMIN_SVR_RMT');
insert into session.IZY_Resource_Transl values ('WebSphereASRemoteApplicationServer','IZY_APPL_SVR_RMT');
insert into session.IZY_Resource_Transl values ('WebSphereASRemoteDataSource','IZY_DATA_SRC_RMT');
insert into session.IZY_Resource_Transl values ('WebSphereASRemoteConnectionPool','IZY_CONN_PL_RMT');
insert into session.IZY_Resource_Transl values ('WebSphereASRemoteEJB','IZY_EJB_RMT');
insert into session.IZY_Resource_Transl values ('WebSphereASRemoteJVMRuntime','IZY_JVM_RMT');
insert into session.IZY_Resource_Transl values ('WebSphereASRemoteServletSession','IZY_SVLT_SESS_RMT');
insert into session.IZY_Resource_Transl values ('WebSphereASRemoteTransaction','IZY_TRANS_MGR_RMT');
insert into session.IZY_Resource_Transl values ('WebSphereASRemoteThreadPool','IZY_THREAD_PL_RMT');
insert into session.IZY_Resource_Transl values ('WebSphereASRemoteWebApplication','IZY_WEB_APPL_RMT');
insert into session.IZY_Resource_Transl values ('WebSphereASRemoteServlet','IZY_SERVLET_RMT');

insert into AMX.Resource_Transl(Resource, CompTyp_Cd) 
select 
t.Resource  ,
t.CompTyp_Cd  
from 
 session.IZY_Resource_Transl t
where not exists
( select 1 from
  AMX.Resource_Transl m
  where
  t.CompTyp_Cd = m.CompTyp_Cd 
  )
; 


--------------------------------------------------
-- Need a translation table if the property 
-- can have more than 17 characters 
-- Need to know which properties are key properties
-- Need to know which properties will be used for the Comp_Nm
--------------------------------------------------

declare global temporary table IZY_CompTyp_Transl (
MSrc_Cd			char(3) not null,
ITM_Key_Property	varchar(1096) not null,
CompTyp_Cd		varchar(17) not null,
Comp_Format_Nm	varchar(254) not null
)
with replace on commit preserve rows not logged
;

insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASRemoteAdminServer.Name','IZY_ADMIN_SVR_RMT','WebSphereASRemoteAdminServer.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASRemoteApplicationServer.Name','IZY_APPL_SVR_RMT','WebSphereASRemoteApplicationServer.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASRemoteDataSource.Name','IZY_DATA_SRC_RMT','WebSphereASRemoteDataSource.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASRemoteConnectionPool.Name','IZY_CONN_PL_RMT','WebSphereASRemoteConnectionPool.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASRemoteEJB.Name','IZY_EJB_RMT','WebSphereASRemoteEJB.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASRemoteJVMRuntime.Name','IZY_JVM_RMT','WebSphereASRemoteJVMRuntime.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASRemoteServletSession.Name','IZY_SVLT_SESS_RMT','WebSphereASRemoteServletSession.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASRemoteThreadPool.Name','IZY_THREAD_PL_RMT','WebSphereASRemoteThreadPool.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASRemoteTransaction.Name','IZY_TRANS_MGR_RMT','WebSphereASRemoteTransaction.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASRemoteWebApplication.Name','IZY_WEB_APPL_RMT','WebSphereASRemoteWebApplication.Name');
insert into session.IZY_CompTyp_Transl values ('IZY','WebSphereASRemoteServlet.Name','IZY_SERVLET_RMT','WebSphereASRemoteServlet.Name');



insert into AMX.Comptyp_Transl (MSrc_Cd, ITM_Key_Property, CompTyp_Cd,Comp_Format_Nm)
select 
t.MSrc_Cd  ,
t.ITM_key_property ,
t.CompTyp_Cd  ,
t.Comp_Format_Nm  
from 
 session.IZY_Comptyp_Transl t
where not exists
( select 1 from
  AMX.Comptyp_Transl m
  where
  t.MSrc_Cd = m.MSrc_Cd and
  t.CompTyp_Cd  = m.CompTyp_Cd 
  )
; 


--------------------------------------------------
-- Need a translation table if the property 
-- can have more than 17 characters
----------------------------------------------
declare global temporary table IZY_AttrTyp_Transl (
MSrc_Cd			char(3) not null,
ITM_Attr_Property	varchar(254) not null,
AttrTyp_Cd		varchar(17) not null
)
with replace on commit preserve rows not logged
;

insert into session.IZY_AttrTyp_Transl values ('IZY','WebSphereASRemoteAdminServer.IZY_HOST','IZY_HOST');
insert into session.IZY_AttrTyp_Transl values ('IZY','WebSphereASRemoteAdminServer.LAST_IP_ADDRESS','LAST_IP_ADDRESS');
insert into session.IZY_AttrTyp_Transl values ('IZY','WebSphereASRemoteAdminServer.WasVersion','VERSION');
insert into session.IZY_AttrTyp_Transl values ('IZY','WebSphereASRemoteAdminServer.OSType','OS_NAME');
insert into session.IZY_AttrTyp_Transl values ('IZY','WebSphereASRemoteAdminServer.PolicyRegion','TME_POLICY_REGION');


insert into AMX.Attrtyp_Transl (MSrc_Cd, ITM_Attr_Property, AttrTyp_Cd)
select 
t.MSrc_Cd  ,
t.ITM_Attr_Property  ,
t.AttrTyp_Cd 
from 
 session.IZY_Attrtyp_Transl t
where not exists
( select 1 from
  AMX.Attrtyp_Transl m
  where
  t.MSrc_Cd = m.MSrc_Cd and
  t.AttrTyp_Cd  = m.AttrTyp_Cd 
  )
; 

-- Update existing rules for AdminServer to reflect use of common standard TWH attributes
UPDATE 
  AMX.Attrtyp_Transl t
-- was IZY_WAS_VERSION
SET t.AttrTyp_Cd = 'VERSION'
  where
   t.MSrc_Cd = 'IZY' and
   t.ITM_Attr_Property = 'WebSphereASAdminServer.WasVersion';

UPDATE 
  AMX.Attrtyp_Transl t
-- was IZY_OS_YPE
SET t.AttrTyp_Cd = 'OS_NAME'
  where
   t.MSrc_Cd = 'IZY' and
   t.ITM_Attr_Property = 'WebSphereASAdminServer.OSType';

UPDATE 
  AMX.Attrtyp_Transl t
-- was IZY_POLICY_REGION
SET t.AttrTyp_Cd = 'TME_POLICY_REGION'
  where
   t.MSrc_Cd = 'IZY' and
   t.ITM_Attr_Property = 'WebSphereASAdminServer.PolicyRegion';

------------------------------------------------------------------------------------------------
-- Insert data to define relation rules for remote (390) WebSphere Application Server components
------------------------------------------------------------------------------------------------ 

-- create temporary table for relation rule translation values
DECLARE global temporary TABLE AMX_RelnRul_Transl (
   CompTyp_Source_Cd 	   VARCHAR(17) NOT NULL,
   CompTyp_Target_Cd 	   VARCHAR(17) NOT NULL,
   RelnTyp_Cd              CHAR(6) NOT NULL,
   RelnRul_Strt_DtTm    	Timestamp NOT NULL,
   RelnRul_End_DtTm        Timestamp NOT NULL
	)
WITH REPLACE ON COMMIT preserve ROWS NOT logged
;
  
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_ADMIN_SERVER', 'IZY_ADMIN_SVR_RMT', 'PROXY', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_APPL_SERVER', 'IZY_APPL_SVR_RMT', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_DATA_SOURCE', 'IZY_DATA_SRC_RMT', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_CONNECT_POOL', 'IZY_CONN_PL_RMT', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_EJB', 'IZY_EJB_RMT', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_JVM', 'IZY_JVM_RMT', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_SERVLET_SESS', 'IZY_SVLT_SESS_RMT', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_THREAD_POOL', 'IZY_THREAD_PL_RMT', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_TRANSACT_MGR', 'IZY_TRANS_MGR_RMT', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_WEB_APPL', 'IZY_WEB_APPL_RMT', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_SERVLET', 'IZY_SERVLET_RMT', 'SAME', current timestamp - current timezone, '9999-01-01-12.00.00.000000');

INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_ADMIN_SVR_RMT', 'IZY_APPL_SVR_RMT', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_APPL_SVR_RMT', 'IZY_DATA_SRC_RMT', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_DATA_SRC_RMT', 'IZY_CONN_PL_RMT', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_APPL_SVR_RMT', 'IZY_EJB_RMT', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_APPL_SVR_RMT', 'IZY_JVM_RMT', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_APPL_SVR_RMT', 'IZY_SVLT_SESS_RMT', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_APPL_SVR_RMT', 'IZY_THREAD_PL_RMT', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_APPL_SVR_RMT', 'IZY_TRANS_MGR_RMT', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_APPL_SVR_RMT', 'IZY_WEB_APPL_RMT', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO session.AMX_RelnRul_Transl VALUES ('IZY_WEB_APPL_RMT', 'IZY_SERVLET_RMT', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');


INSERT INTO AMX.RelnRul_Transl (CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd, 
                                RelnRul_Strt_DtTm, RelnRul_End_DtTm)
SELECT 
   t.CompTyp_Source_Cd,
   t.CompTyp_Target_Cd,
   t.RelnTyp_Cd,
   t.RelnRul_Strt_DtTm,
   t.RelnRul_End_DtTm
FROM 
   session.AMX_RelnRul_Transl t
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  AMX.RelnRul_Transl r
  WHERE
  t.CompTyp_Source_Cd = r.CompTyp_Source_Cd AND
  t.CompTyp_Target_Cd = r.CompTyp_Target_Cd AND
  t.RelnTyp_Cd = r.RelnTyp_Cd 
);


-----------------------------------------------
-- insert the dimension: WebSphere metric info
-- for the WebSphere DataMart
-----------------------------------------------



declare global temporary table temp_min_exists (
 msmttyp_id	integer,
 min_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_min_exists
select
 mb.msmttyp_id,
 'Y' as min_exists
from
 TWG.MgrpMbr mb,
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MIN_E' AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'
;

-- select * from session.temp_min_exists;
-- select count(*) from session.temp_min_exists;


declare global temporary table temp_max_exists (
 msmttyp_id	integer,
 max_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_max_exists
select
 mb.msmttyp_id,
 'Y' as max_exists
from
 TWG.MgrpMbr mb ,
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MAX_E' AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'
;
-- select count(*) from session.temp_max_exists;


declare global temporary table temp_avg_exists (
 msmttyp_id	integer,
 avg_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_avg_exists
select
 mb.msmttyp_id,
 'Y' as avg_exists
from
 TWG.MgrpMbr mb ,
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='AVG_E'    AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'

;

-- select count(*) from session.temp_avg_exists;


declare global temporary table temp_tot_exists (
 msmttyp_id	integer,
 tot_exists     char(1)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_tot_exists
select
 mb.msmttyp_id,
 'Y' as tot_exists
from
 TWG.MgrpMbr mb, 
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='TOT_E'AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'

;

-- select count(*) from session.temp_tot_exists;


-- Insert measurements with WebSphere specific measurement groups,
-- using Measurement Group table MGrp_Nm as the category (for met_Category) 

declare global temporary table temp_category (
 msmttyp_id	integer,
 category     varchar(120)
)
with replace on commit preserve rows not logged 
; 
 
insert into session.temp_category
select
 mb.msmttyp_id,
 mg.mgrp_nm as category
from
 TWG.MgrpMbr mb,
 TWG.Mgrp mg
where
 mb.mgrptyp_cd = 'STATE' and
 mb.mgrp_cd='IZY_ST' and
 mb.mgrp_cd = mg.mgrp_cd
;

-- select count(*) from session.temp_category;


drop table IZY.STAGE_D_WAS_METRIC;

create table IZY.STAGE_D_WAS_METRIC (
 insert_dttm		timestamp,
 Metric_ID            integer not null,
 Met_Category         VARCHAR(254) NOT NULL,
 Met_Desc          VARCHAR(254) NOT NULL,
 Met_Name          VARCHAR(120) NOT NULL,
 Met_Units         CHAR(6) NOT NULL,
 MIN_Exists           CHARACTER NOT NULL,
 MAX_Exists           CHARACTER NOT NULL,
 AVG_Exists           CHARACTER NOT NULL,
 Total_Exists         CHARACTER NOT NULL,
 Msrc_Nm				 VARCHAR(50) NOT NULL,
       PRIMARY KEY (Metric_ID)
);

insert  into IZY.STAGE_D_WAS_METRIC
select
 current timestamp - CURRENT timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 value(cat.category,'not used') as Met_Category,
 mt.msmttyp_ds as met_desc,
 mt.msmttyp_nm as met_name,
 mt.munit_cd as met_units,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 'IZY' as msrc_nm
from
 TWG.msmttyp mt left outer join session.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 TWG.msmttyp mt2 left outer join session.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 TWG.msmttyp mt3 left outer join session.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 TWG.msmttyp mt4 left outer join session.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 TWG.msmttyp mt5 left outer join session.temp_category cat
 on mt5.msmttyp_id=cat.msmttyp_id,
 TWG.MsmtRul mr
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mr.comptyp_cd in ('IZY_ADMIN_SERVER','IZY_APPL_SERVER','IZY_DATA_SOURCE','IZY_CONNECT_POOL',
                   'IZY_EJB','IZY_JVM','IZY_SERVLET_SESS','IZY_TRANSACT_MGR',
                   'IZY_THREAD_POOL','IZY_WEB_APPL','IZY_SERVLET') and
 mt.MSrc_Cd = 'IZY' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 mt.msmttyp_id = mt5.msmttyp_id
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd, 
 min_exists, avg_exists, tot_exists, max_exists,cat.category
;

--#endtag fixpack_1


-- @D1 Start of code for fixpack 2: Version 5.1.2 
--#iftag fixpack_2        

-- Update measurement source name to reflect new version of PAC (V5.1.2)
update TWG.MSrc ms
   SET ms.MSrc_Nm = 'IBM Tivoli Monitoring for Web Infrastructure, Version 5.1.2: WebSphere Application Server'
     where
      (ms.MSrc_Cd='IZY')
  ;                                

-- create a temporary table for generic component types

CREATE table IZY.Temp_CompTyp (
       CompTyp_Cd           CHAR(17) NOT NULL,
       CompTyp_Parent_Cd    CHAR(17),
       CompTyp_Nm           VARCHAR(120) NOT NULL,
       CompTyp_Strt_DtTm    TIMESTAMP NOT NULL,
       CompTyp_End_DtTm     TIMESTAMP NOT NULL
) 
;

insert into IZY.Temp_CompTyp values ('IZY_NODE',NULL, 'IBM WebSphere Node', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into IZY.Temp_CompTyp values ('IZY_NODE_AGENT', NULL, 'IBM WebSphere Node Agent', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into IZY.Temp_CompTyp values ('IZY_DYNA_CACHE',NULL, 'IBM WebSphere Dynamic Cache', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into IZY.Temp_CompTyp values ('IZY_J2C_CONFACT', NULL , 'IBM WebSphere J2C Connection Factory', current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into IZY.Temp_CompTyp values ('IZY_J2C_CONPOOL', NULL, 'IBM WebSphere J2C Connection Pool', current timestamp - current timezone, '9999-01-01-00.00.00.000000');


-- insert the component types into the generic schema 
-- if not exist already

insert into TWG.CompTyp (CompTyp_Cd, CompTyp_Parent_Cd, CompTyp_Nm, CompTyp_Strt_DtTm, CompTyp_End_DtTm) 
select 
 c.CompTyp_Cd,
 c.CompTyp_Parent_Cd,
 c.CompTyp_Nm,
 c.CompTyp_Strt_DtTm,
 c.CompTyp_End_DtTm   
from 
 IZY.Temp_CompTyp c
where not exists
( select 1 from
  TWG.CompTyp t
  where
  t.CompTyp_cd=c.CompTyp_cd)
  ;

drop table IZY.Temp_CompTyp;

-- Change capitalization to conform to HCI standards                                                                              
update  TWG.CompTyp ct
   SET ct.CompTyp_Nm =  'IBM WebSphere Application Server Host'
      WHERE ct.CompTyp_Cd = 'IZY_HOST';           

update  TWG.CompTyp ct
   SET ct.CompTyp_Nm =  'IBM WebSphere Administration Server'
      WHERE ct.CompTyp_Cd = 'IZY_ADMIN_SERVER';
update  TWG.CompTyp ct
   SET ct.CompTyp_Nm =  'IBM WebSphere Application Server'
      WHERE ct.CompTyp_Cd = 'IZY_APPL_SERVER';
update  TWG.CompTyp ct
   SET ct.CompTyp_Nm =  'IBM WebSphere Data Source'
      WHERE ct.CompTyp_Cd = 'IZY_DATA_SOURCE';
update  TWG.CompTyp ct
   SET ct.CompTyp_Nm =  'IBM WebSphere Connection Pool'
      WHERE ct.CompTyp_Cd = 'IZY_CONNECT_POOL';
update  TWG.CompTyp ct
   SET ct.CompTyp_Nm =  'IBM WebSphere Enterprise Javabean'
      WHERE ct.CompTyp_Cd = 'IZY_EJB';
update  TWG.CompTyp ct
   SET ct.CompTyp_Nm =  'IBM WebSphere Java Virtual Machine'
      WHERE ct.CompTyp_Cd = 'IZY_JVM';
update  TWG.CompTyp ct
   SET ct.CompTyp_Nm =  'IBM WebSphere Servlet Session'
      WHERE ct.CompTyp_Cd = 'IZY_SERVLET_SESS';
update  TWG.CompTyp ct
   SET ct.CompTyp_Nm =  'IBM WebSphere Thread Pool'
      WHERE ct.CompTyp_Cd = 'IZY_THREAD_POOL';
update  TWG.CompTyp ct
   SET ct.CompTyp_Nm =  'IBM WebSphere Transaction Manager'
      WHERE ct.CompTyp_Cd = 'IZY_TRANSACT_MGR';
update  TWG.CompTyp ct
   SET ct.CompTyp_Nm =  'IBM WebSphere Web Application'
      WHERE ct.CompTyp_Cd = 'IZY_WEB_APPL';
update  TWG.CompTyp ct
   SET ct.CompTyp_Nm =  'IBM WebSphere Servlet'
      WHERE ct.CompTyp_Cd = 'IZY_SERVLET';


--------------------------------------------------
-- Temporary for TWG.RelnRul
----------------------------------------

CREATE TABLE IZY.Temp_RelnRul (
       CompTyp_Source_Cd    CHAR(17) NOT NULL,
       CompTyp_Target_Cd    CHAR(17) NOT NULL,
       RelnTyp_Cd           CHAR(6) NOT NULL,
       RelnRul_Strt_DtTm    TIMESTAMP NOT NULL,
       RelnRul_End_DtTm     TIMESTAMP NOT NULL
)
;

-- @D3C - added 'current timezone'
insert into IZY.temp_RelnRul values ('IP_HOST','IZY_NODE','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('IP_INTERFACE','IZY_NODE','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('IZY_HOST','IZY_NODE','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('IZY_NODE','IZY_APPL_SERVER','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('IZY_NODE','IZY_NODE_AGENT','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('IZY_APPL_SERVER','IZY_DYNA_CACHE','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('IZY_APPL_SERVER','IZY_J2C_CONFACT','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('IZY_J2C_CONFACT','IZY_J2C_CONPOOL','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');


insert into TWG.RelnRul (CompTyp_Source_Cd,CompTyp_Target_Cd, RelnTyp_Cd, RelnRul_Strt_DtTm, RelnRul_End_DtTm)
select
 m.CompTyp_Source_Cd,
 m.CompTyp_Target_Cd,
 m.RelnTyp_Cd,
 m.RelnRul_Strt_DtTm,
 m.RelnRul_End_DtTm
from
 IZY.temp_RelnRul m
where
 not exists
( select 1 from
  TWG.RelnRul t
  where
  t.CompTyp_Source_Cd = m.CompTyp_Source_Cd and
  t.CompTyp_Target_Cd = m.CompTyp_Target_Cd and
  t.RelnTyp_Cd = m.RelnTyp_Cd 
  )
; 
               
DROP table IZY.temp_RelnRul;

-- Expire relationship of AdminServer parent to Appl Server 
-- Parent of Appl Server for WAS 4.0 changed to Node to correspond with WAS 5.0
-- @D3C add 'current timezone'
update TWG.RelnRul  trr 
   set trr.RelnRul_End_DtTm = current timestamp - current timezone
     where
      (trr.CompTyp_Source_Cd  = 'IZY_ADMIN_SERVER' AND                             
       trr.CompTyp_target_Cd  = 'IZY_APPL_SERVER');                                
-----------------------------------------------------------------
-- create a temporary table for ITM for WebSphere attribute types
-----------------------------------------------------------------
create table IZY.Temp_AttrTyp (
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Nm           VARCHAR(120) NOT NULL
) 
;

insert into IZY.Temp_AttrTyp values ('J2EE_CELL', 'IBM WebSphere Cell');
insert into IZY.Temp_AttrTyp values ('IZY_CLUSTER', 'IBM WebSphere Application Server Cluster');


-- insert the ITM for WebSphere attribute types into the generic schema 
-- if not exist already

insert into TWG.AttrTyp (AttrTyp_Cd, AttrTyp_Nm) 
select 
 m.AttrTyp_Cd,
 m.AttrTyp_Nm
from 
 IZY.Temp_AttrTyp m
where not exists
( select 1 from
  TWG.AttrTyp t
  where
  t.AttrTyp_Cd=m.AttrTyp_Cd )
  ;

DROP table IZY.Temp_AttrTyp;

--------------------------------------
-- temporary table for AttrRul 
---------------------------------------

CREATE table IZY.Temp_AttrRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrRul_Strt_DtTm    TIMESTAMP NOT NULL,
       AttrRul_End_DtTm     TIMESTAMP NOT NULL,
       AttrRul_Dom_Ind      CHAR NOT NULL
)
;   

-- @D3C add 'current timezone'
insert into IZY.Temp_AttrRul values ('IZY_NODE','VERSION', current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into IZY.Temp_AttrRul values ('IZY_NODE','OS_NAME', current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into IZY.Temp_AttrRul values ('IZY_NODE','TME_POLICY_REGION', current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');
insert into IZY.Temp_AttrRul values ('IZY_NODE','J2EE_CELL', current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');   

insert into IZY.Temp_AttrRul values ('IZY_APPL_SERVER','IZY_CLUSTER', current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');

insert into TWG.AttrRul (CompTyp_Cd, AttrTyp_Cd, AttrRul_Strt_DtTm, AttrRul_End_DtTm, AttrRul_Dom_Ind)
select 
 t.CompTyp_Cd ,
 t.AttrTyp_Cd ,
 t.AttrRul_Strt_DtTm ,
 t.AttrRul_End_DtTm ,
 t.AttrRul_Dom_Ind 
from 
 IZY.Temp_AttrRul t
where not exists
( select 1 from
  TWG.AttrRul m
  where
  t.CompTyp_Cd = m.CompTyp_Cd and
  t.AttrTyp_Cd = m.AttrTyp_Cd
  )
; 
   
DROP table IZY.Temp_AttrRul;

--
-- create a temporary table for ITM for WebSphere measurement types
--

CREATE table IZY.Temp_MsmtTyp (
       MUnit_Cd         CHAR(6) NOT NULL,
       MSrc_Cd          CHAR(6) NOT NULL,
       MsmtTyp_Nm       VARCHAR(120) NOT NULL,
       MsmtTyp_Ds       VARCHAR(254)
) 
;

insert into IZY.Temp_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'PRC', 'IZY', 'Percent_CPU_Utilization', 'Percent of the CPU utilized by the application server process. (This measurement is not collected in the z/OS and OS/400 environment.)');
insert into IZY.Temp_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'MB', 'IZY', 'Process_Size', 'Size of application server process. (This measurement is not collected in the z/OS and OS/400 environment.)');
insert into IZY.Temp_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'MSec', 'IZY', 'Average_JDBC_Response_Time', 'Average JDBC driver response time. (This measurement is valid for IBM WebSphere Application Server version 5 only.)');
insert into IZY.Temp_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'PRC', 'IZY', 'Percent_Missed', 'Ratio of missed requests to total requests in the dynamic cache. (This measurement is valid for IBM WebSphere Application Server version 5 only.)');
insert into IZY.Temp_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'QTY', 'IZY', 'Session_Request_Errors', 'Number of times a new session request cannot be satisfied. (This measurement is valid for IBM WebSphere Application Server version 5 only.)');
insert into IZY.Temp_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'MSec', 'IZY', 'Average_J2C_Use_Time', 'Average time J2C connections are in use. (This measurement is valid for IBM WebSphere Application Server version 5 only.)');
insert into IZY.Temp_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'MSec', 'IZY', 'Transaction_Global_Response_Time', 'Recent global transaction response time. (This measurement is not collected in the IBM WebSphere Application Server 3.5.x environment.)');
insert into IZY.Temp_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'Qpm', 'IZY', 'Transaction_Global_Request_Rate', 'Global transaction requests per minute. (This measurement is not collected in the IBM WebSphere Application Server 3.5.x environment.)');
insert into IZY.Temp_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'PRC', 'IZY', 'Transaction_Global_Exceptions', 'Global transaction time outs to total global transactions.  (This measurement is not collected in the z/OS or IBM WebSphere Application Server 3.5.x environment.)');
insert into IZY.Temp_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'MSec', 'IZY', 'Transaction_Local_Response_Time', 'Recent local transaction response time.  (This measurement is not collected in the IBM WebSphere Application Server 3.5.x environment.)');
insert into IZY.Temp_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'Qpm', 'IZY', 'Transaction_Local_Request_Rate', 'Local transaction requests per minute.  (This measurement is not collected in the IBM WebSphere Application Server 3.5.x environment.)');
insert into IZY.Temp_MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) values ( 'PRC', 'IZY', 'Transaction_Local_Exceptions', 'Local transaction time outs to total local transactions. (This measurement is not collected in the z/OS or IBM WebSphere Application Server 3.5.x environment.)');


-- insert the ITM for WebSphere measurement types into the generic schema 
-- if not exist already

insert into TWG.MsmtTyp (MUnit_Cd, MSrc_Cd, MsmtTyp_Nm, MsmtTyp_Ds) 
select 
 m.MUnit_Cd,
 m.MSrc_Cd,
 m.MsmtTyp_Nm,
 m.MsmtTyp_Ds
from 
 IZY.Temp_MsmtTyp m
where not exists
( select 1 from
  TWG.MsmtTyp t
  where
  t.MsmtTyp_Nm=m.MsmtTyp_Nm
)
;

drop table IZY.Temp_MsmtTyp;

-- Update the ITM for WebSphere measurement types - add clarification on platforms supported
update  TWG.MsmtTyp mt
   SET mt.MsmtTyp_Ds =  'Recent transaction response time. (This measurement is not collected in the IBM WebSphere Application Server 3.5.x environment.)'
      WHERE mt.MsmtTyp_Nm = 'Transaction_response_time';

update  TWG.MsmtTyp mt
   SET mt.MsmtTyp_Ds =  'Transaction requests per minute. (This measurement is not collected in the IBM WebSphere Application Server 3.5.x environment.)'
      WHERE mt.MsmtTyp_Nm = 'Transaction_request_rate';

update  TWG.MsmtTyp mt
   SET mt.MsmtTyp_Ds =  'Transaction time outs to total transactions.  (This measurement is not collected in the z/OS or IBM WebSphere Application Server 3.5.x environment.)'
      WHERE mt.MsmtTyp_Nm = 'Transaction_exceptions';

-- Update the ITM for WebSphere measurement types - change capitalization to match HCI guidelines

-- create a temporary table for ITM for WebSphere measurement rules
Create table IZY.Temp_MsmtRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       MsmtTyp_ID           INTEGER NOT NULL
) 
;

insert into IZY.Temp_MsmtRul
select 'IZY_CONNECT_POOL', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_JDBC_Response_Time'
);

insert into IZY.Temp_MsmtRul
select 'IZY_DYNA_CACHE', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Percent_Missed'
);                     

insert into IZY.Temp_MsmtRul
select 'IZY_SERVLET_SESS', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Session_Request_Errors'
);

insert into IZY.Temp_MsmtRul
select 'IZY_J2C_CONPOOL', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_J2C_Use_Time'
);                                         

insert into IZY.Temp_MsmtRul
select 'IZY_TRANSACT_MGR', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Transaction_Global_Response_Time',
   'Transaction_Global_Request_Rate',
   'Transaction_Global_Exceptions',
   'Transaction_Local_Response_Time',
   'Transaction_Local_Request_Rate',
   'Transaction_Local_Exceptions'
);

insert into IZY.Temp_MsmtRul
select 'IZY_APPL_SERVER', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Percent_CPU_Utilization', 
   'Process_Size'
);                  

insert into IZY.Temp_MsmtRul
select 'IZY_NODE_AGENT', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'WebSphere_server_state_up',
   'WebSphere_server_state_down',
   'WebSphere_server_state_initializing',
   'WebSphere_server_state_unknown'
);

-- insert the measurement rule into the generic schema 
-- if not exist already

insert into TWG.MsmtRul (CompTyp_Cd, MsmtTyp_ID) 
select 
 m.CompTyp_Cd,
 m.MsmtTyp_ID
from 
 IZY.Temp_MsmtRul m
where not exists
( select 1 from
  TWG.MsmtRul t
  where
  t.CompTyp_Cd=m.CompTyp_Cd and
  t.MsmtTyp_ID=m.MsmtTyp_ID)
  ;

drop table IZY.Temp_MsmtRul;

---------------------------------------------------------
-- create a temporary table for measurement group member 

CREATE table IZY.Temp_MGrpMbr (
       MGrp_Cd              CHAR(6) NOT NULL,
       MGrpTyp_Cd           CHAR(6) NOT NULL,
       MsmtTyp_ID           INTEGER NOT NULL
       
)
;

-- insert the following two new WebSphere Application Server 5.0.x measurements, 
insert into IZY.Temp_MGrpMbr
select 'MAX_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='IZY' and 
MsmtTyp_Nm in (            
   'Percent_CPU_Utilization', 
   'Process_Size',
   'Average_JDBC_Response_Time',
   'Percent_Missed',
   'Average_J2C_Use_Time',
   'Transaction_Global_Response_Time',
   'Transaction_Global_Request_Rate',
   'Transaction_Local_Response_Time',
   'Transaction_Local_Request_Rate'
);

insert into IZY.Temp_MGrpMbr
select 'MIN_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='IZY' and
MsmtTyp_Nm in (
   'Percent_CPU_Utilization', 
   'Process_Size',
   'Average_JDBC_Response_Time',
   'Percent_Missed',
   'Average_J2C_Use_Time',
   'Transaction_Global_Response_Time',
   'Transaction_Global_Request_Rate',
   'Transaction_Local_Response_Time',
   'Transaction_Local_Request_Rate'
);

insert into IZY.Temp_MGrpMbr
select 'AVG_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='IZY' and 
MsmtTyp_Nm in (
   'Percent_CPU_Utilization', 
   'Process_Size',
   'Average_JDBC_Response_Time',
   'Percent_Missed',
   'Average_J2C_Use_Time',
   'Transaction_Global_Response_Time',
   'Transaction_Global_Request_Rate',
   'Transaction_Local_Response_Time',
   'Transaction_Local_Request_Rate'
);

insert into IZY.Temp_MGrpMbr
select 'TOT_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='IZY' and 
MsmtTyp_Nm in (            
   'Session_Request_Errors',
   'Transaction_Global_Exceptions',
   'Transaction_Local_Exceptions'
);

insert into TWG.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
select 
 m.MGrp_Cd,
 m.MGrpTyp_Cd,
 m.MsmtTyp_ID
from 
 IZY.Temp_MGrpMbr m
where not exists
( select 1 from
  TWG.MGrpMbr t
  where
  t.MGrpTyp_Cd=m.MGrpTyp_Cd and
  t.MGrp_Cd=m.MGrp_Cd and
  t.MsmtTyp_ID=m.MsmtTyp_ID)
  ;  

drop table IZY.Temp_MGrpMbr;

----------------------------------------------
-- AMX Translation tables for ETL1
----------------------------------------------
--------------------------------------------------
-- Need to link the ITM for WAS Resource to the compTyp_cd 
----------------------------------------------

CREATE table IZY.Temp_Rsrc_Transl (
Resource		varchar(128) not null,
CompTyp_Cd		varchar(17) not null
)
;

insert into IZY.Temp_Rsrc_Transl values ('WebSphereASNode','IZY_NODE');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASRemoteNode','IZY_NODE_RMT');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASNodeAgent','IZY_NODE_AGENT');

insert into IZY.Temp_Rsrc_Transl values ('WebSphereASApplicationServer','IZY_APPL_SERVER');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASDynamicCache','IZY_DYNA_CACHE');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASJ2CPool','IZY_J2C_CONPOOL');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASJ2CFactory','IZY_J2C_CONFACT');

insert into AMX.Resource_Transl(Resource, CompTyp_Cd) 
select 
t.Resource  ,
t.CompTyp_Cd  
from 
 IZY.Temp_Rsrc_Transl t
where not exists
( select 1 from
  AMX.Resource_Transl m
  where
  t.CompTyp_Cd = m.CompTyp_Cd 
-- t.resource = m.resource 
  )
; 

drop table IZY.Temp_Rsrc_Transl;

--------------------------------------------------
-- Need a translation table if the property 
-- can have more than 17 characters 
-- Need to know which properties are key properties
-- Need to know which properties will be used for the Comp_Nm
--------------------------------------------------

CREATE table IZY.Temp_CmpTp_Transl (
MSrc_Cd			char(3) not null,
ITM_Key_Property	varchar(1096) not null,
CompTyp_Cd		varchar(17) not null,
Comp_Format_Nm	varchar(254) not null
)
;

insert into IZY.Temp_CmpTp_Transl values ('IZY','WebSphereASNode.Name','IZY_NODE','WebSphereASNode.Name');
insert into IZY.Temp_CmpTp_Transl values ('IZY','WebSphereASRemoteNode.Name','IZY_NODE_RMT','WebSphereASRemoteNode.Name');
                               
insert into IZY.Temp_CmpTp_Transl values ('IZY','WebSphereASNodeAgent.Name','IZY_NODE_AGENT','WebSphereASNodeAgent.Name');
insert into IZY.Temp_CmpTp_Transl values ('IZY','WebSphereASDynamicCache.Name','IZY_DYNA_CACHE','WebSphereASDynamicCache.Name');
insert into IZY.Temp_CmpTp_Transl values ('IZY','WebSphereASJ2CPool.Name','IZY_J2C_CONPOOL','WebSphereASJ2CPool.Name');
insert into IZY.Temp_CmpTp_Transl values ('IZY','WebSphereASJ2CFactory.Name','IZY_J2C_CONFACT','WebSphereASJ2CFactory.Name');  

insert into AMX.Comptyp_Transl (MSrc_Cd, ITM_Key_Property, CompTyp_Cd,Comp_Format_Nm)
select 
t.MSrc_Cd  ,
t.ITM_key_property ,
t.CompTyp_Cd  ,
t.Comp_Format_Nm  
from 
 IZY.Temp_CmpTp_Transl t
where not exists
( select 1 from
  AMX.Comptyp_Transl m
  where
  t.MSrc_Cd = m.MSrc_Cd and
 -- t.ITM_key_property  = m.ITM_key_property 
  t.CompTyp_Cd  = m.CompTyp_Cd 
  )
; 

drop table IZY.Temp_CmpTp_Transl;

--------------------------------------------------
-- Need a translation table if the property 
-- can have more than 17 characters
----------------------------------------------

CREATE table IZY.Temp_AtrTp_Transl (
MSrc_Cd			char(3) not null,
ITM_Attr_Property	varchar(254) not null,
AttrTyp_Cd		varchar(17) not null
)
;

insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASNode.WasVersion','VERSION');
insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASNode.OSType','OS_NAME');
insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASNode.CellName','J2EE_CELL');
insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASNode.PolicyRegion','TME_POLICY_REGION');

insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASRemoteNode.IZY_HOST','IZY_HOST');
insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASRemoteNode.LAST_IP_ADDRESS','LAST_IP_ADDRESS');
insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASRemoteNode.WasVersion','VERSION');
insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASRemoteNode.OSType','OS_NAME');
insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASRemoteNode.CellName','J2EE_CELL');
insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASRemoteNode.PolicyRegion','TME_POLICY_REGION');

insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASApplicationServer.ClusterName','IZY_CLUSTER');


insert into AMX.Attrtyp_Transl (MSrc_Cd, ITM_Attr_Property, AttrTyp_Cd)
select 
t.MSrc_Cd  ,
t.ITM_Attr_Property  ,
t.AttrTyp_Cd 
from 
 IZY.Temp_AtrTp_Transl t
where not exists
( select 1 from
  AMX.Attrtyp_Transl m
  where
  t.MSrc_Cd = m.MSrc_Cd and
  t.ITM_Attr_Property  = m.ITM_Attr_Property 
  AND T.AttrTyp_Cd  = m.AttrTyp_Cd  
  )
; 

DROP table IZY.Temp_AtrTp_Transl;

------------------------------------------------------------------------------------------------
-- Insert data to define relation rules for remote (390) WebSphere Application Server components
------------------------------------------------------------------------------------------------ 

-- create temporary table for relation rule translation values
CREATE  TABLE IZY.temp_RlnRl_Transl (
   CompTyp_Source_Cd 	   VARCHAR(17) NOT NULL,
   CompTyp_Target_Cd 	   VARCHAR(17) NOT NULL,
   RelnTyp_Cd              CHAR(6) NOT NULL,
   RelnRul_Strt_DtTm    	Timestamp NOT NULL,
   RelnRul_End_DtTm        Timestamp NOT NULL
	)
;
  
INSERT INTO IZY.temp_RlnRl_Transl VALUES ('IZY_NODE', 'IZY_NODE_RMT', 'PROXY', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
INSERT INTO IZY.temp_RlnRl_Transl VALUES ('IZY_NODE_RMT', 'IZY_APPL_SVR_RMT', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');


INSERT INTO AMX.RelnRul_Transl (CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd, 
                                RelnRul_Strt_DtTm, RelnRul_End_DtTm)
SELECT 
   t.CompTyp_Source_Cd,
   t.CompTyp_Target_Cd,
   t.RelnTyp_Cd,
   t.RelnRul_Strt_DtTm,
   t.RelnRul_End_DtTm
FROM 
   IZY.temp_RlnRl_Transl t
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  AMX.RelnRul_Transl r
  WHERE
  t.CompTyp_Source_Cd = r.CompTyp_Source_Cd AND
  t.CompTyp_Target_Cd = r.CompTyp_Target_Cd AND
  t.RelnTyp_Cd = r.RelnTyp_Cd 
);

DROP table IZY.Temp_RlnRl_Transl;

-- Remove  relationship of rempote AdminServer parent to Appl Server 
--  Parent of Appl Server for WAS 4.0 changed to Node to correspond with WAS 5.0
DELETE FROM AMX.RelnRul_transl  rrt 
     where
      (rrt.CompTyp_Source_Cd  = 'IZY_ADMIN_SVR_RMT' AND                             
       rrt.CompTyp_target_Cd  = 'IZY_APPL_SVR_RMT' AND
       rrt.relntyp_cd= 'PCHILD')
;                                

-----------------------------------------------
-- insert the dimension: WebSphere metric info
-- for the WebSphere DataMart
-----------------------------------------------

CREATE  table IZY.temp_min_exists (
 msmttyp_id	integer,
 min_exists     char(1)
)
; 
 
insert into IZY.temp_min_exists
select
 mb.msmttyp_id,
 'Y' as min_exists
from
 TWG.MgrpMbr mb,
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MIN_E' AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'
;


create table IZY.temp_max_exists (
 msmttyp_id	integer,
 max_exists     char(1)
)
; 
 
insert into IZY.temp_max_exists
select
 mb.msmttyp_id,
 'Y' as max_exists
from
 TWG.MgrpMbr mb ,
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MAX_E' AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'
;                  


CREATE table IZY.temp_avg_exists (
 msmttyp_id	integer,
 avg_exists     char(1)
)
; 
 
insert into izy.temp_avg_exists
select
 mb.msmttyp_id,
 'Y' as avg_exists
from
 TWG.MgrpMbr mb ,
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='AVG_E'    AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'
;

-- select count(*) from izy.temp_avg_exists;

CREATE table izy.temp_tot_exists (
 msmttyp_id	integer,
 tot_exists     char(1)
)
; 
 
insert into izy.temp_tot_exists
select
 mb.msmttyp_id,
 'Y' as tot_exists
from
 TWG.MgrpMbr mb, 
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='TOT_E'AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'

;                  

-- Insert measurements with WebSphere specific measurement groups,
-- using Measurement Group table MGrp_Nm as the category (for met_Category) 

CREATE  table IZY.temp_category (
 msmttyp_id	integer,
 category     varchar(120)
)
; 
 
insert into izy.temp_category
select
 mb.msmttyp_id,
 mg.mgrp_nm as category
from
 TWG.MgrpMbr mb,
 TWG.Mgrp mg
where
 mb.mgrptyp_cd = 'STATE' and
 mb.mgrp_cd='IZY_ST' and
 mb.mgrp_cd = mg.mgrp_cd
;


drop table IZY.STAGE_D_WAS_METRIC;

create table IZY.STAGE_D_WAS_METRIC (
 insert_dttm		timestamp,
 Metric_ID            integer not null,
 Met_Category         VARCHAR(254) NOT NULL,
 Met_Desc          VARCHAR(254) NOT NULL,
 Met_Name          VARCHAR(120) NOT NULL,
 Met_Units         CHAR(6) NOT NULL,
 MIN_Exists           CHARACTER NOT NULL,
 MAX_Exists           CHARACTER NOT NULL,
 AVG_Exists           CHARACTER NOT NULL,
 Total_Exists         CHARACTER NOT NULL,
 Msrc_Nm				 VARCHAR(50) NOT NULL,
       PRIMARY KEY (Metric_ID)
);


insert  into IZY.STAGE_D_WAS_METRIC
select
-- @D3C add 'current timezone'
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 value(cat.category,'not used') as Met_Category,
 mt.msmttyp_ds as met_desc,
 mt.msmttyp_nm as met_name,
 mt.munit_cd as met_units,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 'IZY' as msrc_nm
from
 TWG.msmttyp mt left outer join izy.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 TWG.msmttyp mt2 left outer join izy.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 TWG.msmttyp mt3 left outer join izy.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 TWG.msmttyp mt4 left outer join izy.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 TWG.msmttyp mt5 left outer join izy.temp_category cat
 on mt5.msmttyp_id=cat.msmttyp_id,
 TWG.MsmtRul mr
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mr.comptyp_cd in ('IZY_ADMIN_SERVER','IZY_APPL_SERVER','IZY_DATA_SOURCE','IZY_CONNECT_POOL',
                   'IZY_EJB','IZY_JVM','IZY_SERVLET_SESS','IZY_TRANSACT_MGR',
                   'IZY_THREAD_POOL','IZY_WEB_APPL','IZY_SERVLET',
                   'IZY_NODE_AGENT','IZY_DYNA_CACHE', 'IZY_J2C_CONPOOL' ) and
 mt.MSrc_Cd = 'IZY' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 mt.msmttyp_id = mt5.msmttyp_id
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd, 
 min_exists, avg_exists, tot_exists, max_exists,cat.category
;


drop table IZY.temp_category;
DROP table izy.temp_tot_exists;
DROP table IZY.temp_avg_exists;
DROP table IZY.temp_min_exists;
DROP table IZY.temp_max_exists;

---------------------------------------
-- temporary table for Extract Control
---------------------------------------

CREATE table IZY.Temp_Ext_Ctl (
   ExtCtl_Source   	varchar(120) not null,
 	ExtCtl_Target   	varchar(120) not null,
 	ExtCtl_From_RawSeq      char(10) for bit data,
 	ExtCtl_To_RawSeq        char(10) for bit data,
 	ExtCtl_From_IntSeq      bigint,
 	ExtCtl_To_IntSeq        bigint,
 	ExtCtl_From_DtTm     	timestamp not null,
 	ExtCtl_To_DtTm       	timestamp not null
	)
;

-----------------------------------------------
-- From TWG.MSMT to the Mart Fact tables
-----------------------------------------------

insert into IZY.Temp_Ext_Ctl values (
    'TWG.MSMT' ,
    'IZY.F_CFGMGR_HOUR' ,
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into IZY.Temp_Ext_Ctl values (
    'TWG.MSMT' ,
    'IZY.F_APPL5_HOUR' ,
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into IZY.Temp_Ext_Ctl values (
    'TWG.MSMT' ,
    'IZY.F_APCP5_HOUR' ,
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into IZY.Temp_Ext_Ctl values (
    'TWG.MSMT' ,
    'IZY.F_SBCP5_HOUR' ,
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-------------------------------------------------------------------
-- From SHADOW Dimension tables in CDW to the Mart Dimension tables
-------------------------------------------------------------------

insert into IZY.Temp_Ext_Ctl values (
    'IZY.STAGE_D_WAS_METRIC' ,
    'IZY.D_WAS_METRIC' ,
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

-----------------------------------------------
-- From TWG.COMP to the Mart Dimension tables
-----------------------------------------------                                                                    F

insert into IZY.Temp_Ext_Ctl values (
    'TWG.COMP',
    'IZY.D_WAS_CELL' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into IZY.Temp_Ext_Ctl values (
    'TWG.COMP',
    'IZY.D_WAS_NODE' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);

insert into IZY.Temp_Ext_Ctl values (
    'TWG.COMP',
    'IZY.D_WAS_CFGMGR' ,
    x'',
    x'',
    -1,
    -1,
    '1970-01-01-00.00.00.000000',
    '9999-01-01-00.00.00.000000'
);


-- insert the static data for the extract table 
-- if not exist already

insert into TWG.Extract_control(ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
 ect.ExtCtl_Source  ,
 ect.ExtCtl_Target  ,
 ect.ExtCtl_From_RawSeq  ,
 ect.ExtCtl_To_RawSeq  ,
 ect.ExtCtl_From_IntSeq  ,
 ect.ExtCtl_To_IntSeq  ,
 ect.ExtCtl_From_DtTm  ,
 ect.ExtCtl_To_DtTm    
from 
 IZY.Temp_Ext_Ctl ect
where not exists
( select 1 from
  TWG.Extract_Control t
  where
  t.ExtCtl_Source=ect.ExtCtl_Source  and
  t.ExtCtl_Target=ect.ExtCtl_Target
  )
; 

DROP table IZY.Temp_Ext_Ctl;
--#endtag fixpack_2


--#iftag fixpack_3
-- @D4 Change modeling for WebSphere 5.0 to common components and change WebSphere 3.5 and 4 back to fixpack_v1101 modeling


-------------------------------------------------------------------------------------------------
-- Expire or Update Components no longer -used; converting to use common components
--------------------------------------------------------------------------------------------------
-- rename existing IZY_NODE_AGENT to WAS_NODE_AGENT

-- Expire compTyps introduced in 5.1.2 but no longer used as a result of common modeling
UPDATE TWG.CompTyp Ct
  SET ct.CompTyp_End_DtTm =  current timestamp - CURRENT timezone 
WHERE (ct.CompTyp_Cd = 'IZY_NODE');    
UPDATE TWG.CompTyp Ct
  SET ct.CompTyp_End_DtTm =  current timestamp - CURRENT timezone 
WHERE (ct.CompTyp_Cd = 'IZY_NODE_AGENT');    
UPDATE TWG.CompTyp Ct
  SET ct.CompTyp_End_DtTm =  current timestamp - CURRENT timezone 
WHERE (ct.CompTyp_Cd = 'IZY_DYNA_CACHE'); 
UPDATE TWG.CompTyp Ct
  SET ct.CompTyp_End_DtTm =  current timestamp - CURRENT timezone 
WHERE (ct.CompTyp_Cd = 'IZY_J2C_CONPOOL');    
UPDATE TWG.CompTyp Ct
  SET ct.CompTyp_End_DtTm =  current timestamp - CURRENT timezone 
WHERE (ct.CompTyp_Cd = 'IZY_J2C_CONFACT'); 

-- create a temporary table for generic component types

CREATE table IZY.Temp_CompTyp (
       CompTyp_Cd           CHAR(17) NOT NULL,
       CompTyp_Parent_Cd    CHAR(17),
       CompTyp_Nm           VARCHAR(120) NOT NULL,
       CompTyp_Strt_DtTm    TIMESTAMP NOT NULL,
       CompTyp_End_DtTm     TIMESTAMP NOT NULL
) 
;

insert into IZY.Temp_CompTyp values ('IZY_WAS_DATA_SRC', NULL, 'IBM WebSphere Data Source', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into IZY.Temp_CompTyp values ('IZY_WAS_CONN_PL', NULL, 'IBM WebSphere Connection Pool', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into IZY.Temp_CompTyp values ('IZY_WAS_EJB', NULL, 'IBM WebSphere Enterprise Javabean', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into IZY.Temp_CompTyp values ('IZY_WAS_JVM', NULL, 'IBM WebSphere Java Virtual Machine', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into IZY.Temp_CompTyp values ('IZY_WAS_SVLT_SESS', NULL, 'IBM WebSphere Servlet Session', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into IZY.Temp_CompTyp values ('IZY_WAS_THREAD_PL', NULL, 'IBM Websphere Thread Pool', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into IZY.Temp_CompTyp values ('IZY_WAS_TRANS_MGR', NULL, 'IBM Websphere Transaction Manager', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into IZY.Temp_CompTyp values ('IZY_WAS_WEB_APPL', NULL, 'IBM Websphere Web Application', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into IZY.Temp_CompTyp values ('IZY_WAS_SERVLET', NULL, 'IBM Websphere Servlet', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into IZY.Temp_CompTyp values ('IZY_WAS_DYNACACHE', NULL, 'IBM WebSphere Dynamic Cache', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into IZY.Temp_CompTyp values ('IZY_WAS_J2C_FACT', NULL, 'IBM WebSphere J2C Connection Factory', current timestamp - current timezone, '9999-01-01-12.00.00.000000');
insert into IZY.Temp_CompTyp values ('IZY_WAS_J2C_POOL', NULL, 'IBM WebSphere J2C Connection Pool', current timestamp - current timezone, '9999-01-01-12.00.00.000000');


-- insert the component types into the generic schema 
-- if not exist already

insert into TWG.CompTyp (CompTyp_Cd, CompTyp_Parent_Cd, CompTyp_Nm, CompTyp_Strt_DtTm, CompTyp_End_DtTm) 
select 
 c.CompTyp_Cd,
 c.CompTyp_Parent_Cd,
 c.CompTyp_Nm,
 c.CompTyp_Strt_DtTm,
 c.CompTyp_End_DtTm   
from 
 IZY.Temp_CompTyp c
where not exists
( select 1 from
  TWG.CompTyp t
  where
  t.CompTyp_cd=c.CompTyp_cd)
  ;

drop table IZY.Temp_CompTyp;

----------------------------------------
-- Temporary for TWG.RelnRul
----------------------------------------

UPDATE TWG.RelnRul rr 
  SET rr.Relnrul_End_DtTm =  current timestamp - CURRENT timezone 
   WHERE rr.CompTyp_Source_Cd = 'IP_HOST' AND rr.CompTyp_Target_Cd = 'IZY_NODE' AND rr.relnTyp_Cd = 'PCHILD';
UPDATE TWG.RelnRul rr 
  SET rr.Relnrul_End_DtTm =  current timestamp - CURRENT timezone 
   WHERE rr.CompTyp_Source_Cd = 'IP_INTERFACE' AND rr.CompTyp_Target_Cd = 'IZY_NODE' AND rr.relnTyp_Cd = 'PCHILD';
UPDATE TWG.RelnRul rr 
  SET rr.Relnrul_End_DtTm =  current timestamp - CURRENT timezone 
   WHERE rr.CompTyp_Source_Cd = 'IZY_HOST' AND rr.CompTyp_Target_Cd = 'IZY_NODE' AND rr.relnTyp_Cd = 'PCHILD';
UPDATE TWG.RelnRul rr 
  SET rr.Relnrul_End_DtTm =  current timestamp - CURRENT timezone 
    WHERE rr.CompTyp_Source_Cd = 'IZY_NODE' AND rr.CompTyp_Target_Cd = 'IZY_APPL_SERVER' AND rr.relnTyp_Cd = 'PCHILD';
UPDATE TWG.RelnRul rr 
  SET rr.Relnrul_End_DtTm =  current timestamp - CURRENT timezone 
    WHERE rr.CompTyp_Source_Cd = 'IZY_NODE' AND rr.CompTyp_Target_Cd = 'IZY_NODE_AGENT' AND rr.relnTyp_Cd = 'PCHILD';
UPDATE TWG.RelnRul rr 
  SET rr.Relnrul_End_DtTm =  current timestamp - CURRENT timezone 
    WHERE rr.CompTyp_Source_Cd = 'IZY_APPL_SERVER' AND rr.CompTyp_Target_Cd = 'IZY_DYNA_CACHE' AND rr.relnTyp_Cd = 'PCHILD';
UPDATE TWG.RelnRul rr 
  SET rr.Relnrul_End_DtTm =  current timestamp - CURRENT timezone 
    WHERE rr.CompTyp_Source_Cd = 'IZY_APPL_SERVER' AND rr.CompTyp_Target_Cd = 'IZY_J2C_CONFACT' AND rr.relnTyp_Cd = 'PCHILD';
UPDATE TWG.RelnRul rr 
  SET rr.Relnrul_End_DtTm =  current timestamp - CURRENT timezone 
    WHERE rr.CompTyp_Source_Cd = 'IZY_J2C_CONFACT' AND rr.CompTyp_Target_Cd = 'IZY_J2C_CONPOOL' AND rr.relnTyp_Cd = 'PCHILD';

-- Recreate/Unexpire relationship (expired in fp_2) of AdminServer parent to Appl Server 
update TWG.RelnRul  trr 
   set trr.RelnRul_End_DtTm = '9999-01-01-00.00.00.000000'
     where
      (trr.CompTyp_Source_Cd  = 'IZY_ADMIN_SERVER' AND                             
       trr.CompTyp_target_Cd  = 'IZY_APPL_SERVER');                                


CREATE TABLE IZY.Temp_RelnRul (
       CompTyp_Source_Cd    CHAR(17) NOT NULL,
       CompTyp_Target_Cd    CHAR(17) NOT NULL,
       RelnTyp_Cd           CHAR(6) NOT NULL,
       RelnRul_Strt_DtTm    TIMESTAMP NOT NULL,
       RelnRul_End_DtTm     TIMESTAMP NOT NULL
)
;


insert into IZY.temp_RelnRul values ('J2EE_SERVER','IZY_HOST','RUNSON',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('WAS_NODE_AGENT','IZY_HOST','RUNSON',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into IZY.temp_RelnRul VALUES ('J2EE_SERVER','IP_INTERFACE','RUNSON',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul VALUES ('WAS_NODE_AGENT','IP_INTERFACE','RUNSON',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into IZY.temp_RelnRul values ('J2EE_SERVER','IZY_WAS_DATA_SRC','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('J2EE_SERVER','IZY_WAS_EJB','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('J2EE_SERVER','IZY_WAS_JVM','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('J2EE_SERVER','IZY_WAS_SVLT_SESS','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('J2EE_SERVER','IZY_WAS_THREAD_PL','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('J2EE_SERVER','IZY_WAS_TRANS_MGR','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('J2EE_SERVER','IZY_WAS_WEB_APPL','PCHILD',current timestamp, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('J2EE_SERVER','IZY_WAS_DYNACACHE','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('J2EE_SERVER','IZY_WAS_J2C_FACT','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('IZY_WAS_DATA_SRC','IZY_WAS_CONN_PL','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('IZY_WAS_WEB_APPL','IZY_WAS_SERVLET','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');
insert into IZY.temp_RelnRul values ('IZY_WAS_J2C_FACT','IZY_WAS_J2C_POOL','PCHILD',current timestamp - current timezone, '9999-01-01-00.00.00.000000');

insert into TWG.RelnRul (CompTyp_Source_Cd,CompTyp_Target_Cd, RelnTyp_Cd, RelnRul_Strt_DtTm, RelnRul_End_DtTm)
select
 m.CompTyp_Source_Cd,
 m.CompTyp_Target_Cd,
 m.RelnTyp_Cd,
 m.RelnRul_Strt_DtTm,
 m.RelnRul_End_DtTm
from
 IZY.temp_RelnRul m
where
 not exists
( select 1 from
  TWG.RelnRul t
  where
  t.CompTyp_Source_Cd = m.CompTyp_Source_Cd and
  t.CompTyp_Target_Cd = m.CompTyp_Target_Cd and
  t.RelnTyp_Cd = m.RelnTyp_Cd 
  )
; 
               
DROP table IZY.temp_RelnRul;

--------------------------------------------------------------------------------------------------
-- Expire existing attribute rules for IZY_Node
--------------------------------------------------------------------------------------------------

UPDATE TWG.AttrRul Ar
  SET Ar.AttrRul_End_DtTm =  current timestamp - CURRENT timezone 
WHERE (Ar.CompTyp_Cd = 'IZY_NODE') AND
       (Ar.AttrTyp_Cd IN ('VERSION', 'OS_NAME', 'TME_POLICY_REGION', 'J2EE_CELL'));

UPDATE TWG.AttrRul Ar
  SET Ar.AttrRul_End_DtTm =  current timestamp - CURRENT timezone 
WHERE (Ar.CompTyp_Cd = 'IZY_APPL_SERVER') AND
       (Ar.AttrTyp_Cd IN ('IZY_CLUSTER'));


-------------------------------------
-- Can't delete IZY_CLUSTER attrTyp                              
-------------------------------------

--------------------------------------
-- temporary table for AttrRul 
---------------------------------------

CREATE table IZY.Temp_AttrRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       AttrTyp_Cd           CHAR(17) NOT NULL,
       AttrRul_Strt_DtTm    TIMESTAMP NOT NULL,
       AttrRul_End_DtTm     TIMESTAMP NOT NULL,
       AttrRul_Dom_Ind      CHAR NOT NULL
)
;   

insert into IZY.Temp_AttrRul values ('J2EE_NODE','OS_NAME', current timestamp - current timezone, '9999-01-01-00.00.00.000000','N');

insert into TWG.AttrRul (CompTyp_Cd, AttrTyp_Cd, AttrRul_Strt_DtTm, AttrRul_End_DtTm, AttrRul_Dom_Ind)
select 
 t.CompTyp_Cd ,
 t.AttrTyp_Cd ,
 t.AttrRul_Strt_DtTm ,
 t.AttrRul_End_DtTm ,
 t.AttrRul_Dom_Ind 
from 
 IZY.Temp_AttrRul t
where not exists
( select 1 from
  TWG.AttrRul m
  where
  t.CompTyp_Cd = m.CompTyp_Cd and
  t.AttrTyp_Cd = m.AttrTyp_Cd
  )
; 
   
DROP table IZY.Temp_AttrRul;

--------------------------------------
-- MsmtRul 
---------------------------------------
DELETE FROM TWG.MsmtRul mr
   WHERE mr.CompTyp_Cd = 'IZY_NODE_AGENT';
DELETE FROM TWG.MsmtRul mr
   WHERE mr.CompTyp_Cd = 'IZY_DYNA_CACHE';
DELETE FROM TWG.MsmtRul mr
   WHERE mr.CompTyp_Cd = 'IZY_J2C_CONPOOL';                                     
DELETE FROM TWG.MsmtRul mr
   WHERE mr.CompTyp_Cd = 'IZY_SERVLET_SESS' 
   AND mr.MsmtTyp_Id = (SELECT mt.msmtTyp_id FROM TWG.MsmtTyp mt WHERE mt.MsmtTyp_Nm = 'Session_Request_Errors') ;
DELETE FROM TWG.MsmtRul mr
   WHERE mr.CompTyp_Cd = 'IZY_CONNECT_POOL' 
   AND mr.MsmtTyp_Id = (SELECT mt.msmtTyp_id FROM TWG.MsmtTyp mt WHERE mt.MsmtTyp_Nm = 'Average_JDBC_Response_Time') ;

-- create a temporary table for ITM for WebSphere measurement rules
Create table IZY.Temp_MsmtRul (
       CompTyp_Cd           CHAR(17) NOT NULL,
       MsmtTyp_ID           INTEGER NOT NULL
) 
;
          
insert into IZY.Temp_MsmtRul
select 'IZY_WAS_DYNACACHE', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Percent_Missed'
);                            

insert into IZY.Temp_MsmtRul
select 'IZY_WAS_J2C_POOL', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_J2C_Use_Time'
);                            

insert into IZY.Temp_MsmtRul
select 'J2EE_SERVER', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_EJB_response_time',
   'EJB_request_rate',
   'Average_concurrent_EJB_requests',
   'Percent_EJB_returns_discarded',
   'Average_servlet_response_time',
   'Servlet_request_rate',
   'Concurrent_servlet_requests',
   'Servlet_error_rate',               
   'WebSphere_server_state_up',
   'WebSphere_server_state_down',
   'WebSphere_server_state_initializing',
   'WebSphere_server_state_unknown',
   'Percent_CPU_Utilization', 
   'Process_Size'
);                  

insert into IZY.Temp_MsmtRul
select 'WAS_NODE_AGENT', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'WebSphere_server_state_up',
   'WebSphere_server_state_down',
   'WebSphere_server_state_initializing',
   'WebSphere_server_state_unknown'
);

insert into IZY.Temp_MsmtRul
select 'IZY_WAS_CONN_PL', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_connection_pool_wait_time',
   'Average_connection_pool_percent_used',
   'Average_JDBC_Response_Time',
   'Connection_pool_faults'
);


insert into IZY.Temp_MsmtRul
select 'IZY_WAS_EJB', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_EJB_response_time',
   'EJB_request_rate',
   'Average_concurrent_EJB_requests',
   'Percent_EJB_returns_discarded'
);

insert into IZY.Temp_MsmtRul
select 'IZY_WAS_JVM', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Used_JVM_memory',
   'Total_JVM_memory'
);

insert into IZY.Temp_MsmtRul
select 'IZY_WAS_THREAD_PL', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Active_threads_to_pool_size_ratio'
); 

insert into IZY.Temp_MsmtRul
select 'IZY_WAS_WEB_APPL', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_servlet_response_time',
   'Servlet_request_rate',
   'Concurrent_servlet_requests',
   'Servlet_error_rate'
);                     

insert into IZY.Temp_MsmtRul
select 'IZY_WAS_SERVLET', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Average_servlet_response_time',
   'Servlet_request_rate',
   'Concurrent_servlet_requests',
   'Servlet_error_rate'
);


insert into IZY.Temp_MsmtRul
select 'IZY_WAS_SVLT_SESS', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Live_servlet_sessions',
   'Session_Request_Errors'
);

insert into IZY.Temp_MsmtRul
select 'IZY_WAS_TRANS_MGR', mt.MsmtTyp_ID from TWG.MsmtTyp mt where 
MsmtTyp_Nm in (
   'Transaction_response_time',
   'Transaction_request_rate',
   'Transaction_exceptions',
   'Transaction_Global_Response_Time',
   'Transaction_Global_Request_Rate',
   'Transaction_Global_Exceptions',
   'Transaction_Local_Response_Time',
   'Transaction_Local_Request_Rate',
   'Transaction_Local_Exceptions'
);


-- insert the measurement rule into the generic schema 
-- if not exist already
insert into TWG.MsmtRul (CompTyp_Cd, MsmtTyp_ID) 
select 
 m.CompTyp_Cd,
 m.MsmtTyp_ID
from 
 IZY.Temp_MsmtRul m
where not exists
( select 1 from
  TWG.MsmtRul t
  where
  t.CompTyp_Cd=m.CompTyp_Cd and
  t.MsmtTyp_ID=m.MsmtTyp_ID)
  ;

DROP table IZY.Temp_MsmtRul;

-- @D5A Update Total_JVM_memory,Servlet_request_rate,Transaction_exceptions, Transaction_Global_Exceptions,Transaction_Local_Exceptions
--     to be a Min, Max, Avg value, instead of a total. 
---------------------------------------------------------
-- create a temporary table for measurement group member 
---------------------------------------------------------
declare global temporary table IZY_MGrpMbr (
       MGrp_Cd              CHAR(6) NOT NULL,
       MGrpTyp_Cd           CHAR(6) NOT NULL,
       MsmtTyp_ID           INTEGER NOT NULL
       
)
with replace on commit preserve rows not logged
;

-- Add  Total_JVM_memory,Servlet_request_rate,Transaction_exceptions, Transaction_Global_Exceptions,Transaction_Local_Exceptions
-- as a Min, Max, Avg value, instead of a total. 
insert into session.IZY_MGrpMbr
select 'MAX_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='IZY' and 
MsmtTyp_Nm in (
               'Total_JVM_memory',
               'Servlet_request_rate',
               'Transaction_exceptions',
               'Transaction_Global_Exceptions',
               'Transaction_Local_Exceptions'            

);

insert into session.IZY_MGrpMbr
select 'MIN_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='IZY' and
MsmtTyp_Nm in (
               'Total_JVM_memory',
               'Servlet_request_rate',
               'Transaction_exceptions',
               'Transaction_Global_Exceptions',
               'Transaction_Local_Exceptions'            
);

insert into session.IZY_MGrpMbr
select 'AVG_E','GROUP', mt.MsmtTyp_ID from TWG.MsmtTyp mt where MSrc_Cd='IZY' and 
MsmtTyp_Nm in (
               'Total_JVM_memory',
               'Servlet_request_rate',
               'Transaction_exceptions',
               'Transaction_Global_Exceptions',
               'Transaction_Local_Exceptions'            
);

insert into TWG.MGrpMbr (MGrp_Cd, MGrpTyp_Cd, MsmtTyp_ID)
select 
 m.MGrp_Cd,
 m.MGrpTyp_Cd,
 m.MsmtTyp_ID
from 
 session.IZY_MGrpMbr m
where not exists
( select 1 from
  TWG.MGrpMbr t
  where
  t.MGrpTyp_Cd=m.MGrpTyp_Cd and
  t.MGrp_Cd=m.MGrp_Cd and
  t.MsmtTyp_ID=m.MsmtTyp_ID)
  ;  

-- 'EJB_request_rate' is a min, max and average value; remove from total
DELETE  from TWG.MGrpMbr mg
 where 
   mg.MGrp_Cd = 'TOT_E' and
   mg.MsmtTyp_ID IN  
      (SELECT mt.MsmtTyp_ID FROM TWG.MsmtTyp mt  
         WHERE mt.MsmtTyp_Nm IN  (
               'Total_JVM_memory',
               'Servlet_request_rate',
               'Transaction_exceptions',
               'Transaction_Global_Exceptions',
               'Transaction_Local_Exceptions') )
;
-- @D5A End

----------------------------------------------
-- AMX Translation tables for ETL1
----------------------------------------------
--------------------------------------------------
-- Need to link the ITM for WAS Resource to the compTyp_cd 
----------------------------------------------

DELETE from AMX.Resource_Transl rt
    WHERE  rt.RESOURCE = 'WebSphereASRemoteNode'AND rt.CompTyp_Cd = 'IZY_NODE_RMT';
DELETE FROM AMX.Resource_Transl rt
   WHERE  rt.RESOURCE = 'WebSphereASNode' AND rt.CompTyp_Cd = 'IZY_NODE';
DELETE FROM AMX.Resource_Transl rt
   WHERE  rt.RESOURCE = 'WebSphereASNodeAgent' AND rt.CompTyp_Cd = 'IZY_NODE_AGENT';
DELETE FROM AMX.Resource_Transl rt
   WHERE  rt.RESOURCE = 'WebSphereASDynamicCache' AND rt.CompTyp_Cd = 'IZY_DYNA_CACHE';
DELETE FROM AMX.Resource_Transl rt
   WHERE  rt.RESOURCE = 'WebSphereASJ2CPool' AND rt.CompTyp_Cd = 'IZY_J2C_CONPOOL';
DELETE FROM AMX.Resource_Transl rt
   WHERE  rt.RESOURCE = 'WebSphereASJ2CFactory' AND rt.CompTyp_Cd = 'IZY_J2C_CONFACT';

CREATE table IZY.Temp_Rsrc_Transl (
Resource		varchar(128) not null,
CompTyp_Cd		varchar(17) not null
)
;

insert into IZY.Temp_Rsrc_Transl values ('WebSphereASJ2EECell','J2EE_CELL');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASJ2EENode','J2EE_NODE');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASJ2EEServer','J2EE_SERVER');

insert into IZY.Temp_Rsrc_Transl values ('WebSphereASV5NodeAgent','WAS_NODE_AGENT');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASV5DataSource','IZY_WAS_DATA_SRC');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASV5ConnectionPool','IZY_WAS_CONN_PL');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASV5EJB','IZY_WAS_EJB');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASV5JVMRuntime','IZY_WAS_JVM');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASV5ServletSession','IZY_WAS_SVLT_SESS');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASV5Transaction','IZY_WAS_TRANS_MGR');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASV5ThreadPool','IZY_WAS_THREAD_PL');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASV5WebApplication','IZY_WAS_WEB_APPL');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASV5Servlet','IZY_WAS_SERVLET');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASV5DynamicCache','IZY_WAS_DYNACACHE');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASV5J2CPool','IZY_WAS_J2C_POOL');
insert into IZY.Temp_Rsrc_Transl values ('WebSphereASV5J2CFactory','IZY_WAS_J2C_FACT');

insert into AMX.Resource_Transl(Resource, CompTyp_Cd) 
select 
t.Resource  ,
t.CompTyp_Cd  
from 
 IZY.Temp_Rsrc_Transl t
where not exists
( select 1 from
  AMX.Resource_Transl m
  where
  t.CompTyp_Cd = m.CompTyp_Cd 
-- t.resource = m.resource 
  )
; 

drop table IZY.Temp_Rsrc_Transl;

--------------------------------------------------
-- Need a translation table if the property 
-- can have more than 17 characters 
-- Need to know which properties are key properties
-- Need to know which properties will be used for the Comp_Nm
--------------------------------------------------
DELETE FROM AMX.CompTyp_Transl 
   WHERE MSrc_Cd ='IZY' AND ITM_Key_Property = 'WebSphereASRemoteNode.Name'AND CompTyp_Cd = 'IZY_NODE_RMT'
      AND Comp_Format_Nm = 'WebSphereASRemoteNode.Name';

DELETE FROM AMX.CompTyp_Transl 
   WHERE MSrc_Cd = 'IZY' AND ITM_Key_Property='WebSphereASNode.Name' AND CompTyp_Cd = 'IZY_NODE';

DELETE FROM  AMX.CompTyp_Transl ct
   WHERE MSrc_Cd = 'IZY' AND ITM_Key_Property='WebSphereASNodeAgent.Name' AND CompTyp_Cd = 'IZY_NODE_AGENT';

DELETE FROM  AMX.CompTyp_Transl ct
   WHERE MSrc_Cd = 'IZY' AND ITM_Key_Property='WebSphereASDynamicCache.Name' AND CompTyp_Cd = 'IZY_DYNA_CACHE';
DELETE FROM  AMX.CompTyp_Transl ct
   WHERE MSrc_Cd = 'IZY' AND ITM_Key_Property='WebSphereASJ2CPool.Name' AND CompTyp_Cd = 'IZY_J2C_CONPOOL';
DELETE FROM  AMX.CompTyp_Transl ct
   WHERE MSrc_Cd = 'IZY' AND ITM_Key_Property='WebSphereASV5J2CFactory.Name' AND CompTyp_Cd = 'IZY_J2C_CONFACT';


CREATE table IZY.Temp_CmpTp_Transl (
MSrc_Cd			char(3) not null,
ITM_Key_Property	varchar(1096) not null,
CompTyp_Cd		varchar(17) not null,
Comp_Format_Nm	varchar(254) not null
)
;

insert into IZY.temp_CmpTp_Transl values ('IZY','WebSphereASJ2EECell.Name','J2EE_CELL','WebSphereASJ2EECell.Name');
insert into IZY.temp_CmpTp_Transl values ('IZY','WebSphereASJ2EENode.Name','J2EE_NODE','WebSphereASJ2EENode.Name');
insert into IZY.temp_CmpTp_Transl values ('IZY','WebSphereASJ2EEServer.Name','J2EE_SERVER','WebSphereASJ2EEServer.Name');
insert into IZY.temp_CmpTp_Transl values ('IZY','WebSphereASV5NodeAgent.Name','WAS_NODE_AGENT','WebSphereASV5NodeAgent.Name');

insert into IZY.temp_CmpTp_Transl values ('IZY','WebSphereASV5DataSource.Name','IZY_WAS_DATA_SRC','WebSphereASV5DataSource.Name');
insert into IZY.temp_CmpTp_Transl values ('IZY','WebSphereASV5ConnectionPool.Name','IZY_WAS_CONN_PL','WebSphereASV5ConnectionPool.Name');
insert into IZY.temp_CmpTp_Transl values ('IZY','WebSphereASV5EJB.Name','IZY_WAS_EJB','WebSphereASV5EJB.Name');
insert into IZY.temp_CmpTp_Transl values ('IZY','WebSphereASV5JVMRuntime.Name','IZY_WAS_JVM','WebSphereASV5JVMRuntime.Name');
insert into IZY.temp_CmpTp_Transl values ('IZY','WebSphereASV5ServletSession.Name','IZY_WAS_SVLT_SESS','WebSphereASV5ServletSession.Name');
insert into IZY.temp_CmpTp_Transl values ('IZY','WebSphereASV5ThreadPool.Name','IZY_WAS_THREAD_PL','WebSphereASV5ThreadPool.Name');
insert into IZY.temp_CmpTp_Transl values ('IZY','WebSphereASV5Transaction.Name','IZY_WAS_TRANS_MGR','WebSphereASV5Transaction.Name');
insert into IZY.temp_CmpTp_Transl values ('IZY','WebSphereASV5WebApplication.Name','IZY_WAS_WEB_APPL','WebSphereASV5WebApplication.Name');
insert into IZY.temp_CmpTp_Transl values ('IZY','WebSphereASV5Servlet.Name','IZY_WAS_SERVLET','WebSphereASV5Servlet.Name');

insert into IZY.Temp_CmpTp_Transl values ('IZY','WebSphereASV5DynamicCache.Name','IZY_WAS_DYNACACHE','WebSphereASV5DynamicCache.Name');
insert into IZY.Temp_CmpTp_Transl values ('IZY','WebSphereASV5J2CPool.Name','IZY_WAS_J2C_POOL','WebSphereASV5J2CPool.Name');
insert into IZY.Temp_CmpTp_Transl values ('IZY','WebSphereASV5J2CFactory.Name','IZY_WAS_J2C_FACT','WebSphereASV5J2CFactory.Name');

insert into AMX.Comptyp_Transl (MSrc_Cd, ITM_Key_Property, CompTyp_Cd,Comp_Format_Nm)
select 
t.MSrc_Cd  ,
t.ITM_key_property ,
t.CompTyp_Cd  ,
t.Comp_Format_Nm  
from 
 IZY.Temp_CmpTp_Transl t
where not exists
( select 1 from
  AMX.Comptyp_Transl m
  where
  t.MSrc_Cd = m.MSrc_Cd and
 -- t.ITM_key_property  = m.ITM_key_property 
  t.CompTyp_Cd  = m.CompTyp_Cd 
  )
; 

drop table IZY.Temp_CmpTp_Transl;

CREATE table IZY.Tmp_CmpT_Trnsl_Cm (
MSrc_Cd			char(3) not null,
CompTyp_Cd		varchar(17) not null,
Common_MSrc_Cd	char(6) not NULL
)
;

insert into IZY.Tmp_CmpT_Trnsl_Cm values ('IZY','J2EE_CELL','MODEL1');
insert into IZY.Tmp_CmpT_Trnsl_Cm values ('IZY','J2EE_NODE','MODEL1');
insert into IZY.Tmp_CmpT_Trnsl_Cm values ('IZY','J2EE_SERVER','MODEL1');
insert into IZY.Tmp_CmpT_Trnsl_Cm values ('IZY','WAS_NODE_AGENT','MODEL1');

insert into AMX.Comptyp_Transl_Common (MSrc_Cd, CompTyp_Cd,Common_MSrc_cd)
select 
t.MSrc_Cd  ,
t.CompTyp_Cd  ,
t.Common_MSrc_Cd  
from 
 IZY.Tmp_CmpT_Trnsl_Cm t
where not exists
( select 1 from
  AMX.Comptyp_Transl_Common m
  where
  t.MSrc_Cd = m.MSrc_Cd and
  t.CompTyp_Cd  = m.CompTyp_Cd 
  )
; 

drop table IZY.Tmp_CmpT_Trnsl_Cm;

--------------------------------------------------
-- Need a translation table if the property 
-- can have more than 17 characters
----------------------------------------------

DELETE FROM AMX.AttrTyp_Transl 
   WHERE MSrc_Cd = 'IZY' AND ITM_Attr_Property = 'WebSphereASNode.WasVersion' AND AttrTyp_Cd = 'VERSION';
DELETE FROM AMX.AttrTyp_Transl 
   WHERE MSrc_Cd = 'IZY' AND ITM_Attr_Property = 'WebSphereASNode.OSType' AND AttrTyp_Cd = 'OS_NAME';
DELETE FROM AMX.AttrTyp_Transl 
   WHERE MSrc_Cd = 'IZY' AND ITM_Attr_Property = 'WebSphereASNode.CellName' AND AttrTyp_Cd = 'J2EE_CELL';
DELETE FROM AMX.AttrTyp_Transl 
   WHERE MSrc_Cd = 'IZY' AND ITM_Attr_Property = 'WebSphereASNode.PolicyRegion' AND AttrTyp_Cd = 'TME_POLICY_REGION';
DELETE FROM AMX.AttrTyp_Transl 
   WHERE MSrc_Cd = 'IZY' AND ITM_Attr_Property = 'WebSphereASApplicationServer.ClusterName' AND AttrTyp_Cd = 'IZY_CLUSTER';

DELETE FROM AMX.AttrTyp_Transl 
   WHERE MSrc_Cd ='IZY' AND ITM_Attr_Property ='WebSphereASRemoteNode.IZY_HOST' AND AttrTyp_Cd ='IZY_HOST';
DELETE FROM AMX.AttrTyp_Transl 
   WHERE MSrc_Cd ='IZY' AND ITM_Attr_Property = 'WebSphereASRemoteNode.LAST_IP_ADDRESS'AND AttrTyp_Cd ='LAST_IP_ADDRESS';
DELETE FROM AMX.AttrTyp_Transl 
   WHERE MSrc_Cd ='IZY' AND ITM_Attr_Property = 'WebSphereASRemoteNode.WasVersion' AND AttrTyp_Cd ='VERSION';
DELETE FROM AMX.AttrTyp_Transl 
   WHERE MSrc_Cd ='IZY' AND ITM_Attr_Property ='WebSphereASRemoteNode.OSType' AND AttrTyp_Cd ='OS_NAME';
DELETE FROM AMX.AttrTyp_Transl 
   WHERE MSrc_Cd ='IZY' AND ITM_Attr_Property = 'WebSphereASRemoteNode.CellName' AND AttrTyp_Cd ='J2EE_CELL';
DELETE FROM AMX.AttrTyp_Transl 
   WHERE MSrc_Cd ='IZY' AND ITM_Attr_Property = 'WebSphereASRemoteNode.PolicyRegion' AND AttrTyp_Cd ='TME_POLICY_REGION';

CREATE table IZY.Temp_AtrTp_Transl (
MSrc_Cd			char(3) not null,
ITM_Attr_Property	varchar(254) not null,
AttrTyp_Cd		varchar(17) not null
)
;

insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASV5NodeAgent.Manufacturer','MANUFACTURER');
insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASV5NodeAgent.WasVersion','VERSION');

insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASJ2EEServer.Manufacturer','MANUFACTURER');    
insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASJ2EEServer.Version','VERSION');

insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASJ2EENode.OSType','OS_NAME');
insert into IZY.Temp_AtrTp_Transl values ('IZY','WebSphereASJ2EEServer.ClusterName','WAS_CLUSTER');

                                                    
insert into AMX.Attrtyp_Transl (MSrc_Cd, ITM_Attr_Property, AttrTyp_Cd)
select 
t.MSrc_Cd  ,
t.ITM_Attr_Property  ,
t.AttrTyp_Cd 
from 
 IZY.Temp_AtrTp_Transl t
where not exists
( select 1 from
  AMX.Attrtyp_Transl m
  where
  t.MSrc_Cd = m.MSrc_Cd and
  t.ITM_Attr_Property  = m.ITM_Attr_Property 
  AND T.AttrTyp_Cd  = m.AttrTyp_Cd  
  )
; 

DROP table IZY.Temp_AtrTp_Transl;

------------------------------------------------------------------------------------------------
-- Insert data to define relation rules for remote (390) WebSphere Application Server components
----------------------------------------------------------------------------------------------- 
DELETE FROM AMX.relnrul_Transl WHERE CompTyp_Source_Cd='IZY_NODE' AND CompTyp_Target_Cd='IZY_NODE_RMT' AND RelnTyp_Cd='PROXY';
DELETE FROM AMX.relnrul_Transl WHERE CompTyp_Source_Cd='IZY_NODE_RMT' AND CompTyp_Target_Cd='IZY_APPL_SVR_RMT' AND RelnTyp_Cd= 'PCHILD';

-- create temporary table for relation rule translation values
CREATE  TABLE IZY.temp_RlnRl_Transl (
   CompTyp_Source_Cd 	   VARCHAR(17) NOT NULL,
   CompTyp_Target_Cd 	   VARCHAR(17) NOT NULL,
   RelnTyp_Cd              CHAR(6) NOT NULL,
   RelnRul_Strt_DtTm    	Timestamp NOT NULL,
   RelnRul_End_DtTm        Timestamp NOT NULL
	)
;
  

-- Readd  relationship of rempote AdminServer parent to Appl Server which was removed in fp v1102
INSERT INTO IZY.temp_RlnRl_Transl VALUES ('IZY_ADMIN_SVR_RMT', 'IZY_APPL_SVR_RMT', 'PCHILD', current timestamp - current timezone, '9999-01-01-12.00.00.000000');


INSERT INTO AMX.RelnRul_Transl (CompTyp_Source_Cd, CompTyp_Target_Cd, RelnTyp_Cd, 
                                RelnRul_Strt_DtTm, RelnRul_End_DtTm)
SELECT 
   t.CompTyp_Source_Cd,
   t.CompTyp_Target_Cd,
   t.RelnTyp_Cd,
   t.RelnRul_Strt_DtTm,
   t.RelnRul_End_DtTm
FROM 
   IZY.temp_RlnRl_Transl t
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  AMX.RelnRul_Transl r
  WHERE
  t.CompTyp_Source_Cd = r.CompTyp_Source_Cd AND
  t.CompTyp_Target_Cd = r.CompTyp_Target_Cd AND
  t.RelnTyp_Cd = r.RelnTyp_Cd 
);

DROP table IZY.Temp_RlnRl_Transl;




-----------------------------------------------
-- insert the dimension: WebSphere metric info
-- for the new  WebSphere 5.0 components
-----------------------------------------------

CREATE  table IZY.temp_min_exists (
 msmttyp_id	integer,
 min_exists     char(1)
)
; 
 
insert into IZY.temp_min_exists
select
 mb.msmttyp_id,
 'Y' as min_exists
from
 TWG.MgrpMbr mb,
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MIN_E' AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'
;


create table IZY.temp_max_exists (
 msmttyp_id	integer,
 max_exists     char(1)
)
; 
 
insert into IZY.temp_max_exists
select
 mb.msmttyp_id,
 'Y' as max_exists
from
 TWG.MgrpMbr mb ,
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='MAX_E' AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'
;                  


CREATE table IZY.temp_avg_exists (
 msmttyp_id	integer,
 avg_exists     char(1)
)
; 
 
insert into izy.temp_avg_exists
select
 mb.msmttyp_id,
 'Y' as avg_exists
from
 TWG.MgrpMbr mb ,
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='AVG_E'    AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'
;

-- select count(*) from izy.temp_avg_exists;

CREATE table izy.temp_tot_exists (
 msmttyp_id	integer,
 tot_exists     char(1)
)
; 
 
insert into izy.temp_tot_exists
select
 mb.msmttyp_id,
 'Y' as tot_exists
from
 TWG.MgrpMbr mb, 
 TWG.MsmtTyp mt
where
 mb.mgrptyp_cd = 'GROUP' and
 mb.mgrp_cd='TOT_E'AND
 mb.msmtTyp_Id = mt.MsmtTyp_Id AND
 mt.MSrc_Cd = 'IZY'

;                  

-- Insert measurements with WebSphere specific measurement groups,
-- using Measurement Group table MGrp_Nm as the category (for met_Category) 

CREATE  table IZY.temp_category (
 msmttyp_id	integer,
 category     varchar(120)
)
; 
 
insert into izy.temp_category
select
 mb.msmttyp_id,
 mg.mgrp_nm as category
from
 TWG.MgrpMbr mb,
 TWG.Mgrp mg
where
 mb.mgrptyp_cd = 'STATE' and
 mb.mgrp_cd='IZY_ST' and
 mb.mgrp_cd = mg.mgrp_cd
;


drop table IZY.STAGE_D_WAS_METRIC;

create table IZY.STAGE_D_WAS_METRIC (
 insert_dttm		timestamp,
 Metric_ID            integer not null,
 Met_Category         VARCHAR(254) NOT NULL,
 Met_Desc          VARCHAR(254) NOT NULL,
 Met_Name          VARCHAR(120) NOT NULL,
 Met_Units         CHAR(6) NOT NULL,
 MIN_Exists           CHARACTER NOT NULL,
 MAX_Exists           CHARACTER NOT NULL,
 AVG_Exists           CHARACTER NOT NULL,
 Total_Exists         CHARACTER NOT NULL,
 Msrc_Nm				 VARCHAR(50) NOT NULL,
       PRIMARY KEY (Metric_ID)
);


insert  into IZY.STAGE_D_WAS_METRIC
select
-- @D3C add 'current timezone'
 current timestamp - current timezone as insert_dttm,
 mt.msmttyp_id as metric_id,
 value(cat.category,'not used') as Met_Category,
 mt.msmttyp_ds as met_desc,
 mt.msmttyp_nm as met_name,
 mt.munit_cd as met_units,
 value(min.min_exists,'N') as min_exists,
 value(max.max_exists,'N') as max_exists,
 value(avg.avg_exists,'N') as avg_exists,
 value(tot.tot_exists,'N') as total_exists,
 'IZY' as msrc_nm
from
 TWG.msmttyp mt left outer join izy.temp_min_exists min
 on mt.msmttyp_id=min.msmttyp_id,
 TWG.msmttyp mt2 left outer join izy.temp_max_exists max
 on mt2.msmttyp_id=max.msmttyp_id,
 TWG.msmttyp mt3 left outer join izy.temp_avg_exists avg
 on mt3.msmttyp_id=avg.msmttyp_id,
 TWG.msmttyp mt4 left outer join izy.temp_tot_exists tot
 on mt4.msmttyp_id=tot.msmttyp_id,
 TWG.msmttyp mt5 left outer join izy.temp_category cat
 on mt5.msmttyp_id=cat.msmttyp_id,
 TWG.MsmtRul mr
where
 mt.msmttyp_id = mr.msmttyp_id and 
 mr.comptyp_cd in ('IZY_ADMIN_SERVER','IZY_APPL_SERVER','IZY_DATA_SOURCE','IZY_CONNECT_POOL',
                   'IZY_EJB','IZY_JVM','IZY_SERVLET_SESS','IZY_TRANSACT_MGR',
                   'IZY_THREAD_POOL','IZY_WEB_APPL','IZY_SERVLET',
                   'J2EE_SERVER','IZY_WAS_CONN_PL',
                   'IZY_WAS_EJB','IZY_WAS_JVM','IZY_WAS_SVLT_SESS','IZY_WAS_TRANS_MGR',
                   'IZY_WAS_THREAD_PL','IZY_WAS_WEB_APPL','IZY_WAS_SERVLET',
                   'WAS_NODE_AGENT','IZY_WAS_DYNACACHE', 'IZY_WAS_J2C_POOL'
                         ) and
 mt.MSrc_Cd = 'IZY' and
 mt.msmttyp_id = mt2.msmttyp_id and
 mt.msmttyp_id = mt3.msmttyp_id and
 mt.msmttyp_id = mt4.msmttyp_id and
 mt.msmttyp_id = mt5.msmttyp_id
group by
 mt.msmttyp_id, mt.msmttyp_nm, mt.msmttyp_ds, mt.munit_cd, 
 min_exists, avg_exists, tot_exists, max_exists,cat.category
;


drop table IZY.temp_category;
DROP table izy.temp_tot_exists;
DROP table IZY.temp_avg_exists;
DROP table IZY.temp_min_exists;
DROP table IZY.temp_max_exists;


------------------------------------------------------------------------------------------------
-- Insert new extract_control statements for each new SubCmp staging table
----------------------------------------------------------------------------------------------- 
CREATE table IZY.Temp_Ext_Ctl (
   ExtCtl_Source   	varchar(120) not null,
 	ExtCtl_Target   	varchar(120) not null,
 	ExtCtl_From_RawSeq      char(10) for bit data,
 	ExtCtl_To_RawSeq        char(10) for bit data,
 	ExtCtl_From_IntSeq      bigint,
 	ExtCtl_To_IntSeq        bigint,
 	ExtCtl_From_DtTm     	timestamp not null,
 	ExtCtl_To_DtTm       	timestamp not null
	)
;

-----------------------------------------------
-- From TWG.MSMT to the Mart Fact tables
-----------------------------------------------
insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SBCMP_HOUR1' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.STAGE_F_SBCMP_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SBCMP_HOUR2' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.STAGE_F_SBCMP_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SBCMP_HOUR3' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.STAGE_F_SBCMP_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SBCMP_HOUR4' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.STAGE_F_SBCMP_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SBCMP_HOUR5' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.STAGE_F_SBCMP_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SBCMP_HOUR6' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.STAGE_F_SBCMP_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SBCMP_HOUR7' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.STAGE_F_SBCMP_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SBCMP_HOUR8' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.STAGE_F_SBCMP_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SBCMP_HOUR9' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.STAGE_F_SBCMP_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SBCMP_HOUR10' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.STAGE_F_SBCMP_HOUR'
;
 
insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SBCMP_HOUR11' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.STAGE_F_SBCMP_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SBCMP_HOUR12' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.STAGE_F_SBCMP_HOUR'
;                  
                                                         
insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SC5_HOUR1' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.F_SBCP5_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SC5_HOUR2' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.F_SBCP5_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SC5_HOUR3' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.F_SBCP5_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SC5_HOUR4' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.F_SBCP5_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SC5_HOUR5' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.F_SBCP5_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SC5_HOUR6' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.F_SBCP5_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SC5_HOUR7' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.F_SBCP5_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SC5_HOUR8' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.F_SBCP5_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SC5_HOUR9' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.F_SBCP5_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SC5_HOUR10' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.F_SBCP5_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SC5_HOUR11' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.F_SBCP5_HOUR'
;

insert into IZY.temp_Ext_Ctl (ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
    ec.ExtCtl_Source ,
    'IZY.STAGE_F_SC5_HOUR12' ,
    ec.ExtCtl_From_RawSeq,
    ec.ExtCtl_To_RawSeq,
    ec.ExtCtl_From_IntSeq,
    ec.ExtCtl_To_IntSeq,
    ec.ExtCtl_From_DtTm,
    ec.ExtCtl_To_DtTm
   from TWG.Extract_Control ec 
   where ec.extctl_target='IZY.F_SBCP5_HOUR'
;

insert into TWG.Extract_control(ExtCtl_Source, ExtCtl_Target,ExtCtl_From_RawSeq, ExtCtl_To_RawSeq, ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm )
select 
 m.ExtCtl_Source  ,
 m.ExtCtl_Target  ,
 m.ExtCtl_From_RawSeq  ,
 m.ExtCtl_To_RawSeq  ,
 m.ExtCtl_From_IntSeq  ,
 m.ExtCtl_To_IntSeq  ,
 m.ExtCtl_From_DtTm  ,
 m.ExtCtl_To_DtTm    
from 
 IZY.temp_Ext_Ctl m
where not exists
( select 1 from
  TWG.Extract_Control t
  where
  t.ExtCtl_Source=m.ExtCtl_Source  and
  t.ExtCtl_Target=m.ExtCtl_Target
  )
;                  

DROP table IZY.Temp_Ext_Ctl;

--#endtag fixpack_3
