-- ==========================================================================
-- Licensed Materials - Property of IBM
-- "Restricted Materials of IBM"
--
-- 5724-C01
-- 5698-WAZ
--
-- (C) COPYRIGHT IBM CORP. 2002, 2004. ALL RIGHTS RESERVED.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- ==========================================================================
--
-- File Information: wsappsvr/src/tedw_apps_etl/fixpack_v1103/izy/etl/sql/izy_m05_s010_dimension.db2, waspac, waspac_512, 200403221252
-- 
-- Revision: 1.6
-- 
-- Date: 3/22/04 11:56:01
-- 
-- Description: IBM Tivoli Monitoring  for WebSphere file for moving data 
--              from the Central Data Warehouse tables in TWH_CDW to the  
--              metric dimension tables in the data mart (TWH_Mart).                             
-- ==========================================================================
--  Change Activity:
--  $F0 107152 12/09/02  lmd  Add support for WAS z/OS: migrate to common 
--                             standard attributes 
--  $D0 115192 06/05/03  lmd  Add support for WAS 5.0
--  $D1 120827 09/23/03  lmd  Change extract control comparison for cells
--  $D2 118844 09/26/03  lmd  Performance enhancements
--  $D3 IY51267 12/17/03  lmd  Change WAS 4.0 modeling back to prior to 5.1.2
--                             and WAS 5.0 modeling to common data model
--  ==========================================================================
-- 
---------------------------------
-- insert the metric dimension
------------------------------
-- get the high value for the window

update TWG.Extract_Control ec set 
 ec.extctl_to_intseq =  ( select max(metric_id) from IZY.STAGE_D_WAS_METRIC)
where 
 ec.extctl_source='IZY.STAGE_D_WAS_METRIC' and
 ec.extctl_target='IZY.D_WAS_METRIC' and
-- @D2C Change to exists test with true test query on extract_control.extctl_to_intseq stops of all rows
 exists (select 1 from IZY.STAGE_D_WAS_METRIC where ec.extctl_to_intseq = ec.extctl_to_intseq) 
;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_D_MRT_METRIC;

-- Staging table for Data mart cross DB transfers 
--#EXECUTE_AT_TARGET
create table IZY.STAGE_D_MRT_METRIC (
 Metric_ID            INTEGER NOT NULL,
 Met_Category         VARCHAR(254) NOT NULL,
 Met_Desc				 VARCHAR(254) NOT NULL,
 Met_Name             VARCHAR(120) NOT NULL,
 Met_Units            CHAR(6) NOT NULL,
 MIN_Exists           CHARACTER NOT NULL,
 MAX_Exists           CHARACTER NOT NULL,
 AVG_Exists           CHARACTER NOT NULL,
 Total_Exists         CHARACTER NOT NULL,
 Msrc_Nm					 VARCHAR(120) NOT NULL,
       PRIMARY KEY (Metric_ID)
);


-- Insert new metric data from staging table into the data mart table
--#INSERT_INTO_TARGET
insert into IZY.STAGE_D_MRT_METRIC
select 
 d.metric_id as metric_id, 
 d.met_category as met_category,
 d.met_desc as met_desc,
 d.met_name as met_name,
 d.met_units as met_units,
 d.min_exists as min_exists,
 d.max_exists as max_exists,
 d.avg_exists as avg_exists,
 d.total_exists as total_exists,
 d.msrc_nm as msrc_nm
from
 IZY.STAGE_D_WAS_METRIC d,
 TWG.Extract_Control ec
where
 ec.extctl_source = 'IZY.STAGE_D_WAS_METRIC' and
 ec.extctl_target = 'IZY.D_WAS_METRIC' and
 d.metric_id > ec.extctl_from_intseq and
 d.metric_id <= ec.extctl_to_intseq 
;


-- copy WebSphere measurements from staging table into Mart metric table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_METRIC
select * from IZY.STAGE_D_MRT_METRIC s
where not exists
( select 1 from
  IZY.D_WAS_METRIC d
  where
  d.metric_id = s.metric_id
);                                
;                                

-- confirm that the insertion of 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log 
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source  ,
 ec.extctl_target  ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq  ,
 ec.extctl_to_rawseq  ,
 ec.extctl_from_intseq  ,
 ec.extctl_to_intseq  ,
 ec.extctl_from_dttm  ,
 ec.extctl_to_dttm  
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'IZY.STAGE_D_WAS_METRIC' and
 ec.extctl_target = 'IZY.D_WAS_METRIC'
; 

-----------------------------------------------
--  insert the dimension: Hosts 
-----------------------------------------------

-- get the high value for the window
-- cr1.comp_source_id = host of IZY_ADMIN_SERVER
-- @D0C added comp_source_id = host of IZY_NODE
-- @D3C removed comp_source_id = host of IZY_NODE -> back to IZY_ADMIN_SERVER.
update TWG.Extract_Control ec set 
 ec.extctl_to_intseq =  
   (select max(cr1.comp_source_id) 
        from twg.Cur_comp co1, 
             TWG.Cur_CompReln cr1
        where 
           co1.comptyp_cd = 'IZY_ADMIN_SERVER' and
           co1.comp_id = cr1.comp_target_id and
           cr1.relntyp_cd='PCHILD'
    )
where 
 ec.extctl_source='TWG.COMP' and
 ec.extctl_target='IZY.D_WAS_HOST' and
-- @D2C Change to exists test with true test query on extract_control.extctl_to_intseq stops of all rows
 exists (select 1 from twg.Cur_comp co1, TWG.Cur_CompReln cr1
                                where ec.extctl_to_intseq = ec.extctl_to_intseq and
                                      co1.comptyp_cd = 'IZY_ADMIN_SERVER' and
                                      co1.comp_id = cr1.comp_target_id and
                                      cr1.relntyp_cd='PCHILD') 
;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_D_HOST;

-- WebSphere Host dimension table   
--#EXECUTE_AT_TARGET
create table IZY.STAGE_D_HOST(
 host_id     		integer not null,
 host_name    		varchar(254) not null,
 cust_nm		varchar(120) not null,
 centr_nm  		varchar(120) not NULL,
      primary key (host_id)
);


--#INSERT_INTO_TARGET
-- @D0C Added WAS 5.0 Node
-- @D3C Removed IZY_NODE - host table not needed for WAS v5
insert into IZY.STAGE_D_HOST
-- @D2C Removed group by -> select distinct
select distinct 
 cr1.comp_source_id as host_id,
 co2.comp_nm as host_name,
 cu1.cust_nm as cust_nm,
 ce1.centr_nm as centr_nm
from
 TWG.Cur_Comp co1,
 TWG.Cur_Comp co2,
 TWG.Cur_CompReln cr1,
 TWG.Cust cu1,
 TWG.Centr ce1,
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_HOST' and
 cr1.comp_source_id > ec.extctl_from_intseq and
 cr1.comp_source_id <= ec.extctl_to_intseq and
 co1.comptyp_cd = 'IZY_ADMIN_SERVER' and
 co1.comp_id = cr1.comp_target_id and
 cr1.relntyp_cd='PCHILD' and 
 cr1.comp_source_id = co2.comp_id and
 co2.cust_id = cu1.cust_id and
 co2.centr_cd = ce1.centr_cd 
;


-- copy WebSphere host components from staging table into Mart host table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_HOST
select * from IZY.STAGE_D_HOST s
where not exists
( select 1 from
  IZY.D_WAS_HOST d
  where
  d.host_id=s.host_id)
;                                


-- confirm that the insertion of 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_HOST'
; 

-------------------------------------------------------------------------------------
-- D3C insert the dimension: WebSphere AdminServer 3.5 or 4.0 Nodes
-------------------------------------------------------------------------------------

-- get the high value for the window
update TWG.Extract_Control ec set 
 ec.extctl_to_intseq =  ( select max(ca.compattr_id) from twg.Cur_comp co1, twg.Cur_compattr ca
    where 
        co1.comptyp_cd = 'IZY_ADMIN_SERVER' and
        co1.comp_id = ca.comp_id and
-- @F0C added common TWH attributes which we are now using. Support existing data and new data.
        ca.attrtyp_cd in ('IZY_WAS_VERSION', 'IZY_POLICY_REGION', 'IZY_OS_TYPE', 
                          'VERSION', 'TME_POLICY_REGION', 'OS_NAME') )
where 
 ec.extctl_source='TWG.COMP' and
 ec.extctl_target='IZY.D_WAS_ADMINSRV' and
-- @D2C Change to exists test with true test query on extract_control.extctl_to_intseq stops of all rows
 exists (select 1 from twg.Cur_comp co1, twg.Cur_compattr ca 
 where 
  ec.extctl_to_intseq = ec.extctl_to_intseq and
  co1.comptyp_cd = 'IZY_ADMIN_SERVER' and
  co1.comp_id = ca.comp_id and
-- @F0C added common TWH attributes which we are now using. Support existing data and new data.
-- @D0 Only need to care about attributes that can change - don't need J2EE_CELL
  ca.attrtyp_cd in ('IZY_WAS_VERSION', 'IZY_POLICY_REGION','IZY_OS_TYPE',
                    'VERSION', 'TME_POLICY_REGION', 'OS_NAME') ) 
;


-- Temporary staging table for WebSphere AdminServer components and attributes
--#IGNORE_ERROR
drop table IZY.STAGE_ADMIN_ATTR;

-- create temporary table in CDW 
create table IZY.STAGE_ADMIN_ATTR (
 comp_id    integer not null,
 comp_name  varchar(254) not null, 
 compattr_strt_dttm		timestamp not null,
 primary key (comp_id, compattr_strt_dttm )
);

-- WebSphere AdminServer dimension table
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_D_ADMINSRV;

--#EXECUTE_AT_TARGET
create table IZY.STAGE_D_ADMINSRV (
 AdminSrv_Comp_ID    integer not null,
 AdminSrv_Comp_Name  varchar(254) not null, 
 XQ_AdminSrv_dttm		timestamp not null,
 AdminSrv_OS_Type       	varchar(254) not null,
 AdminSrv_WAS_Ver    	varchar(254) not null,
 AdminSrv_PolicyReg     varchar(254) not null,
 primary key (AdminSrv_Comp_ID,XQ_AdminSrv_dttm )
);


-- Get new WebSphere Administration server components or components whose attributes 
-- have changed which implies a new component in the dimension table
insert into IZY.STAGE_ADMIN_ATTR
select 
 co1.comp_id as comp_id,
 co1.comp_nm as comp_nm,               
 max(ca.compattr_strt_dttm) as compattr_strt_dttm
from  
 TWG.Cur_Comp co1,
 TWG.Cur_CompAttr ca,  
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_ADMINSRV' and
 ca.compattr_id > ec.extctl_from_intseq and
 ca.compattr_id <= ec.extctl_to_intseq and
 co1.comptyp_cd = 'IZY_ADMIN_SERVER' and
-- @D3D4 removed WAS IZY_NODE 
 ca.comp_id=co1.comp_id and  
-- @F0C added common TWH attributes which we are now using. Support existing data and new data.
 ca.attrtyp_cd in ('IZY_OS_TYPE','IZY_WAS_VERSION','IZY_POLICY_REGION',
                          'OS_NAME','VERSION','TME_POLICY_REGION')
group by
 co1.comp_id, co1.comp_nm
; 

--#INSERT_INTO_TARGET
insert into IZY.STAGE_D_ADMINSRV
-- @D2C Removed group by -> select distinct
select distinct
 s.comp_id as ADMINSRV_COMP_ID,
 s.comp_name as ADMINSRV_COMP_NAME, 
 s.compattr_strt_dttm as XQ_AdminSrv_dttm,
 ca1.compattr_val as ADMINSRV_OS_TYPE,
 ca2.compattr_val as AdminSrv_WAS_VER,
 ca3.compattr_val as AdminSrv_PolicyReg 
from
 IZY.STAGE_ADMIN_ATTR s,
 TWG.Cur_CompAttr ca1,  
 TWG.Cur_CompAttr ca2,  
 TWG.Cur_CompAttr ca3   
where
 s.comp_id=ca1.comp_id and  
-- @F0C added common TWH attributes which we are now using. Support existing data and new data.
 ca1.attrtyp_cd in ('IZY_OS_TYPE','OS_NAME')  and  
 ca2.comp_id=s.comp_id and  
 ca2.attrtyp_cd in ('IZY_WAS_VERSION','VERSION') and
 ca3.comp_id=s.comp_id and  
 ca3.attrtyp_cd in ('IZY_POLICY_REGION','TME_POLICY_REGION') 
;

-- copy WebSphere administration server component from staging table into Mart dimension table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_ADMINSRV
select * from IZY.STAGE_D_ADMINSRV s
where not exists
( select 1 from
  IZY.D_WAS_ADMINSRV d
  where
  d.AdminSrv_Comp_ID = s.AdminSrv_Comp_id and
  d.XQ_AdminSrv_dttm = s.XQ_AdminSrv_dttm
);                                

-- confirm that the insertion of 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_ADMINSRV'
; 

-- @D0 Start: Add mart dimension tables for WebSphere 5.0.x 
-----------------------------------------------
--  insert the CELL dimension information
-----------------------------------------------
-- @D3C Change for J2EE_CELL attribute to component
-- get the high value for the window
update TWG.Extract_Control ec set                
 ec.extctl_to_intseq =  ( select max(co1.comp_id) from twg.Cur_comp co1
    where 
        co1.comptyp_cd = 'J2EE_CELL')
where 
 ec.extctl_source='TWG.COMP' and
 ec.extctl_target='IZY.D_WAS_CELL' and
-- @D2C Change to exists test with true test query on extract_control.extctl_to_intseq stops of all rows
 exists (select 1 from twg.Cur_comp co1
 where 
  ec.extctl_to_intseq = ec.extctl_to_intseq and
  co1.comptyp_cd = 'J2EE_CELL')  
;                      

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_D_CELL;

-- WebSphere Host dimension table   
--#EXECUTE_AT_TARGET
create table IZY.STAGE_D_CELL(
 cell_id          integer not null,
 cell_val         varchar(254) not null,
 primary key (cell_id)
);


--#INSERT_INTO_TARGET
insert into IZY.STAGE_D_CELL
-- @D2C Removed group by -> select distinct
select distinct
 co1.comp_id as cell_id,
 co1.comp_Nm as cell_Val
from
 TWG.Cur_Comp co1,
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_CELL' and
 co1.comp_id > ec.extctl_from_intseq and
 co1.comp_id <= ec.extctl_to_intseq and
 co1.comptyp_cd = 'J2EE_CELL'  
;                

-- copy WebSphere host components from staging table into Mart host table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_CELL
select * from IZY.STAGE_D_CELL s
where not exists
( select 1 from
  IZY.D_WAS_CELL d
  where
  d.cell_attr_id = s.cell_id)
;                                


-- confirm that the insertion of 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_CELL'
; 

----------------------------------------------------
--  insert the NODE dimension information - WAS 5.0 
----------------------------------------------------

-- get the high value for the window
-- @D3C Changed IZY_NODE to J2EE_NODE with only 1 attribute 
update TWG.Extract_Control ec set 
 ec.extctl_to_intseq =  ( select max(ca.compattr_id) from twg.Cur_comp co1, twg.Cur_compattr ca
                            where 
                             co1.comptyp_cd in ('J2EE_NODE','J2EE_SERVER','WAS_NODE_AGENT') 
                             and co1.comp_id = ca.comp_id 
                             and ca.attrtyp_cd in ('OS_NAME','VERSION')
                         )
where 
 ec.extctl_source='TWG.COMP' and
 ec.extctl_target='IZY.D_WAS_NODE' and
-- @D2C Change count(*) to exists test with true test query on extract_control.extctl_to_intseq stops of all rows
 exists (select 1 from twg.Cur_comp co1, twg.Cur_compattr ca 
 where 
  ec.extctl_to_intseq = ec.extctl_to_intseq 
  and co1.comptyp_cd in ('J2EE_NODE','J2EE_SERVER','WAS_NODE_AGENT') 
  and co1.comp_id = ca.comp_id 
  and ca.attrtyp_cd in ('OS_NAME','VERSION'))
;


-- Temporary staging table for Node components and attributes
--#IGNORE_ERROR
drop table IZY.STAGE_NODE_ATTR;

-- create temporary table in CDW 
create table IZY.STAGE_NODE_ATTR (
 comp_id                integer not null,
 comp_name              varchar(254) not null, 
 compattr_strt_dttm     timestamp not null,
 primary key (comp_id, compattr_strt_dttm )
);

                                           
-- @D3A Get the latest WAS_NODE_AGENT or J2EE_SERVER VERSION attribute  
--#IGNORE_ERROR
drop table IZY.STAGE_VERS_ATTR;

-- create temporary table in CDW 
create table IZY.STAGE_VERS_ATTR (
 comp_id                integer not null,
 comp_name              varchar(254) not null, 
 compattr_strt_dttm     timestamp not null,
 primary key (comp_id, compattr_strt_dttm )
);
-- @D3A End Get the latest WAS_NODE_AGENT or J2EE_SERVER VERSION attribute  

-- WebSphere Nodes dimension table
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_D_NODE;

--#EXECUTE_AT_TARGET
create table IZY.STAGE_D_NODE (
 Node_Comp_ID           integer not null,
 Node_Comp_Name         varchar(254) not null, 
 XQ_Node_dttm	        timestamp not null,
 Node_Host_Name         varchar(254) not null,
 Node_OS_Type           varchar(254) not null,
 Node_WAS_Ver    	varchar(254) not null,
 centr_nm  		varchar(120) not NULL,
 cust_nm		varchar(120) not null,
 primary key (Node_Comp_ID,XQ_Node_dttm )
);                                

-- Get new WebSphere Node components or components whose attributes 
-- have changed which implies a new component in the dimension table
insert into IZY.STAGE_NODE_ATTR
select 
 co1.comp_id as comp_id,
 co1.comp_nm as comp_nm,               
 max(ca.compattr_strt_dttm) as compattr_strt_dttm
from  
 TWG.Cur_Comp co1,
 TWG.Cur_CompAttr ca,  
 TWG.Cur_CompReln cr1,  
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_NODE' and
 ca.compattr_id > ec.extctl_from_intseq and
 ca.compattr_id <= ec.extctl_to_intseq and
 co1.comptyp_cd = 'J2EE_NODE' and
 co1.comp_id = cr1.comp_source_id and
-- ca.comp_id in (j2ee_node, j2ee_server or node agent)
 ca.comp_id in (co1.comp_id, cr1.comp_target_id) and
-- @D3C OS_NAME (contains os version) and J2EE_SERVER VERSION attr can change. 
 ca.attrtyp_cd in ('OS_NAME','VERSION')
group by
 co1.comp_id, co1.comp_nm
; 

-- @D3A Get the latest WAS_NODE_AGENT or J2EE_SERVER VERSION attribute
insert into IZY.STAGE_VERS_ATTR
select 
 co1.comp_id as comp_id,
 co1.comp_nm as comp_nm,               
 max(ca.compattr_strt_dttm) as compattr_strt_dttm
from  
 TWG.Cur_Comp co1,
 TWG.Cur_Comp co2,
 TWG.Cur_CompAttr ca,  
 TWG.Cur_CompReln cr1,  
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_NODE' and
 ca.compattr_id > ec.extctl_from_intseq and
 ca.compattr_id <= ec.extctl_to_intseq and
 co1.comptyp_cd = 'J2EE_NODE' and
 co1.comp_id = cr1.comp_source_id and
 co2.comp_id in (cr1.comp_target_id)  and
 ca.comp_id = co2.comp_id and
 ca.attrtyp_cd = 'VERSION'
group by
 co1.comp_id, co1.comp_nm
;       
-- @D3A End Get the latest WAS_NODE_AGENT or J2EE_SERVER VERSION attribute

--#INSERT_INTO_TARGET
insert into IZY.STAGE_D_NODE
-- @D2C Removed group by -> select distinct
select distinct 
 s.comp_id as Node_COMP_ID,
 s.comp_name as Node_COMP_NAME, 
 s.compattr_strt_dttm as XQ_Node_dttm,
 co2.comp_Nm as Node_Host_Name,
 ca1.compattr_val as Node_OS_TYPE,
 ca2.compattr_val as Node_WAS_VER,
 cu1.cust_nm as cust_nm,
 ce1.centr_nm as centr_nm
from
 IZY.STAGE_NODE_ATTR s,
 IZY.STAGE_VERS_ATTR va,
 TWG.Cur_Comp co2,
 TWG.Cur_CompReln cr1,
 TWG.Cur_CompReln cr2,
 TWG.Cur_CompAttr ca1,  
 TWG.Cur_CompAttr ca2,
 TWG.Cust cu1,
 TWG.Centr ce1
where
 ca1.comp_id=s.comp_id and  
 ca1.attrtyp_cd = 'OS_NAME'  and  
 s.comp_id = cr1.comp_source_id and
 cr1.relntyp_cd='PCHILD' and 
-- cr1.comp_target_id = J2EE_SERVER or WAS_NODE_AGENT          
-- and need the most recent VERSION value
 cr1.comp_target_id = ca2.comp_id and
 ca2.compattr_strt_dttm = va.compattr_strt_dttm and
 va.comp_id = s.comp_id and
-- cr2.comp_source_id = J2EE_SERVER which target = host
 cr1.comp_target_id = cr2.comp_source_id and
 cr2.relntyp_cd='RUNSON' and
-- cr2.comp_target_id = RUNSON xxx_HOST
 cr2.comp_target_id = co2.comp_id and
 co2.cust_id = cu1.cust_id and
 co2.centr_cd = ce1.centr_cd 
;

-- copy WebSphere 5.0 node components from staging table into Mart dimension table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_NODE
select * from IZY.STAGE_D_NODE s
where not exists
( select 1 from
  IZY.D_WAS_NODE d
  where
  d.Node_Comp_ID = s.Node_Comp_id and
  d.XQ_Node_dttm = s.XQ_Node_dttm
);                                

-- confirm that the insertion of 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_NODE'
; 

--------------------------------------------------------------
--  insert the dimension: Configuration Manager (Node Agents)
--------------------------------------------------------------

-- get the high value for the window
update TWG.Extract_Control ec set 
 ec.extctl_to_intseq =  ( select max(co1.comp_id) from twg.Cur_comp co1 
    where 
        co1.comptyp_cd = 'WAS_NODE_AGENT' )
where 
 ec.extctl_source='TWG.COMP' and
 ec.extctl_target='IZY.D_WAS_CFGMGR' and
-- @D2C Change to exists test with true test query on extract_control.extctl_to_intseq stops of all rows
 exists (select 1 from twg.Cur_comp co1 
            where ec.extctl_to_intseq = ec.extctl_to_intseq 
            and co1.comptyp_cd = 'WAS_NODE_AGENT' ) 
;                                   

-- Configuration Manager dimension table
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop  table IZY.STAGE_D_CFGMGR;

--#EXECUTE_AT_TARGET
create table IZY.STAGE_D_CFGMGR (
 cfgmgr_comp_id    	integer not null,
 cfgmgr_comp_name       varchar(254) not null,
 cfgmgr_TypeCd	        char(17) not null,
 primary key (cfgmgr_comp_id)
);                      

--#INSERT_INTO_TARGET
insert into IZY.STAGE_D_CFGMGR
-- @D2C Removed group by -> select distinct
select distinct
 co1.comp_id as cfgmgr_comp_id,
 co1.comp_nm as cfgmgr_comp_name,
 co1.comptyp_cd as cfgmgr_TypeCd
from
 TWG.Cur_Comp co1,
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_CFGMGR' and
 co1.comp_id > ec.extctl_from_intseq and
 co1.comp_id <= ec.extctl_to_intseq and
 co1.comptyp_cd = 'WAS_NODE_AGENT'
;                  

-- copy WebSphere application server component from staging table into Mart dimension table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_CFGMGR
select * from IZY.STAGE_D_CFGMGR s
where not exists
( select 1 from
  IZY.D_WAS_CFGMGR d
  where
  d.cfgmgr_comp_id = s.cfgmgr_comp_id
);                                


-- confirm that the insertion of 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone),
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_CFGMGR'
; 
-- @D0 End: Add mart dimension tables for WebSphere 5.0.x 
                           
-------------------------------------------------------
--  insert the dimension: WebSphere Application server
-------------------------------------------------------

-- get the high value for the window
update TWG.Extract_Control ec set 
 ec.extctl_to_intseq =  ( select max(co1.comp_id) from twg.Cur_comp co1 
    where 
        co1.comptyp_cd in ('IZY_APPL_SERVER', 'J2EE_SERVER'))
where 
 ec.extctl_source='TWG.COMP' and
 ec.extctl_target='IZY.D_WAS_APPLSRV' and
-- @D2C Change to exists test with true test query on extract_control.extctl_to_intseq stops of all rows
 exists (select 1 from twg.Cur_comp co1 
            where 
                ec.extctl_to_intseq = ec.extctl_to_intseq 
                and co1.comptyp_cd in ('IZY_APPL_SERVER','J2EE_SERVER') ) 
;


-- WebSphere Application Server dimension table
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop  table IZY.STAGE_D_APPLSRV;

--#EXECUTE_AT_TARGET
-- @D0C Added WAS 5.0 Cluster name attribute
create table IZY.STAGE_D_APPLSRV (
 ApplSrv_Comp_ID    integer not null,
 ApplSrv_Comp_Name  varchar(254) not NULL,
 ApplSrv_Cluster    varchar(254),
 primary key (ApplSrv_Comp_ID)
);                 

--#INSERT_INTO_TARGET
-- @D0C Only version 3.5 and 4.x Applications servers
insert into IZY.STAGE_D_APPLSRV
-- @D2C Removed group by -> select distinct
select distinct
 co1.comp_id as ApplSrv_comp_id,
 co1.comp_nm as ApplSrv_comp_name,
 '--'        as ApplSrv_Cluster  
from
 TWG.Cur_Comp co1,
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_APPLSRV' and
 co1.comp_id > ec.extctl_from_intseq and
 co1.comp_id <= ec.extctl_to_intseq and
 co1.comptyp_cd = 'IZY_APPL_SERVER'
;                  

-- @D0A Added for Cluster name for WAS 5.0
--#INSERT_INTO_TARGET
insert into IZY.STAGE_D_APPLSRV
-- @D2C Removed group by -> select distinct
select distinct
 co1.comp_id as ApplSrv_comp_id,
 co1.comp_nm as ApplSrv_comp_name,
 ca2.compAttr_Val as ApplSrv_Cluster  
from
 TWG.Cur_Comp co1,
 TWG.Cur_CompAttr ca2,
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_APPLSRV' and
 co1.comp_id > ec.extctl_from_intseq and
 co1.comp_id <= ec.extctl_to_intseq and
 -- @D3C Changed IZY_APPL_SERVER to J2EE_SERVER for WAS 5.0 modeling
 co1.comptyp_cd = 'J2EE_SERVER' and
 co1.comp_id = ca2.comp_id and  
 ca2.attrtyp_cd = 'WAS_CLUSTER'
;               
       
-- copy WebSphere application server component from staging table into Mart dimension table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_APPLSRV
select * from IZY.STAGE_D_APPLSRV s
where not exists
( select 1 from
  IZY.D_WAS_APPLSRV d
  where
  d.ApplSrv_Comp_ID = s.ApplSrv_Comp_ID
);                                


-- confirm that the insertion of 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone),
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_APPLSRV'
; 


-----------------------------------------------------------
--  insert the dimension: Application Server Components
-----------------------------------------------------------

-- get the high value for the window
update TWG.Extract_Control ec set 
 ec.extctl_to_intseq =  ( select max(comp_id) from twg.Cur_comp
    where comptyp_cd in 
         ('IZY_DATA_SOURCE','IZY_EJB','IZY_JVM','IZY_SERVLET_SESS','IZY_THREAD_POOL','IZY_TRANSACT_MGR','IZY_WEB_APPL',
          'IZY_DYNA_CACHE', 'IZY_J2C_CONFACT',
          'IZY_WAS_DATA_SRC','IZY_WAS_EJB','IZY_WAS_JVM','IZY_WAS_SVLT_SESS','IZY_WAS_THREAD_PL','IZY_WAS_TRANS_MGR','IZY_WAS_WEB_APPL',
          'IZY_WAS_DYNACACHE', 'IZY_WAS_J2C_FACT'
          ) 
                    )
where 
 ec.extctl_source='TWG.COMP' and
 ec.extctl_target='IZY.D_WAS_APPLCMP' and
-- @D2C Change to exists test with true test query on extract_control.extctl_to_intseq stops of all rows
 exists (select 1 from twg.Cur_comp where 
    ec.extctl_to_intseq = ec.extctl_to_intseq and 
 comptyp_cd in
  ('IZY_DATA_SOURCE','IZY_EJB','IZY_JVM','IZY_SERVLET_SESS','IZY_THREAD_POOL','IZY_TRANSACT_MGR','IZY_WEB_APPL',
   'IZY_DYNA_CACHE', 'IZY_J2C_CONFACT',
   'IZY_WAS_DATA_SRC','IZY_WAS_EJB','IZY_WAS_JVM','IZY_WAS_SVLT_SESS','IZY_WAS_THREAD_PL','IZY_WAS_TRANS_MGR','IZY_WAS_WEB_APPL',
   'IZY_WAS_DYNACACHE', 'IZY_WAS_J2C_FACT'
  )
       ) 
;                   

-- WebSphere Application Server SubComponents dimension table
-- ie. JVM, EJBs, Web Applications, Servlets, DataSources...
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_D_APPLCMP;

--#EXECUTE_AT_TARGET
create table IZY.STAGE_D_APPLCMP(
 ApplCmp_Comp_ID     integer not null,
 ApplCmp_Comp_Name   varchar(254) not null, 
 ApplCmp_Comp_TypeCd	char(17) not null,
 primary key (ApplCmp_Comp_ID)
);


--#INSERT_INTO_TARGET
insert into IZY.STAGE_D_APPLCMP
-- @D2C Removed group by -> select distinct
select  distinct
 co1.comp_id as ApplCmp_Comp_id,
 co1.comp_nm as ApplCmp_Name, 
 co1.comptyp_cd as ApplCmp_TypeCd
from  
 TWG.Cur_Comp co1,  
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_APPLCMP' and
 co1.comp_id > ec.extctl_from_intseq and
 co1.comp_id <= ec.extctl_to_intseq and
 co1.comptyp_cd in ('IZY_DATA_SOURCE','IZY_EJB','IZY_JVM','IZY_SERVLET_SESS','IZY_THREAD_POOL','IZY_TRANSACT_MGR','IZY_WEB_APPL',
   'IZY_DYNA_CACHE', 'IZY_J2C_CONFACT',
   'IZY_WAS_DATA_SRC','IZY_WAS_EJB','IZY_WAS_JVM','IZY_WAS_SVLT_SESS','IZY_WAS_THREAD_PL','IZY_WAS_TRANS_MGR','IZY_WAS_WEB_APPL',
   'IZY_WAS_DYNACACHE', 'IZY_WAS_J2C_FACT'
   )
;


-- copy WebSphere application server components from staging table into Mart dimension table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_APPLCMP
select * from IZY.STAGE_D_APPLCMP s
where not exists
( select 1 from
  IZY.D_WAS_APPLCMP d
  where
  d.ApplCmp_Comp_ID = s.ApplCmp_Comp_ID
);                                


-- confirm that the insertion 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_APPLCMP'
; 

------------------------------------------------------------------------
-- insert the dimension: Subcomponent (Connection Pools, servlets)
-------------------------------------------------------------------------

-- get the high value for the window
update TWG.Extract_Control ec set 
 ec.extctl_to_intseq =  ( select max(comp_id) from twg.Cur_comp
    where comptyp_cd in ('IZY_SERVLET','IZY_CONNECT_POOL','IZY_J2C_CONPOOL',
                         'IZY_WAS_SERVLET','IZY_WAS_CONN_PL','IZY_WAS_J2C_POOL'
                        ) )
where 
 ec.extctl_source='TWG.COMP' and
 ec.extctl_target='IZY.D_WAS_SUBCMP' and
-- @D2C Change to exists test with true test query on extract_control.extctl_to_intseq stops of all rows
 exists (select 1 from twg.Cur_comp 
 where ec.extctl_to_intseq = ec.extctl_to_intseq and
 comptyp_cd in ('IZY_SERVLET','IZY_CONNECT_POOL', 'IZY_J2C_CONPOOL',
                'IZY_WAS_SERVLET','IZY_WAS_CONN_PL','IZY_WAS_J2C_POOL')
        )
;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_D_SUBCMP;

-- WebSphere SubComponent dimension table
--#EXECUTE_AT_TARGET
create table IZY.STAGE_D_SUBCMP(
 SubCmp_Comp_ID     integer not null,
 SubCmp_Name   varchar(254) not null, 
 SubCmp_TypeCd	char(17) not null,
 primary key (SubCmp_Comp_ID)
);


--#INSERT_INTO_TARGET
insert into IZY.STAGE_D_SUBCMP
-- @D2C Removed group by -> select distinct
select  distinct
 co1.comp_id as SubCmp_Comp_Id,
 co1.comp_nm as SubCmp_Name, 
 co1.comptyp_cd as SubCmp_TypeCd
from  
 TWG.Cur_Comp co1,  
 TWG.Extract_Control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_SUBCMP' and
 co1.comp_id > ec.extctl_from_intseq and
 co1.comp_id <= ec.extctl_to_intseq and
 co1.comptyp_cd in ('IZY_SERVLET','IZY_CONNECT_POOL', 'IZY_J2C_CONPOOL',
                    'IZY_WAS_SERVLET','IZY_WAS_CONN_PL','IZY_WAS_J2C_POOL')
;


-- copy WebSphere application server subcomponent from staging table into Mart dimension table 
--#EXECUTE_AT_TARGET
insert into IZY.D_WAS_SUBCMP
select * from IZY.STAGE_D_SUBCMP s
where not exists
( select 1 from
  IZY.D_WAS_SUBCMP d
  where
  d.SubCmp_Comp_ID = s.SubCmp_Comp_ID
);                                


-- confirm that the insertion 
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.COMP' and
 ec.extctl_target = 'IZY.D_WAS_SUBCMP'
; 

                           
