-- ==========================================================================
-- Licensed Materials - Property of IBM
-- "Restricted Materials of IBM"
--
-- 5724-C01
-- 5698-WAZ
--
-- (C) COPYRIGHT IBM CORP. 2002, 2004. ALL RIGHTS RESERVED.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- ==========================================================================
--
-- File Information: wsappsvr/src/tedw_apps_etl/fixpack_v1103/izy/etl/sql/izy_m10_s010_fact.db2, waspac, waspac_512, 200403261523
-- 
-- Revision: 1.9
-- 
-- Date: 3/24/04 17:52:22
-- 
-- Description: IBM Tivoli Monitoring  for WebSphere file for moving data 
--              from the tables in the Central Data Warehouse (TWH_CDW) 
--              to the fact dimension tables in the Data mart (TWH_Mart) via
--              staging tables in the data mart.  
--  
-- ==========================================================================
--  Change Activity:
--  $F0 107152 12/09/03  lmd  Add support for WAS z/OS 
--  $D0 116710 07/11/03  lmd  5.1.2 - Check for WAS v5
--  $D1 118844 09/28/03  lmd  Performance enhancements
--  $D2 IY49528 11/05/03 lmd  Performance enhancements - add staging tables
--  $D3 IY51267 12/17/03 lmd  Change WAS 4.0 modeling back to prior to 5.1.2
--  $D4 129959  03/09/04 lmd  Improve performance of pruning Deletes     
--  $D5 130986  03/23/04 lmd  Add 'where not exists' clauses to F_ADMINSRV_HOUR
--  ==========================================================================
-- 
--
---------------------------
-- IZY_m05_s020_fact step
---------------------------
-- 
------------------------------------------------------------------------
--  Prune data from hourly, daily, weekly, monthly fact tables
------  according to the settings in the izy.Prune_Mart_Control table            
------  Log the pruning in the izy.prune_mart_log table
------  Remove any entries from the log where no pruning took place.                 
------------------------------------------------------------------------             
                             
-- @D4A Added temporary table to store actual pruning date for performance
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.Stage_PMart_Ctl;

--#EXECUTE_AT_TARGET
CREATE TABLE IZY.Stage_PMART_CTL (
        Table_Name         VARCHAR(120) NOT NULL,
        PMart_Ctl_Date     timestamp,
       PRIMARY KEY (Table_Name)
);      

--------------------------------------------------------------------------------
-- log the pruning of the hourly fact table IZY.F_ADMINSRV_HOUR
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_ADMINSRV_HOUR',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_ADMINSRV_HOUR')
  ); 

--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_ADMINSRV_HOUR',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_ADMINSRV_HOUR'),
     (select count(*) FROM IZY.F_ADMINSRV_HOUR f  WHERE 
        f.meas_hour  < 
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_ADMINSRV_HOUR')
     )
  ); 

-- prune the hourly fact table IZY.F_ADMINSRV_HOUR
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_ADMINSRV_HOUR f
WHERE
    f.meas_hour < 
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_ADMINSRV_HOUR')
;

--------------------------------------------------------------------------------
-- log the pruning of the daily fact table IZY.F_ADMINSRV_DAY
--------------------------------------------------------------------------------
-- @D4A For performance, calcufate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_ADMINSRV_DAY',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_ADMINSRV_DAY')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_ADMINSRV_DAY',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_ADMINSRV_DAY'),
     (select count(*) FROM IZY.F_ADMINSRV_DAY f  WHERE
        f.meas_date < 
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_ADMINSRV_DAY')
     )      
  ); 

-- prune the daily fact table IZY.F_ADMINSRV_DAY
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_ADMINSRV_DAY f
WHERE
   f.meas_date < 
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_ADMINSRV_DAY')
;

--------------------------------------------------------------------------------
-- log the pruning of the weekly fact table IZY.F_ADMINSRV_WEEK
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_ADMINSRV_WEEK',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_ADMINSRV_WEEK')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_ADMINSRV_WEEK',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_ADMINSRV_WEEK'),
     (select count(*) FROM IZY.F_ADMINSRV_WEEK f  WHERE
       f.meas_date <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_ADMINSRV_WEEK')
     )      
  ); 

-- prune the weekly fact table IZY.F_ADMINSRV_WEEK
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_ADMINSRV_WEEK f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_ADMINSRV_WEEK')   
;


--------------------------------------------------------------------------------
-- log the pruning of the monthly fact table IZY.F_ADMINSRV_MONTH
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_ADMINSRV_MONTH',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_ADMINSRV_MONTH')
  ); 

--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_ADMINSRV_MONTH',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_ADMINSRV_MONTH'),
     (select count(*) FROM IZY.F_ADMINSRV_MONTH f  WHERE
       f.meas_date < 
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_ADMINSRV_MONTH')
     )      
  ); 

-- prune the monthly fact table IZY.F_ADMINSRV_MONTH
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_ADMINSRV_MONTH f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_ADMINSRV_MONTH')
;


--------------------------------------------------------------------------------
-- log the pruning of the hourly fact table IZY.F_APPLSRV_HOUR
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_APPLSRV_HOUR',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLSRV_HOUR')
  ); 

--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLSRV_HOUR',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLSRV_HOUR'),   
     (select count(*) FROM IZY.F_APPLSRV_HOUR f  WHERE
      f.meas_hour < 
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
         WHERE p.Table_Name= 'IZY.F_APPLSRV_HOUR')
     )      
  ); 

-- prune the hourly fact table IZY.F_APPLSRV_HOUR
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLSRV_HOUR f
WHERE
   f.meas_hour < 
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLSRV_HOUR')
;

--------------------------------------------------------------------------------
-- log the pruning of the daily fact table IZY.F_APPLSRV_DAY
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_APPLSRV_DAY',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLSRV_DAY')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLSRV_DAY',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLSRV_DAY'),
     
     (select count(*) FROM IZY.F_APPLSRV_DAY f  WHERE
      f.meas_date <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLSRV_DAY')
     )      
  ); 

-- prune the daily fact table IZY.F_APPLSRV_DAY
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLSRV_DAY f
WHERE
   f.meas_date < 
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLSRV_DAY')
;

--------------------------------------------------------------------------------
-- log the pruning of the weekly fact table IZY.F_APPLSRV_WEEK
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_APPLSRV_WEEK',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLSRV_WEEK')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLSRV_WEEK',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLSRV_WEEK'),
     
     (select count(*) FROM IZY.F_APPLSRV_WEEK f  WHERE
      f.meas_date <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLSRV_WEEK')
     )      
  ); 

-- prune the weekly fact table IZY.F_APPLSRV_WEEK
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLSRV_WEEK f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLSRV_WEEK')
;


--------------------------------------------------------------------------------
-- log the pruning of the monthly fact table IZY.F_APPLSRV_MONTH
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_APPLSRV_MONTH',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLSRV_MONTH')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLSRV_MONTH',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLSRV_MONTH'),
     
     (select count(*) FROM IZY.F_APPLSRV_MONTH f  WHERE
      f.meas_date < 
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLSRV_MONTH')
     )      
  ); 

-- prune the monthly fact table IZY.F_APPLSRV_MONTH
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLSRV_MONTH f
WHERE
   f.meas_date < 
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLSRV_MONTH')
;


--------------------------------------------------------------------------------
-- log the pruning of the hourly fact table IZY.F_APPLCMP_HOUR
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_APPLCMP_HOUR',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLCMP_HOUR')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLCMP_HOUR',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLCMP_HOUR'),
     
     (select count(*) FROM IZY.F_APPLCMP_HOUR f  WHERE
      f.meas_hour <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLCMP_HOUR')
     )      
  ); 

-- prune the hourly fact table IZY.F_APPLCMP_HOUR
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLCMP_HOUR f
WHERE
   f.meas_hour  <  
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLCMP_HOUR')
;

--------------------------------------------------------------------------------
-- log the pruning of the daily fact table IZY.F_APPLCMP_DAY
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_APPLCMP_DAY',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLCMP_DAY')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLCMP_DAY',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLCMP_DAY'),
     
     (select count(*) FROM IZY.F_APPLCMP_DAY f  WHERE
      f.meas_date <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLCMP_DAY')
     )      
  ); 

-- prune the daily fact table IZY.F_APPLCMP_DAY
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLCMP_DAY f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLCMP_DAY')
;

--------------------------------------------------------------------------------
-- log the pruning of the weekly fact table IZY.F_APPLCMP_WEEK
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_APPLCMP_WEEK',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLCMP_WEEK')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLCMP_WEEK',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLCMP_WEEK'),
     (select count(*) FROM IZY.F_APPLCMP_WEEK f  WHERE
      f.meas_date < 
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLCMP_WEEK')
     )      
  ); 

-- prune the weekly fact table IZY.F_APPLCMP_WEEK
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLCMP_WEEK f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLCMP_WEEK')
;

--------------------------------------------------------------------------------
-- log the pruning of the monthly fact table IZY.F_APPLCMP_MONTH
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_APPLCMP_MONTH',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLCMP_MONTH')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLCMP_MONTH',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLCMP_MONTH'),
     (select count(*) FROM IZY.F_APPLCMP_MONTH f  WHERE
      f.meas_date <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLCMP_MONTH')
     )      
  ); 

-- prune the monthly fact table IZY.F_APPLCMP_MONTH
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLCMP_MONTH f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLCMP_MONTH')
;


--------------------------------------------------------------------------------
-- log the pruning of the hourly fact table IZY.F_SUBCMP_HOUR
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_SUBCMP_HOUR',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_SUBCMP_HOUR')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_SUBCMP_HOUR',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_SUBCMP_HOUR'),
     (select count(*) FROM IZY.F_SUBCMP_HOUR f  WHERE
      f.meas_hour <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_SUBCMP_HOUR')
     )      
  ); 

-- prune the hourly fact table IZY.F_SUBCMP_HOUR
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_SUBCMP_HOUR f
WHERE
   f.meas_hour <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_SUBCMP_HOUR')
;

--------------------------------------------------------------------------------
-- log the pruning of the daily fact table IZY.F_SUBCMP_DAY
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_SUBCMP_DAY',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_SUBCMP_DAY')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_SUBCMP_DAY',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_SUBCMP_DAY'),        
     (select count(*) FROM IZY.F_SUBCMP_DAY f  WHERE
      f.meas_date <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_SUBCMP_DAY')
     )      
  ); 

-- prune the daily fact table IZY.F_SUBCMP_DAY
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_SUBCMP_DAY f
WHERE
   f.meas_date < 
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_SUBCMP_DAY')
;

--------------------------------------------------------------------------------
-- log the pruning of the weekly fact table IZY.F_SUBCMP_WEEK
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_SUBCMP_WEEK',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_SUBCMP_WEEK')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_SUBCMP_WEEK',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_SUBCMP_WEEK'),
     (select count(*) FROM IZY.F_SUBCMP_WEEK f  WHERE
      f.meas_date < 
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_SUBCMP_WEEK')
     )      
  ); 

-- prune the weekly fact table IZY.F_SUBCMP_WEEK
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_SUBCMP_WEEK f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_SUBCMP_WEEK')
;


--------------------------------------------------------------------------------
-- log the pruning of the monthly fact table IZY.F_SUBCMP_MONTH
--------------------------------------------------------------------------------
-- @D4A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart_Ctl  values 
 ('IZY.F_SUBCMP_MONTH',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_SUBCMP_MONTH')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_SUBCMP_MONTH',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_SUBCMP_MONTH'),
     
     (select count(*) FROM IZY.F_SUBCMP_MONTH f  WHERE
      f.meas_date <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
        WHERE p.Table_Name= 'IZY.F_SUBCMP_MONTH')
     )      
  ); 

-- prune the monthly fact table IZY.F_SUBCMP_MONTH
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_SUBCMP_MONTH f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart_Ctl p
     WHERE p.Table_Name = 'IZY.F_SUBCMP_MONTH')
;



-- delete entries in prune log where nothing was pruned
--#EXECUTE_AT_TARGET
DELETE FROM IZY.PRUNE_MART_LOG 
  WHERE NUMBER_PRUNED = 0
;

--------------------------------------------------------------------------------
-- @d3C Get the high value msmt_id for the window and set for all tables at once.
-- Find max msmt_id only one time to improve performance.
--------------------------------------------------------------------------------
update TWG.Extract_Control ec set 
 ec.extctl_to_intseq =  ( select max(msmt_id) from twg.msmt)
where 
 ec.extctl_source='TWG.MSMT' and
 ec.extctl_target in ('IZY.STAGE_F_ADMIN_HOUR' ,
                      'IZY.STAGE_F_APPL_HOUR', 
                      'IZY.STAGE_F_APCMP_HOUR',
                      'IZY.STAGE_F_SBCMP_HOUR1',
                      'IZY.STAGE_F_SBCMP_HOUR2',  
                      'IZY.STAGE_F_SBCMP_HOUR3',
                      'IZY.STAGE_F_SBCMP_HOUR4',
                      'IZY.STAGE_F_SBCMP_HOUR5',
                      'IZY.STAGE_F_SBCMP_HOUR6',
                      'IZY.STAGE_F_SBCMP_HOUR7',
                      'IZY.STAGE_F_SBCMP_HOUR8',
                      'IZY.STAGE_F_SBCMP_HOUR9',
                      'IZY.STAGE_F_SBCMP_HOUR10', 
                      'IZY.STAGE_F_SBCMP_HOUR11',
                      'IZY.STAGE_F_SBCMP_HOUR12')
 AND
-- @D1C Change count(*) to exists test with true test query on extract_control.extctl_to_intseq stops scan of all rows in twg.msmt
 exists (select 1 from twg.msmt where ec.extctl_to_intseq = ec.extctl_to_intseq)   
;

--------------------------------------------------------------------------------
-- insert the facts for WebSphere AdminServer (IZY_ADMIN_SERVER) component
--------------------------------------------------------------------------------

-- @D2A Added staging table
--#IGNORE_ERROR
drop table IZY.Stage_adminSrv;

create table IZY.Stage_adminSrv (
adminSrv_id integer not null,
host_id integer, 
adminSrv_dttm  timestamp,
primary key(adminSrv_id)
);

insert into IZY.Stage_adminSrv
select 
 co1.comp_id as adminSrv_id,
 cr1.comp_source_id as host_id,
 max(ca.compattr_strt_dttm) as adminSrv_dttm
from
 TWG.Cur_Comp co1,
 TWG.Cur_CompReln cr1,
 TWG.Cur_CompAttr ca
where
 co1.comptyp_cd = 'IZY_ADMIN_SERVER' and         
 ca.comp_id=co1.comp_id and  
 ca.attrtyp_cd in ('IZY_OS_TYPE','IZY_WAS_VERSION','IZY_POLICY_REGION',
                          'VERSION', 'TME_POLICY_REGION', 'OS_NAME') and
 cr1.comp_target_id=co1.comp_id and
 cr1.relntyp_cd='PCHILD'
group by
 co1.comp_id ,
 cr1.comp_source_id
; 

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_ADMIN_HOUR;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against AdminServer 
create table IZY.STAGE_F_ADMIN_HOUR (
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
  total_value double,
  sample_count integer,
	primary key (AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


--#INSERT_INTO_TARGET
insert into IZY.STAGE_F_ADMIN_HOUR
select 
 m.comp_id as AdminSrv_Comp_ID, 
 c1.AdminSrv_dttm as XQ_AdminSrv_dttm,
 c1.host_id as host_id,
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value,
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_adminSrv c1,  
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_ADMIN_HOUR' and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq and
 m.tmsum_cd='H' and
 c1.adminSrv_id=m.comp_id             
group by
 m.comp_id, c1.host_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm,
 c1.AdminSrv_dttm
;


--#EXECUTE_AT_TARGET
-- @D5C Add 'where not exists' clauses to prevent failure on duplicates
insert into IZY.F_ADMINSRV_HOUR
select * from IZY.STAGE_F_ADMIN_HOUR a
where not exists
(select 1 from 
IZY.F_ADMINSRV_HOUR b
where 
a.adminsrv_comp_id=b.adminsrv_comp_id and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour)
;

-- confirm that the insertion of 
-- the facts for WAS AdminServer has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone),
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_ADMIN_HOUR'
; 

------------------------------------------------------------------------------------
-- insert the facts for WebSphere Application Server (IZY_APPL_SERVER) component
------------------------------------------------------------------------------------
-- @D3D get the high value for the window: now done up front for all entries

--#IGNORE_ERROR
-- @d2A Added staging tables
drop table IZY.Stage_applSrv;

create table IZY.Stage_applSrv(
 ApplSrv_ID 	integer not null,
 AdminSrv_ID	integer,
 AdminSrv_dttm timestamp,
 host_id 	integer,
primary key(ApplSrv_ID)
);

insert into IZY.Stage_applSrv
select
 co1.comp_id as ApplSrv_ID, 
 cr1.comp_source_id as AdminSrv_ID,
 max(ca.compattr_strt_dttm) as AdminSrv_dttm,
 cr2.comp_source_id as host_id
from
 TWG.Cur_Comp co1,
 TWG.Cur_CompAttr ca,  
 TWG.Cur_CompReln cr1,
 TWG.Cur_CompReln cr2
where
 co1.comptyp_cd = 'IZY_APPL_SERVER' and
 co1.comp_id = cr1.comp_target_id and
 cr1.relntyp_cd='PCHILD'and 
-- cr1.comp_source_id = adminSrv
 ca.comp_id=cr1.comp_source_id and  
 ca.attrtyp_cd in ('IZY_OS_TYPE','IZY_WAS_VERSION','IZY_POLICY_REGION',
 			'VERSION', 'TME_POLICY_REGION', 'OS_NAME') and
 cr1.comp_source_id = cr2.comp_target_id and 
 cr2.relntyp_cd='PCHILD'
group by
 co1.comp_id, cr1.comp_source_id, cr2.comp_source_id
 ;
 

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_APPL_HOUR;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against Application Server
create table IZY.STAGE_F_APPL_HOUR (
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
  total_value double,
  sample_count integer,
	primary key (ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


--#INSERT_INTO_TARGET
insert into IZY.STAGE_F_APPL_HOUR
select 
 m.comp_id as ApplSrv_Comp_ID, 
 c1.AdminSrv_id as AdminSrv_Comp_ID,
 c1.AdminSrv_dttm as XQ_AdminSrv_dttm,
 c1.host_id as host_id,
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value,
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_applSrv c1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_APPL_HOUR' and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq and
 m.tmsum_cd='H' and
 m.comp_id=c1.ApplSrv_id
group by
 m.comp_id, c1.host_id,c1.AdminSrv_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm,c1.AdminSrv_dttm 
;

--#EXECUTE_AT_TARGET
insert into IZY.F_APPLSRV_HOUR
select * from IZY.STAGE_F_APPL_HOUR a
where not exists
(select 1 from 
IZY.F_APPLSRV_HOUR b
where 
a.applsrv_comp_id=b.applsrv_comp_id and
a.adminsrv_comp_id=b.adminsrv_comp_id and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour)
;

-- confirm that the insertion of 
-- the facts for WAS Application Server has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_APPL_HOUR'
;                                                 


------------------------------------------------------------------------------------
-- insert the facts for the Subcomponents of the Application Server:
--       IZY_DATA_SOURCE,IZY_EJB, IZY_SERVLET_SESS, IZY_THREAD_POOL,IZY_TRANSACT_MGR, IZY_WEB_APPL
------------------------------------------------------------------------------------

-- @D2A Added staging tables to improve performance
--#IGNORE_ERROR
drop table IZY.Stage_apcmp_apsrv;

create table IZY.Stage_apcmp_apsrv (
applcmp_id integer not null,
applsvr_id integer, 
primary key(applcmp_id)
);

insert into IZY.Stage_apcmp_apsrv
select distinct
 co1.comp_id as applcmp_id,
 cr1.comp_source_id as applsvr_id
from
 TWG.Cur_Comp co1,
 TWG.Cur_CompReln cr1
where
 co1.comptyp_cd in ('IZY_DATA_SOURCE',
                   'IZY_EJB',
                   'IZY_JVM',
                   'IZY_SERVLET_SESS',
                   'IZY_THREAD_POOL',
                   'IZY_TRANSACT_MGR',
                   'IZY_WEB_APPL') and
 cr1.comp_target_id=co1.comp_id and
 cr1.relntyp_cd='PCHILD' 
; 

-- select count(*) from IZY.Stage_apcmp_apsrv;

--#IGNORE_ERROR
drop table   IZY.Stage_apcmp_admin;

create table IZY.Stage_apcmp_admin (
applcmp_id integer not null,
adminsvr_id integer ,
primary key(applcmp_id)
);

insert into IZY.Stage_apcmp_admin
select distinct
 co1.applcmp_id as applcmp_id,
 cr1.comp_source_id as adminsvr_id
from
 IZY.Stage_apcmp_apsrv co1 ,
 TWG.Cur_compReln cr1
where
-- web appl or data source = comp_target_id = co1.applcmp_id  
 cr1.comp_target_id=co1.applsvr_id and
 cr1.relntyp_cd='PCHILD' 
; 

-- select count(*) from IZY.Stage_apcmp_admin;



--#IGNORE_ERROR
drop table IZY.Stage_apcmp_ASattr;

create table IZY.Stage_apcmp_ASattr (
applcmp_id integer not null,
adminsvr_dttm  timestamp,
primary key(applcmp_id)
);

insert into IZY.Stage_apcmp_ASattr
select
 co1.applcmp_id as applcmp_id,
 max(ca.compattr_strt_dttm) as adminsvr_dttm
from
 IZY.Stage_apcmp_admin co1,
 TWG.Cur_compAttr ca
where
ca.attrtyp_cd in ('IZY_OS_TYPE','IZY_WAS_VERSION','IZY_POLICY_REGION',
                          'VERSION', 'TME_POLICY_REGION', 'OS_NAME') and
ca.comp_id=co1.adminsvr_id
group by 
co1.applcmp_id
; 

-- select count(*) from IZY.Stage_apcmp_ASattr;

--#IGNORE_ERROR
drop table IZY.Stage_apcmp_host;

create table IZY.Stage_apcmp_host (
applcmp_id integer not null,
host_id integer,
primary key(applcmp_id)
);

insert into IZY.Stage_apcmp_host
select distinct
 co1.applcmp_id as applcmp_id,
 cr1.comp_source_id as host_id
from
 IZY.Stage_apcmp_admin co1,
 TWG.Cur_compReln cr1
where
 cr1.comp_target_id=co1.adminsvr_id and
 cr1.relntyp_cd='PCHILD' 
; 

-- select count(*) from IZY.Stage_apcmp_host;

--#IGNORE_ERROR
drop table IZY.Stage_apcmp_All;

create table IZY.Stage_apcmp_All (
applcmp_id integer not null,
applsvr_id integer,
adminsvr_id integer,
adminsvr_dttm timestamp,
host_id integer,
primary key(applcmp_id)
);

insert into IZY.Stage_apcmp_All
select distinct
 co1.applcmp_id as applcmp_id,
 co1.applsvr_id as applsvr_id,
 co2.adminsvr_id as  adminsvr_id,
 co3.adminsvr_dttm as adminsvr_dttm,
 co4.host_id as host_id
from
 IZY.Stage_apcmp_apsrv co1,
 IZY.Stage_apcmp_admin co2,
 IZY.Stage_apcmp_ASattr co3,
 IZY.Stage_apcmp_host co4
where
 co1.applcmp_id=co2.applcmp_id and
 co1.applcmp_id=co3.applcmp_id and
 co1.applcmp_id=co4.applcmp_id and
 exists ( select 1 from IZY.Stage_apcmp_ASattr )
;

insert into IZY.Stage_apcmp_All
select distinct
 co1.applcmp_id as applcmp_id,
 co1.applsvr_id as applsvr_id,
 co2.adminsvr_id as  adminsvr_id,
 current timestamp - current timezone as adminsvr_dttm,
 co4.host_id as host_id
from
 IZY.Stage_apcmp_apsrv co1,
 IZY.Stage_apcmp_admin co2,
 IZY.Stage_apcmp_host co4
where
 co1.applcmp_id=co2.applcmp_id and
 co1.applcmp_id=co4.applcmp_id and
 not exists ( select 1 from IZY.Stage_apcmp_ASattr )
;

-- select count(*) from izy.stage_apcmp_all;



-- @D3D get the high value for the window: now done up front for all entries

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_APCMP_HOUR;

--#EXECUTE_AT_TARGET
-- Staging measurement hour fact table for all metrics against Application Server components
create table IZY.STAGE_F_APCMP_HOUR (
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
  total_value double,
  sample_count integer,
	primary key (ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);

--#INSERT_INTO_TARGET
insert into IZY.STAGE_F_APCMP_HOUR
select 
 m.comp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.adminsvr_id as AdminSrv_Comp_ID,
 max(co1.adminsvr_dttm) as XQ_AdminSrv_dttm,
 co1.host_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
 -- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_apcmp_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_APCMP_HOUR' and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq and
 m.tmsum_cd='H' and
 co1.applcmp_id=m.comp_id 
group by
 m.comp_id, 
 co1.applsvr_id, co1.adminsvr_id, co1.adminsvr_dttm, co1.host_id,
 m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_APPLCMP_HOUR
select * from IZY.STAGE_F_APCMP_HOUR a
-- @d3a Add where not exists to prevent duplicate data error
where not exists 
( select 1 from
IZY.F_APPLCMP_HOUR b
where
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.AdminSrv_Comp_ID=b.AdminSrv_Comp_ID and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);



-- confirm that the insertion of the facts for the Subcomponents of the Application Server:
-- IZY_DATA_SOURCE,IZY_EJB, IZY_SERVLET_SESS, IZY_THREAD_POOL,IZY_TRANSACT_MGR, IZY_WEB_APPL
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_APCMP_HOUR'
;



------------------------------------------------------------------------------------
-- insert the facts for the Subcomponents items of Data Sources and Web Applications:
------------------------------------------------------------------------------------


-- @D2A Added staging tables to improve performance
--#IGNORE_ERROR
drop table IZY.Stage_sbcmp_apcmp;

create table IZY.Stage_sbcmp_apcmp (
subcomp_id integer not null,
applcmp_id integer,
primary key(subcomp_id)
);

insert into IZY.Stage_sbcmp_apcmp
select distinct
 co1.comp_id as subcomp_id,
 cr1.comp_source_id as applcmp_id
from
 TWG.Cur_Comp co1,
 TWG.Cur_compReln cr1
where
 co1.comptyp_cd in ('IZY_CONNECT_POOL','IZY_SERVLET') and
 cr1.comp_target_id=co1.comp_id and
 cr1.relntyp_cd='PCHILD' 
; 

-- select count(*) from IZY.Stage_sbcmp_apcmp;

--#IGNORE_ERROR
drop table   IZY.Stage_sbcmp_apsrv;

create table IZY.Stage_sbcmp_apsrv (
subcomp_id integer not null,
applsvr_id integer ,
primary key(subcomp_id)
);

insert into IZY.Stage_sbcmp_apsrv
select distinct
 co1.subcomp_id as subcomp_id,
 cr1.comp_source_id as applsvr_id
from
 IZY.Stage_sbcmp_apcmp co1 ,
 TWG.Cur_compReln cr1
where
-- web appl or data source = comp_target_id = co1.applcmp_id  
 cr1.comp_target_id=co1.applcmp_id and
 cr1.relntyp_cd='PCHILD' 
; 

-- select count(*) from IZY.Stage_sbcmp_apsrv;

--#IGNORE_ERROR
drop table IZY.Stage_sbcmp_admin;

create table IZY.Stage_sbcmp_admin (
subcomp_id integer not null,
adminsvr_id integer,
primary key(subcomp_id)
);

insert into IZY.Stage_sbcmp_admin
select distinct
 co1.subcomp_id as subcomp_id,
 cr1.comp_source_id as adminsvr_id
from
 IZY.Stage_sbcmp_apsrv co1,
 TWG.Cur_compReln cr1
where
 cr1.comp_target_id=co1.applsvr_id and
 cr1.relntyp_cd='PCHILD' 
; 

-- select count(*) from IZY.Stage_sbcmp_admin;

--#IGNORE_ERROR
drop table IZY.Stage_sbcmp_ASattr;

create table IZY.Stage_sbcmp_ASattr (
subcomp_id integer not null,
adminsvr_dttm  timestamp,
primary key(subcomp_id)
);

insert into IZY.Stage_sbcmp_ASattr
select
 co1.subcomp_id as subcomp_id,
 max(ca.compattr_strt_dttm) as adminsvr_dttm
from
 IZY.Stage_sbcmp_admin co1,
 TWG.Cur_compAttr ca
where
ca.attrtyp_cd in ('IZY_OS_TYPE','IZY_WAS_VERSION','IZY_POLICY_REGION',
        'VERSION', 'TME_POLICY_REGION', 'OS_NAME') and
ca.comp_id=co1.adminsvr_id
group by 
co1.subcomp_id
; 

-- select count(*) from IZY.Stage_sbcmp_ASattr;

--#IGNORE_ERROR
drop table IZY.Stage_sbcmp_host;

create table IZY.Stage_sbcmp_host (
subcomp_id integer not null,
host_id integer,
primary key(subcomp_id)
);

insert into IZY.Stage_sbcmp_host
select distinct
 co1.subcomp_id as subcomp_id,
 cr1.comp_source_id as host_id
from
 IZY.Stage_sbcmp_admin co1,
 TWG.Cur_compReln cr1
where
 cr1.comp_target_id=co1.adminsvr_id and
 cr1.relntyp_cd='PCHILD' 
; 

-- select count(*) from IZY.Stage_sbcmp_host;

--#IGNORE_ERROR
drop table IZY.Stage_sbcmp_All;

create table IZY.Stage_sbcmp_All (
subcomp_id integer not null,
applcmp_id integer,
applsvr_id integer,
adminsvr_id integer,
adminsvr_dttm timestamp,
host_id integer,
primary key(subcomp_id)
);

insert into IZY.Stage_sbcmp_All
select
 co1.subcomp_id as subcomp_id,
 co1.applcmp_id as applcmp_id,
 co2.applsvr_id as applsvr_id,
 co3.adminsvr_id as  adminsvr_id,
 co4.adminsvr_dttm as adminsvr_dttm,
 co5.host_id as host_id
from
 IZY.Stage_sbcmp_apcmp co1,
 IZY.Stage_sbcmp_apsrv co2,
 IZY.Stage_sbcmp_admin co3,
 IZY.Stage_sbcmp_ASattr co4,
 IZY.Stage_sbcmp_host co5
where
 co1.subcomp_id=co2.subcomp_id and
 co1.subcomp_id=co3.subcomp_id and
 co1.subcomp_id=co4.subcomp_id and
 co1.subcomp_id=co5.subcomp_id and
 exists ( select 1 from IZY.Stage_sbcmp_ASattr )
; 

insert into IZY.Stage_sbcmp_All
select
 co1.subcomp_id as subcomp_id,
 co1.applcmp_id as applcmp_id,
 co2.applsvr_id as applsvr_id,
 co3.adminsvr_id as  adminsvr_id,
 current timestamp - current timezone as adminsvr_dttm,
 co5.host_id as host_id
from
 IZY.Stage_sbcmp_apcmp co1,
 IZY.Stage_sbcmp_apsrv co2,
 IZY.Stage_sbcmp_admin co3,
 IZY.Stage_sbcmp_ASattr co4,
 IZY.Stage_sbcmp_host co5
where
 co1.subcomp_id=co2.subcomp_id and
 co1.subcomp_id=co3.subcomp_id and
 co1.subcomp_id=co4.subcomp_id and
 co1.subcomp_id=co5.subcomp_id and
 not exists ( select 1 from IZY.Stage_sbcmp_ASattr )
; 

-- select count(*) from IZY.Stage_sbcmp_All;

-- @D1A END: Added staging tables


----------------------------------------------------------------------------------
-- PERFORMANCE AND LOG TUNING
-- In order to lower down the space needed in the
-- transaction log , and in order to keep good performance (for the sub components
-- that include the large number of servlets), I have
-- divided the data by chunk of 8000 on 12 staging tables
-- If the number of rows that need to be inserted is greater than 12 * 8000
-- ( from_intseq - to_intseq > 12 * 8000) , then we extract data by chunk of 250000
-- if not all the data is inserted into the IZY.STAGE_F_SBCMP_HOUR
-- The first table IZY.STAGE_F_SBC_HOUR1 may have more than 8000 rows if
-- the total rows is greater than 12 * 8000, but all the subsequent staging tables
-- should have 8000 rows only.
-- the "to_intseq" should always be updated to the max (msmt_id) so that all staging 
-- tables keep a record of the total number of rows inserte into the final Fact table
-------------------------------------------------------------------------------------

-------- PART 1

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBC_HOUR1;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBC_HOUR1 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


-- @D3D get the high value for the window: now done up front for all entries
        
--#INSERT_INTO_TARGET
-- @D2A Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SBC_HOUR1
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.adminsvr_id as AdminSrv_Comp_ID,
 max(co1.adminsvr_dttm) as XQ_AdminSrv_dttm,
 co1.host_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcmp_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR1' and
 m.msmt_id > ec.extctl_from_intseq  and
 m.msmt_id <= ec.extctl_to_intseq  - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 11) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.adminsvr_id, co1.adminsvr_dttm,
 co1.host_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;



--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR1 a
where not exists (
select 1 from 
IZY.F_SUBCMP_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.AdminSrv_Comp_ID=b.AdminSrv_Comp_ID and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR1'
;


--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR1;

---------- PART 2

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBC_HOUR2;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBC_HOUR2 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID       integer not null,
  AdminSrv_Comp_ID      integer not null,
  XQ_AdminSrv_dttm	timestamp not null,
  host_id		integer not null,
  metric_id             integer not null,
  meas_hour             timestamp not null,
  min_value             double,
  max_value             double,
  avg_value             double,
  total_value           double,
  sample_count          integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D2C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SBC_HOUR2
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.adminsvr_id as AdminSrv_Comp_ID,
 max(co1.adminsvr_dttm) as XQ_AdminSrv_dttm,
 co1.host_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D2C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcmp_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR2' and
 m.msmt_id > ec.extctl_to_intseq  - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 11) and
 m.msmt_id <= ec.extctl_to_intseq  - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 10) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.adminsvr_id, co1.adminsvr_dttm,
 co1.host_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR2 a
where not exists (
select 1 from 
IZY.F_SUBCMP_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.AdminSrv_Comp_ID=b.AdminSrv_Comp_ID and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR2'
;

--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR2;

--- PART 3

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBC_HOUR3;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBC_HOUR3 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SBC_HOUR3
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.adminsvr_id as AdminSrv_Comp_ID,
 max(co1.adminsvr_dttm) as XQ_AdminSrv_dttm,
 co1.host_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcmp_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR3' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 10) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 9) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.adminsvr_id, co1.adminsvr_dttm,
 co1.host_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR3 a
where not exists (
select 1 from 
IZY.F_SUBCMP_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.AdminSrv_comp_id=b.AdminSrv_Comp_ID and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR3'
;


--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR3;

--- PART 4

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBC_HOUR4;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBC_HOUR4 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SBC_HOUR4
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.adminsvr_id as AdminSrv_Comp_ID,
 max(co1.adminsvr_dttm) as XQ_AdminSrv_dttm,
 co1.host_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcmp_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR4' and
 m.msmt_id > ec.extctl_to_intseq -  (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 9) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 8) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.adminsvr_id, co1.adminsvr_dttm,
 co1.host_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR4 a
where not exists (
select 1 from 
IZY.F_SUBCMP_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.AdminSrv_comp_id=b.AdminSrv_Comp_ID and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR4'
;

--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR4;

--- PART 5

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBC_HOUR5;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBC_HOUR5 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SBC_HOUR5
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.adminsvr_id as AdminSrv_Comp_ID,
 max(co1.adminsvr_dttm) as XQ_AdminSrv_dttm,
 co1.host_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcmp_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR5' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 8) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 7) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.adminsvr_id, co1.adminsvr_dttm,
 co1.host_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR5 a
where not exists (
select 1 from 
IZY.F_SUBCMP_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.AdminSrv_comp_id=b.AdminSrv_Comp_ID and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR5'
;

--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR5;

--- PART 6

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBC_HOUR6;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBC_HOUR6 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SBC_HOUR6
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.adminsvr_id as AdminSrv_Comp_ID,
 max(co1.adminsvr_dttm) as XQ_AdminSrv_dttm,
 co1.host_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcmp_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR6' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 7) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 6) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.adminsvr_id, co1.adminsvr_dttm,
 co1.host_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR6 a
where not exists (
select 1 from 
IZY.F_SUBCMP_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.AdminSrv_comp_id=b.AdminSrv_Comp_ID and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR6'
;


--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR6;

--- PART 7

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBC_HOUR7;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBC_HOUR7 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SBC_HOUR7
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.adminsvr_id as AdminSrv_Comp_ID,
 max(co1.adminsvr_dttm) as XQ_AdminSrv_dttm,
 co1.host_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcmp_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR7' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 6) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 5) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.adminsvr_id, co1.adminsvr_dttm,
 co1.host_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR7 a
where not exists (
select 1 from 
IZY.F_SUBCMP_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.AdminSrv_comp_id=b.AdminSrv_Comp_ID and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR7'
;


--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR7;

--- PART 8

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBC_HOUR8;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBC_HOUR8 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SBC_HOUR8
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.adminsvr_id as AdminSrv_Comp_ID,
 max(co1.adminsvr_dttm) as XQ_AdminSrv_dttm,
 co1.host_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcmp_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR8' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 5) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 4) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.adminsvr_id, co1.adminsvr_dttm,
 co1.host_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR8 a
where not exists (
select 1 from 
IZY.F_SUBCMP_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.AdminSrv_comp_id=b.AdminSrv_Comp_ID and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR8'
;

--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR8;

--- PART 9

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBC_HOUR9;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBC_HOUR9 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SBC_HOUR9
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.adminsvr_id as AdminSrv_Comp_ID,
 max(co1.adminsvr_dttm) as XQ_AdminSrv_dttm,
 co1.host_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcmp_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR9' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 4) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 3) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.adminsvr_id, co1.adminsvr_dttm,
 co1.host_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR9 a
where not exists (
select 1 from 
IZY.F_SUBCMP_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.AdminSrv_comp_id=b.AdminSrv_Comp_ID and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR9'
;

--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR9;

--- PART 10

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBC_HOUR10;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBC_HOUR10 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SBC_HOUR10
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.adminsvr_id as AdminSrv_Comp_ID,
 max(co1.adminsvr_dttm) as XQ_AdminSrv_dttm,
 co1.host_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcmp_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR10' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 3) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 2) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.adminsvr_id, co1.adminsvr_dttm,
 co1.host_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR10 a
where not exists (
select 1 from 
IZY.F_SUBCMP_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.AdminSrv_comp_id=b.AdminSrv_Comp_ID and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR10'
;


--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR10;

--- PART 11

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBC_HOUR11;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBC_HOUR11 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SBC_HOUR11
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.adminsvr_id as AdminSrv_Comp_ID,
 max(co1.adminsvr_dttm) as XQ_AdminSrv_dttm,
 co1.host_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcmp_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR11' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 2) and
 m.msmt_id <= ec.extctl_to_intseq - ((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.adminsvr_id, co1.adminsvr_dttm,
 co1.host_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR11 a
where not exists (
select 1 from 
IZY.F_SUBCMP_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.AdminSrv_comp_id=b.AdminSrv_Comp_ID and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR11'
;

--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR11; 

--- PART 12

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBC_HOUR12;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBC_HOUR12 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SBC_HOUR12
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.adminsvr_id as AdminSrv_Comp_ID,
 max(co1.adminsvr_dttm) as XQ_AdminSrv_dttm,
 co1.host_id as host_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcmp_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR12' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 1) and
 m.msmt_id <= ec.extctl_to_intseq and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.adminsvr_id, co1.adminsvr_dttm,
 co1.host_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR12 a
where not exists (
select 1 from 
IZY.F_SUBCMP_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.AdminSrv_comp_id=b.AdminSrv_Comp_ID and
a.xq_adminsrv_dttm=b.xq_adminsrv_dttm and
a.host_id=b.host_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SBCMP_HOUR12'
;

--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCMP_HOUR
select * from IZY.STAGE_F_SBC_HOUR12;

