-- ==========================================================================
-- Licensed Materials - Property of IBM
-- "Restricted Materials of IBM"
--
-- 5724-C01
-- 5698-WAZ
--
-- (C) COPYRIGHT IBM CORP. 2002, 2003. ALL RIGHTS RESERVED.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- ==========================================================================
--
-- File Information: wsappsvr/src/tedw_apps_etl/fixpack_v1103/izy/etl/sql/izy_m10_s055_cleanup.db2, waspac, waspac_512, 200402061736
-- 
-- Revision: 1.3
-- 
-- Date: 1/22/04 17:41:13
-- 
-- Description: IBM Tivoli Monitoring  for WebSphere file for moving data 
--              from the tables in the Central Data Warehouse (TWH_CDW) 
--              to the fact dimension tables in the Data mart (TWH_Mart) via
--              staging tables in the data mart.  
--  
-- ==========================================================================
--  Change Activity:
--  $D1 IY49528 11/05/03  lmd  Performance enhancements - new file
--  $D2 126070  01/13/04  lmd  Add V5 staging table
--  ==========================================================================
-- 
-- @D1A  new file 
---------------------------
-- IZY_m05_s055_Cleanup step
---------------------------
-- 
------------------------------------------------------------------------
-- IY49528 breaks up the subcmp fact table data into 12 staging tables and
-- 12 seperate inserts.  Rollup works off IZY.STAGE_F_SBCMP_HOUR which  
-- is populated for the 12 staging tables during the fact process.
-- Drop and recreate IZY.STAGE_F_SBCMP_HOUR after sbcmp rollup has 
-- successfully completed.
------------------------------------------------------------------------             

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBCMP_HOUR;

-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 

--#EXECUTE_AT_TARGET
create table IZY.STAGE_F_SBCMP_HOUR (
  SubCmp_Comp_ID    integer not null,
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID    integer not null,
  AdminSrv_Comp_ID    integer not null,
  XQ_AdminSrv_dttm		timestamp not null,
  host_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, AdminSrv_Comp_ID, XQ_AdminSrv_dttm, host_id, metric_id , meas_hour )
);


-- @D2A  Add staging table for WebSphere version 5.x or later
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SBCP5_HOUR;

-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
--#EXECUTE_AT_TARGET
create table IZY.STAGE_F_SBCP5_HOUR (
  SubCmp_Comp_ID     integer not null,
  ApplCmp_Comp_ID    integer not null,
  ApplSrv_Comp_ID    integer not null,
  Node_Comp_ID       integer not null,
  XQ_Node_dttm		   timestamp not null,
  cell_attr_id		      integer not null,
  metric_id          integer not null,
  meas_hour          timestamp not null,
  min_value          double,
  max_value          double,
  avg_value          double,
	total_value       double,
	sample_count      integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);                
-- @D2A End
