-- ==========================================================================
-- Licensed Materials - Property of IBM
-- "Restricted Materials of IBM"
--
-- 5724-C01
-- 5698-WAZ
--
-- (C) COPYRIGHT IBM CORP. 2003, 2004. ALL RIGHTS RESERVED.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- ==========================================================================
--
-- File Information: wsappsvr/src/tedw_apps_etl/fixpack_v1103/izy/etl/sql/izy_m10_s060_fact.db2, waspac, waspac_512, 200403261523
-- 
-- Revision: 1.10
-- 
-- Date: 3/24/04 17:52:25
-- 
-- Description: IBM Tivoli Monitoring  for WebSphere file for moving data 
--              from the tables in the Central Data Warehouse (TWH_CDW) 
--              to the fact dimension tables in the Data mart (TWH_Mart) via
--              staging tables in the data mart.  
--  
-- ==========================================================================
--  Change Activity:
--  $D0 115192 06/04/03  lmd  new file: Add support for WAS 5.0
--  $D1 118844 09/28/03  lmd  Performance enhancements
--  $D2 IY51267 01/27/05  fr  Change WAS 5.0 modeling to common data model
--  $D3 129959  03/09/04 lmd  Improve performance of pruning Deletes     
--  $D5 130986  03/23/04 lmd  Add 'where not exists' clauses to prevent duplicates
--  ==========================================================================
-- 
--
---------------------------
-- IZY_m10_s060_fact step
---------------------------
-- 
------------------------------------------------------------------------
--  Prune data from hourly, daily, weekly, monthly fact tables
------  according to the settings in the izy.Prune_Mart_Control table            
------  Log the pruning in the izy.prune_mart_log table
------  Remove any entries from the log where no pruning took place.                 
------------------------------------------------------------------------             
                             
-- @D3A Added temporary table to store actual pruning date for performance
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.Stage_PMart5_Ctl;

--#EXECUTE_AT_TARGET
CREATE TABLE IZY.Stage_PMart5_Ctl (
        Table_Name         VARCHAR(120) NOT NULL,
        PMart_Ctl_Date     timestamp,
       PRIMARY KEY (Table_Name)
);      

--------------------------------------------------------------------------------
-- log the pruning of the hourly fact table IZY.F_CFGMGR_HOUR
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_CFGMGR_HOUR',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_CFGMGR_HOUR')
  ); 

--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_CFGMGR_HOUR',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_CFGMGR_HOUR'),
     (select count(*) FROM IZY.F_CFGMGR_HOUR f  WHERE
        f.meas_hour  < 
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_CFGMGR_HOUR')
     )      
  ); 

-- prune the hourly fact table IZY.F_CFGMGR_HOUR
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_CFGMGR_HOUR f
WHERE
    f.meas_hour < 
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_CFGMGR_HOUR')
;

--------------------------------------------------------------------------------
-- log the pruning of the daily fact table IZY.F_CFGMGR_DAY
--------------------------------------------------------------------------------
-- @D3A For performance, calcufate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_CFGMGR_DAY',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_CFGMGR_DAY')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_CFGMGR_DAY',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_CFGMGR_DAY'),
     (select count(*) FROM IZY.F_CFGMGR_DAY f  WHERE
        f.meas_date < 
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_CFGMGR_DAY')
     )      
  ); 

-- prune the daily fact table IZY.F_CFGMGR_DAY
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_CFGMGR_DAY f
WHERE
   f.meas_date < 
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_CFGMGR_DAY')
;

--------------------------------------------------------------------------------
-- log the pruning of the weekly fact table IZY.F_CFGMGR_WEEK
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_CFGMGR_WEEK',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_CFGMGR_WEEK')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_CFGMGR_WEEK',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_CFGMGR_WEEK'),
     (select count(*) FROM IZY.F_CFGMGR_WEEK f  WHERE
       f.meas_date <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_CFGMGR_WEEK')
     )      
  ); 

-- prune the weekly fact table IZY.F_CFGMGR_WEEK
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_CFGMGR_WEEK f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_CFGMGR_WEEK')
;


--------------------------------------------------------------------------------
-- log the pruning of the monthly fact table IZY.F_CFGMGR_MONTH
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_CFGMGR_MONTH',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_CFGMGR_MONTH')
  ); 

--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_CFGMGR_MONTH',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_CFGMGR_MONTH'),
     (select count(*) FROM IZY.F_CFGMGR_MONTH f  WHERE
       f.meas_date < 
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_CFGMGR_MONTH')
     )      
  ); 

-- prune the monthly fact table IZY.F_CFGMGR_MONTH
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_CFGMGR_MONTH f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_CFGMGR_MONTH')
;

--------------------------------------------------------------------------------
-- log the pruning of the hourly fact table IZY.F_APPLSRV5_HOUR
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_APPLSRV5_HOUR',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLSRV5_HOUR')
  ); 

--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLSRV5_HOUR',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLSRV5_HOUR'),
     (select count(*) FROM IZY.F_APPLSRV5_HOUR f  WHERE
      f.meas_hour < 
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLSRV5_HOUR')
     )      
  ); 

-- prune the hourly fact table IZY.F_APPLSRV5_HOUR
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLSRV5_HOUR f
WHERE
   f.meas_hour < 
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLSRV5_HOUR')
;

--------------------------------------------------------------------------------
-- log the pruning of the daily fact table IZY.F_APPLSRV5_DAY
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_APPLSRV5_DAY',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLSRV5_DAY')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLSRV5_DAY',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLSRV5_DAY'),
     (select count(*) FROM IZY.F_APPLSRV5_DAY f  WHERE
      f.meas_date <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLSRV5_DAY')
     )   
  ); 

-- prune the daily fact table IZY.F_APPLSRV5_DAY
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLSRV5_DAY f
WHERE
   f.meas_date < 
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLSRV5_DAY')
;

--------------------------------------------------------------------------------
-- log the pruning of the weekly fact table IZY.F_APPLSRV5_WEEK
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_APPLSRV5_WEEK',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLSRV5_WEEK')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLSRV5_WEEK',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLSRV5_WEEK'),
     (select count(*) FROM IZY.F_APPLSRV5_WEEK f  WHERE
      f.meas_date <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLSRV5_WEEK')
     )      
  ); 

-- prune the weekly fact table IZY.F_APPLSRV5_WEEK
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLSRV5_WEEK f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLSRV5_WEEK')
;

--------------------------------------------------------------------------------
-- log the pruning of the monthly fact table IZY.F_APPLSRV5_MONTH
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_APPLSRV5_MONTH',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLSRV5_MONTH')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLSRV5_MONTH',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLSRV5_MONTH'),
     (select count(*) FROM IZY.F_APPLSRV5_MONTH f  WHERE
      f.meas_date < 
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLSRV5_MONTH')
     )     
  ); 

-- prune the monthly fact table IZY.F_APPLSRV5_MONTH
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLSRV5_MONTH f
WHERE
   f.meas_date < 
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLSRV5_MONTH')
;                                               

--------------------------------------------------------------------------------
-- log the pruning of the hourly fact table IZY.F_APPLCMP5_HOUR
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_APPLCMP5_HOUR',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLCMP5_HOUR')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLCMP5_HOUR',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLCMP5_HOUR'), 
     (select count(*) FROM IZY.F_APPLCMP5_HOUR f  WHERE
      f.meas_hour <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLCMP5_HOUR')
     )      
  ); 

-- prune the hourly fact table IZY.F_APPLCMP5_HOUR
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLCMP5_HOUR f
WHERE
   f.meas_hour  <  
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLCMP5_HOUR')
;

--------------------------------------------------------------------------------
-- log the pruning of the daily fact table IZY.F_APPLCMP5_DAY
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_APPLCMP5_DAY',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLCMP5_DAY')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLCMP5_DAY',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLCMP5_DAY'),
     (select count(*) FROM IZY.F_APPLCMP5_DAY f  WHERE
      f.meas_date <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLCMP5_DAY')
     )      
  ); 

-- prune the daily fact table IZY.F_APPLCMP5_DAY
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLCMP5_DAY f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLCMP5_DAY')
;

--------------------------------------------------------------------------------
-- log the pruning of the weekly fact table IZY.F_APPLCMP5_WEEK
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_APPLCMP5_WEEK',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLCMP5_WEEK')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLCMP5_WEEK',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLCMP5_WEEK'), 
     (select count(*) FROM IZY.F_APPLCMP5_WEEK f  WHERE
      f.meas_date < 
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLCMP5_WEEK')
     )      
  ); 

-- prune the weekly fact table IZY.F_APPLCMP5_WEEK
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLCMP5_WEEK f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLCMP5_WEEK')
;

--------------------------------------------------------------------------------
-- log the pruning of the monthly fact table IZY.F_APPLCMP5_MONTH
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_APPLCMP5_MONTH',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_APPLCMP5_MONTH')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_APPLCMP5_MONTH',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_APPLCMP5_MONTH'),
     (select count(*) FROM IZY.F_APPLCMP5_MONTH f  WHERE
      f.meas_date <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_APPLCMP5_MONTH')
     )      
  ); 

-- prune the monthly fact table IZY.F_APPLCMP5_MONTH
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_APPLCMP5_MONTH f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_APPLCMP5_MONTH')
;


--------------------------------------------------------------------------------
-- log the pruning of the hourly fact table IZY.F_SUBCMP5_HOUR
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_SUBCMP5_HOUR',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_SUBCMP5_HOUR')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_SUBCMP5_HOUR',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_SUBCMP5_HOUR'),
     
     (select count(*) FROM IZY.F_SUBCMP5_HOUR f  WHERE
      f.meas_hour <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_SUBCMP5_HOUR')
     )      
  ); 

-- prune the hourly fact table IZY.F_SUBCMP5_HOUR
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_SUBCMP5_HOUR f
WHERE
   f.meas_hour <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_SUBCMP5_HOUR')
;

--------------------------------------------------------------------------------
-- log the pruning of the daily fact table IZY.F_SUBCMP5_DAY
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_SUBCMP5_DAY',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_SUBCMP5_DAY')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_SUBCMP5_DAY',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_SUBCMP5_DAY'), 
     (select count(*) FROM IZY.F_SUBCMP5_DAY f  WHERE
      f.meas_date <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_SUBCMP5_DAY')
     )      
  ); 

-- prune the daily fact table IZY.F_SUBCMP5_DAY
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_SUBCMP5_DAY f
WHERE
   f.meas_date < 
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_SUBCMP5_DAY')
;

--------------------------------------------------------------------------------
-- log the pruning of the weekly fact table IZY.F_SUBCMP5_WEEK
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_SUBCMP5_WEEK',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_SUBCMP5_WEEK')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_SUBCMP5_WEEK',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_SUBCMP5_WEEK'),
     (select count(*) FROM IZY.F_SUBCMP5_WEEK f  WHERE
      f.meas_date < 
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_SUBCMP5_WEEK')
     )      
  ); 

-- prune the weekly fact table IZY.F_SUBCMP5_WEEK
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_SUBCMP5_WEEK f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_SUBCMP5_WEEK')
;


--------------------------------------------------------------------------------
-- log the pruning of the monthly fact table IZY.F_SUBCMP_MONTH
--------------------------------------------------------------------------------
-- @D3A For performance, calculate the date to compare for pruning
--#EXECUTE_AT_TARGET
insert into IZY.Stage_PMart5_Ctl  values 
 ('IZY.F_SUBCMP5_MONTH',
   (CURRENT timestamp - CURRENT timezone) - 
    (SELECT PMartC_Duration FROM IZY.Prune_Mart_Control p 
        WHERE p.Table_Name = 'IZY.F_SUBCMP5_MONTH')
  ); 
  
--#EXECUTE_AT_TARGET
insert into IZY.prune_mart_log  values 
  ( 
     current timestamp - current timezone,  
     'IZY.F_SUBCMP5_MONTH',
     (select PMartC_Duration from IZY.prune_mart_control where  
             Table_Name='IZY.F_SUBCMP5_MONTH'),
     (select count(*) FROM IZY.F_SUBCMP5_MONTH f  WHERE
      f.meas_date <
        (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
        WHERE p.Table_Name= 'IZY.F_SUBCMP5_MONTH')
     )      
  ); 

-- prune the monthly fact table IZY.F_SUBCMP5_MONTH
--#EXECUTE_AT_TARGET
DELETE FROM IZY.F_SUBCMP5_MONTH f
WHERE
   f.meas_date <
    (SELECT PMart_Ctl_Date FROM IZY.Stage_PMart5_Ctl p
     WHERE p.Table_Name = 'IZY.F_SUBCMP5_MONTH')
;                           


-- delete entries in prune log where nothing was pruned
--#EXECUTE_AT_TARGET
DELETE FROM IZY.PRUNE_MART_LOG 
  WHERE NUMBER_PRUNED = 0
;


--------------------------------------------------------------------------------
-- @d3C Get the high value msmt_id for the window and set for all tables at once.
-- Find max msmt_id only one time to improve performance.
--------------------------------------------------------------------------------

update TWG.Extract_Control ec set 
 ec.extctl_to_intseq =  ( select max(msmt_id) from twg.msmt)
where 
 ec.extctl_source='TWG.MSMT' and
 ec.extctl_target in ('IZY.F_CFGMGR_HOUR',
                      'IZY.F_APPL5_HOUR',
                      'IZY.F_APCP5_HOUR',
                      'IZY.STAGE_F_SC5_HOUR1',
                      'IZY.STAGE_F_SC5_HOUR2',
                      'IZY.STAGE_F_SC5_HOUR3',
                      'IZY.STAGE_F_SC5_HOUR4',
                      'IZY.STAGE_F_SC5_HOUR5',
                      'IZY.STAGE_F_SC5_HOUR6',
                      'IZY.STAGE_F_SC5_HOUR7',
                      'IZY.STAGE_F_SC5_HOUR8',
                      'IZY.STAGE_F_SC5_HOUR9',
                      'IZY.STAGE_F_SC5_HOUR10',
                      'IZY.STAGE_F_SC5_HOUR11',
                      'IZY.STAGE_F_SC5_HOUR12'
                       ) 
 AND
-- @D1C Change count(*) to exists test with true test query on extract_control.extctl_to_intseq stops of all rows
 exists (select 1 from twg.msmt where ec.extctl_to_intseq = ec.extctl_to_intseq ) 
;

--------------------------------------------------------------------------------
-- insert the facts for WebSphere Configuration Manager (WAS_NODE_AGENT) component
--------------------------------------------------------------------------------

-- @D2A Added staging table
--#IGNORE_ERROR
drop table IZY.Stage_CfgMgr;

create table IZY.Stage_CfgMgr (
CfgMgr_id integer not null,
Node_id integer, 
Node_dttm  timestamp,
cell_id integer,
primary key(CfgMgr_id)
);

insert into IZY.Stage_CfgMgr  
select 
 co1.comp_id as CfgMgr_id,
 cr1.comp_source_id as Node_id,
 max(ca.compattr_strt_dttm) as Node_dttm,
 cr3.comp_source_id as cell_id
from
 TWG.Cur_Comp co1,
 TWG.Cur_CompReln cr1,
 TWG.Cur_compReln cr2,       
 TWG.Cur_compReln cr3,       
 TWG.Cur_CompAttr ca
where
 co1.comptyp_cd = 'WAS_NODE_AGENT' and         
 cr1.comp_target_id=co1.comp_id and
 cr1.relntyp_cd='PCHILD' and
-- VERSION and MANUFACTURER are attributes on WAS_NODE_AGENT but MANUFACTURER does not change.
-- and OS_NAME (contains OS Version) on the J2EE_NODE can change
 cr1.comp_source_id = cr2.comp_source_id and 
 cr2.relntyp_cd='PCHILD' and
-- ca.comp_id in (node agent, j2ee_node, j2ee_server or node agent)
 ca.comp_id in (co1.comp_id, cr1.comp_source_id, cr2.comp_target_id) and 
 ca.attrtyp_cd in ('OS_NAME','VERSION') and
-- comp_source_id = node, comp_target_id=cell
 cr1.comp_source_id=cr3.comp_target_id and
 cr3.relntyp_cd='PCHILD' 
group by
 co1.comp_id, cr1.comp_source_id,  cr3.comp_source_id
; 

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_CgMgr_HOUR;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against AdminServer 
create table IZY.STAGE_F_CgMgr_HOUR (
    CfgMgr_Comp_ID      integer not null,
    Node_Comp_id	integer not null,
    XQ_node_dttm	timestamp not null,
    cell_attr_id	integer not null,
    metric_id           integer not null,
    meas_hour           timestamp not null,
    min_value           double,
    max_value           double,
    avg_value           double,
    total_value         double,
    sample_count        integer,
	primary key (CfgMgr_Comp_ID, node_Comp_id, XQ_node_dttm, cell_attr_id, metric_id , meas_hour )
);

--#INSERT_INTO_TARGET
insert into IZY.STAGE_F_CgMgr_HOUR
select 
 m.comp_id as CfgMgr_Comp_ID , 
 s1.Node_id as Node_Comp_id,
 max(s1.Node_dttm) as XQ_Node_dttm,
 s1.cell_id as cell_attr_id, 
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value,
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_CfgMgr s1,  
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.F_CFGMGR_HOUR' and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq and
 m.tmsum_cd='H' and
 m.comp_id = s1.CfgMgr_id             
group by
-- node agent, node, cell, msmt 
 m.comp_id, s1.node_id, s1.cell_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;                                           

--#EXECUTE_AT_TARGET
-- @D5C Add 'where not exists' clauses to prevent failure on duplicates
insert into IZY.F_CFGMGR_HOUR
select * from IZY.STAGE_F_CgMgr_HOUR a
where not exists
(select 1 from 
IZY.F_CFGMGR_HOUR b
where 
a.CfgMgr_Comp_ID=b.CfgMgr_Comp_ID and
a.Node_Comp_id=b.Node_Comp_ID and
a.XQ_node_dttm=b.XQ_node_dttm and
a.cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour)
;

-- confirm that the insertion of 
-- the facts for WAS Node Agent has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone),
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.F_CFGMGR_HOUR'
; 

------------------------------------------------------------------------------------
-- insert the facts for WebSphere Application Server 5.x (IZY_APPL_SVR_V5) component
------------------------------------------------------------------------------------
-- @D3D get the high value for the window: now done up front for all entries

--#IGNORE_ERROR
-- @d2A Added staging tables
drop table IZY.Stage_applSrv5;

create table IZY.Stage_applSrv5(
 ApplSrv_ID 	integer not null,
 Node_ID	integer,
 Node_dttm timestamp,
 cell_id 	integer,
primary key(ApplSrv_ID)
);

insert into IZY.Stage_applSrv5
select
 co1.comp_id as ApplSrv_ID, 
 cr1.comp_source_id as Node_ID,
 max(ca.compattr_strt_dttm) as Node_dttm,
 cr3.comp_source_id as cell_id
from
 TWG.Cur_Comp co1,
 TWG.Cur_CompReln cr1,
 TWG.Cur_CompReln cr2,
 TWG.Cur_CompReln cr3,
 TWG.Cur_CompAttr ca   
where
 co1.comptyp_cd = 'J2EE_SERVER' and
 co1.comp_id = cr1.comp_target_id and
 cr1.relntyp_cd='PCHILD'and 
-- @D2C VERSION and MANUFACTURER are attributes on WAS_NODE_AGENT but MANUFACTURER does not change.
-- and OS_NAME (contains OS Version) on the J2EE_NODE can change
-- cr1.comp_source_id = J2EE_Node
 cr1.comp_source_id = cr2.comp_source_id and 
 cr2.relntyp_cd='PCHILD' and
-- ca.comp_id in (j2ee_server, j2ee_node, j2ee_server or node agent)
 ca.comp_id in (co1.comp_id, cr1.comp_source_id, cr2.comp_target_id) and
 ca.attrtyp_cd in ('VERSION', 'OS_NAME') and
-- comp_source_id = node, comp_target_id=cell
 cr1.comp_source_id = cr3.comp_target_id and
 cr3.relntyp_cd='PCHILD'                    
group by
 co1.comp_id, cr1.comp_source_id, cr3.comp_source_id
 ;
 


--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_APPL5_HOUR;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against Application Server
create table IZY.STAGE_F_APPL5_HOUR (
    ApplSrv_Comp_ID     integer not null,
    Node_Comp_ID        integer not null,
    XQ_Node_dttm	timestamp not null,
    cell_attr_ID        integer not null,
    metric_id           integer not null,
    meas_hour           timestamp not null,
    min_value           double,
    max_value           double,
    avg_value           double,
    total_value         double,
    sample_count        integer,
    primary key (ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);


--#INSERT_INTO_TARGET
insert into IZY.STAGE_F_APPL5_HOUR
select 
 m.comp_id as ApplSrv_Comp_ID, 
 s1.Node_id as Node_Comp_ID,
 max(s1.Node_dttm) as XQ_Node_dttm,
 s1.cell_id as cell_attr_id,
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value,
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_applSrv5 s1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.F_APPL5_HOUR' and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq and
 m.tmsum_cd='H' and
 m.comp_id=s1.ApplSrv_id
group by
-- appl server, node, cell, msmt 
 m.comp_id, s1.node_id, s1.cell_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;

--#EXECUTE_AT_TARGET
insert into IZY.F_APPLSRV5_HOUR
select * from IZY.STAGE_F_APPL5_HOUR a
where not exists
(select 1 from 
IZY.F_APPLSRV5_HOUR b
where 
a.ApplSrv_Comp_ID=b.ApplSrv_Comp_ID and
a.Node_Comp_ID=b.Node_Comp_ID and
a.XQ_Node_dttm=b.XQ_Node_dttm and
a.Cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour)
;

-- confirm that the insertion of 
-- the facts for WAS Application Server has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.F_APPL5_HOUR'
;                                                 


------------------------------------------------------------------------------------
-- insert the facts for the omponents of the Application Server version 5.x
--       IZY_WAS_DATA_SRC,IZY_WAS_EJB, IZY_WAS_SERVLET_SESS, IZY_WAS_THREAD_POOL,IZYWAS_TRANSACT_MGR, IZYWAS_WEB_APPL
--       IZY_WAS_DYNACACHE, IZY_WAS_J2C_FACT    
------------------------------------------------------------------------------------
-- @D2A Added staging tables to improve performance
--#IGNORE_ERROR
drop table IZY.Stage_apcmp5_apsrv;

create table IZY.Stage_apcmp5_apsrv (
applcmp_id integer not null,
applsvr_id integer, 
primary key(applcmp_id)
);

insert into IZY.Stage_apcmp5_apsrv
select distinct
 co1.comp_id as applcmp_id,
 cr1.comp_source_id as applsvr_id
from
 TWG.Cur_Comp co1,
 TWG.Cur_CompReln cr1
where
 co1.comptyp_cd in ('IZY_WAS_DATA_SRC',
                    'IZY_WAS_EJB',
                    'IZY_WAS_JVM',
                    'IZY_WAS_SVLT_SESS',
                    'IZY_WAS_THREAD_PL',
                    'IZY_WAS_TRANS_MGR',
                    'IZY_WAS_WEB_APPL',
                    'IZY_WAS_DYNACACHE', 
                    'IZY_WAS_J2C_FACT'
                   ) and
 cr1.comp_target_id=co1.comp_id and
 cr1.relntyp_cd='PCHILD' 
; 

-- select count(*) from IZY.Stage_apcmp5_apsrv;

--#IGNORE_ERROR
drop table   IZY.Stage_apcmp5_node;

create table IZY.Stage_apcmp5_node (
applcmp_id integer not null,
node_id integer ,
primary key(applcmp_id)
);

insert into IZY.Stage_apcmp5_node
select distinct
 co1.applcmp_id as applcmp_id,
 cr1.comp_source_id as node_id
from
 IZY.Stage_apcmp5_apsrv co1 ,
 TWG.Cur_compReln cr1
where
-- web appl or data source = comp_target_id = co1.applcmp_id  
 cr1.comp_target_id=co1.applsvr_id and
 cr1.relntyp_cd='PCHILD' 
; 

-- select count(*) from IZY.Stage_apcmp5_node;



--#IGNORE_ERROR
drop table IZY.Stage_apcmp5_Attr;

create table IZY.Stage_apcmp5_Attr (
applcmp_id integer not null,
node_dttm  timestamp,
primary key(applcmp_id)
);

insert into IZY.Stage_apcmp5_Attr
select
 co1.applcmp_id as applcmp_id,
 max(ca.compattr_strt_dttm) as node_dttm
from
 IZY.Stage_apcmp5_node co1,
 TWG.Cur_compReln cr1,
 TWG.Cur_compAttr ca
where
 co1.node_id = cr1.comp_source_id and
 cr1.relntyp_cd='PCHILD'and 
-- @D2C VERSION and MANUFACTURER are attributes on WAS_NODE_AGENT but MANUFACTURER does not change.
-- and OS_NAME (contains OS Version) on the J2EE_NODE can change
 ca.comp_id in (co1.node_id,cr1.comp_target_id) and
 ca.attrtyp_cd in ('VERSION', 'OS_NAME') 
group by 
co1.applcmp_id
; 

-- select count(*) from IZY.Stage_apcmp5_Attr;

--#IGNORE_ERROR
drop table IZY.Stage_apcmp5_cell;

create table IZY.Stage_apcmp5_cell (
applcmp_id integer not null,
cell_id integer,
primary key(applcmp_id)
);

insert into IZY.Stage_apcmp5_cell
select distinct
 co1.applcmp_id as applcmp_id,
 cr1.comp_source_id as cell_id
from
 IZY.Stage_apcmp5_node co1,
 TWG.Cur_compReln cr1
where
 cr1.comp_target_id=co1.node_id and
 cr1.relntyp_cd='PCHILD' 
; 

-- select count(*) from IZY.Stage_apcmp_host;

--#IGNORE_ERROR
drop table IZY.Stage_apcmp5_All;

create table IZY.Stage_apcmp5_All (
applcmp_id integer not null,
applsvr_id integer,
node_id integer,
node_dttm timestamp,
cell_id integer,
primary key(applcmp_id)
);

insert into IZY.Stage_apcmp5_All
select distinct
 co1.applcmp_id as applcmp_id,
 co1.applsvr_id as applsvr_id,
 co2.node_id as  node_id,
 co3.node_dttm as node_dttm,
 co4.cell_id as cell_id
from
 IZY.Stage_apcmp5_apsrv co1,
 IZY.Stage_apcmp5_node  co2,
 IZY.Stage_apcmp5_Attr co3,
 IZY.Stage_apcmp5_cell co4
where
 co1.applcmp_id=co2.applcmp_id and
 co1.applcmp_id=co3.applcmp_id and
 co1.applcmp_id=co4.applcmp_id and
 exists ( select 1 from IZY.Stage_apcmp5_Attr )
;

insert into IZY.Stage_apcmp_All
select distinct
 co1.applcmp_id as applcmp_id,
 co1.applsvr_id as applsvr_id,
 co2.node_id as  node_id,
 current timestamp - current timezone as node_dttm,
 co4.cell_id as cell_id
from
 IZY.Stage_apcmp5_apsrv co1,
 IZY.Stage_apcmp5_node co2,
 IZY.Stage_apcmp5_cell co4
where
 co1.applcmp_id=co2.applcmp_id and
 co1.applcmp_id=co4.applcmp_id and
 not exists ( select 1 from IZY.Stage_apcmp5_Attr )
;

-- select count(*) from izy.stage_apcmp5_all;


-- @D3D get the high value for the window: now done up front for all entries

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_APCP5_HOUR;

--#EXECUTE_AT_TARGET
-- Staging measurement hour fact table for all metrics against Application Server components
create table IZY.STAGE_F_APCP5_HOUR (
    ApplCmp_Comp_ID     integer not null,
    ApplSrv_Comp_ID     integer not null,
    Node_Comp_ID        integer not null,
    XQ_Node_dttm	timestamp not null,
    cell_attr_id	integer not null,
    metric_id           integer not null,
    meas_hour           timestamp not null,
    min_value           double,
    max_value           double,
    avg_value           double,
    total_value         double,
    sample_count        integer,
primary key (ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);

--#INSERT_INTO_TARGET
insert into IZY.STAGE_F_APCP5_HOUR
select 
 m.comp_id as ApplCmp_Comp_ID, 
 s1.applsvr_id as ApplSrv_Comp_ID,
 s1.node_id as Node_Comp_ID,
 max(s1.node_dttm) as XQ_Node_dttm,
 s1.cell_id as cell_attr_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_apcmp5_All s1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.F_APCP5_HOUR' and
 m.msmt_id > ec.extctl_from_intseq and
 m.msmt_id <= ec.extctl_to_intseq and
 m.tmsum_cd='H' and
 s1.applcmp_id=m.comp_id 
group by
-- components, appl server, node, cell, msmt 
 m.comp_id, s1.applsvr_id, s1.node_id, s1.cell_id,
 m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_APPLCMP5_HOUR
select * from IZY.STAGE_F_APCP5_HOUR a
-- @d3a Add where not exists to prevent duplicate data error
where not exists 
( select 1 from
IZY.F_APPLCMP5_HOUR b
where
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.Node_Comp_ID=b.Node_Comp_ID and
a.xq_node_dttm=b.xq_node_dttm and
a.cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);



-- confirm that the insertion of the facts for the Subcomponents of the Application Server:
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.F_APCP5_HOUR'
;                                     

------------------------------------------------------------------------------------
-- insert the facts for the Subcomponents items of Data Sources and Web Applications:
------------------------------------------------------------------------------------


-- @D2A Added staging tables to improve performance
--#IGNORE_ERROR
drop table IZY.Stage_sbcp5_apcmp;

create table IZY.Stage_sbcp5_apcmp (
subcomp_id integer not null,
applcmp_id integer,
primary key(subcomp_id)
);

insert into IZY.Stage_sbcp5_apcmp
select distinct
 co1.comp_id as subcomp_id,
 cr1.comp_source_id as applcmp_id
from
 TWG.Cur_Comp co1,
 TWG.Cur_compReln cr1
where
 co1.comptyp_cd in ('IZY_WAS_CONN_PL','IZY_WAS_SERVLET', 'IZY_WAS_J2C_POOL') and
 cr1.comp_target_id=co1.comp_id and
 cr1.relntyp_cd='PCHILD' 
; 

-- select count(*) from IZY.Stage_sbcp5_apcmp;

--#IGNORE_ERROR
drop table   IZY.Stage_sbcp5_apsrv;

create table IZY.Stage_sbcp5_apsrv (
subcomp_id integer not null,
applsvr_id integer ,
primary key(subcomp_id)
);

insert into IZY.Stage_sbcp5_apsrv
select distinct
 co1.subcomp_id as subcomp_id,
 cr1.comp_source_id as applsvr_id
from
 IZY.Stage_sbcp5_apcmp co1 ,
 TWG.Cur_compReln cr1
where
-- web appl or data source = comp_target_id = co1.applcmp_id  
 cr1.comp_target_id=co1.applcmp_id and
 cr1.relntyp_cd='PCHILD' 
; 

-- select count(*) from IZY.Stage_sbcp5_apsrv;

--#IGNORE_ERROR
drop table IZY.Stage_sbcp5_node;

create table IZY.Stage_sbcp5_node (
subcomp_id integer not null,
node_id integer,
primary key(subcomp_id)
);

insert into IZY.Stage_sbcp5_node
select distinct
 co1.subcomp_id as subcomp_id,
 cr1.comp_source_id as node_id
from
 IZY.Stage_sbcp5_apsrv co1,
 TWG.Cur_compReln cr1
where
 cr1.comp_target_id=co1.applsvr_id and
 cr1.relntyp_cd='PCHILD' 
; 

-- select count(*) from IZY.Stage_sbcp5_node;

--#IGNORE_ERROR
drop table IZY.Stage_sbcp5_ASattr;

create table IZY.Stage_sbcp5_ASattr (
subcomp_id integer not null,
node_dttm  timestamp,
primary key(subcomp_id)
);

insert into IZY.Stage_sbcp5_ASattr
select
 co1.subcomp_id as subcomp_id,
 max(ca.compattr_strt_dttm) as node_dttm
from
 IZY.Stage_sbcp5_node co1,
 TWG.Cur_compReln cr1,
 TWG.Cur_compAttr ca
where
 co1.node_id = cr1.comp_source_id and
 cr1.relntyp_cd='PCHILD'and 
 ca.comp_id in (co1.node_id,cr1.comp_target_id) and
 ca.attrtyp_cd in ('VERSION', 'OS_NAME') 
group by 
co1.subcomp_id
; 

-- select count(*) from IZY.Stage_sbcp5_ASattr;

--#IGNORE_ERROR
drop table IZY.Stage_sbcp5_cell;

create table IZY.Stage_sbcp5_cell (
subcomp_id integer not null,
cell_attr_id integer,
primary key(subcomp_id)
);

insert into IZY.Stage_sbcp5_cell
select distinct
 co1.subcomp_id as subcomp_id,
 cr1.comp_source_id as cell_attr_id
from
 IZY.Stage_sbcp5_node co1,
 TWG.Cur_compReln cr1
where
 cr1.comp_target_id=co1.node_id and
 cr1.relntyp_cd='PCHILD' 
; 

-- select count(*) from IZY.Stage_sbcp5_cell;

--#IGNORE_ERROR
drop table IZY.Stage_sbcp5_All;

create table IZY.Stage_sbcp5_All (
subcomp_id integer not null,
applcmp_id integer,
applsvr_id integer,
node_id integer,
node_dttm timestamp,
cell_attr_id integer,
primary key(subcomp_id)
);

insert into IZY.Stage_sbcp5_All
select
 co1.subcomp_id as subcomp_id,
 co1.applcmp_id as applcmp_id,
 co2.applsvr_id as applsvr_id,
 co3.node_id as  node_id,
 co4.node_dttm as node_dttm,
 co5.cell_attr_id as cell_attr_id
from
 IZY.Stage_sbcp5_apcmp co1,
 IZY.Stage_sbcp5_apsrv co2,
 IZY.Stage_sbcp5_node co3,
 IZY.Stage_sbcp5_ASattr co4,
 IZY.Stage_sbcp5_cell co5
where
 co1.subcomp_id=co2.subcomp_id and
 co1.subcomp_id=co3.subcomp_id and
 co1.subcomp_id=co4.subcomp_id and
 co1.subcomp_id=co5.subcomp_id and
 exists ( select 1 from IZY.Stage_sbcp5_ASattr )
; 

insert into IZY.Stage_sbcp5_All
select
 co1.subcomp_id as subcomp_id,
 co1.applcmp_id as applcmp_id,
 co2.applsvr_id as applsvr_id,
 co3.node_id as  node_id,
 current timestamp - current timezone as node_dttm,
 co5.cell_attr_id as cell_attr_id
from
 IZY.Stage_sbcp5_apcmp co1,
 IZY.Stage_sbcp5_apsrv co2,
 IZY.Stage_sbcp5_node co3,
 IZY.Stage_sbcp5_ASattr co4,
 IZY.Stage_sbcp5_cell co5
where
 co1.subcomp_id=co2.subcomp_id and
 co1.subcomp_id=co3.subcomp_id and
 co1.subcomp_id=co4.subcomp_id and
 co1.subcomp_id=co5.subcomp_id and
 not exists ( select 1 from IZY.Stage_sbcp5_ASattr )
; 

-- select count(*) from IZY.Stage_sbcp5_All;

-- @D1A END: Added staging tables


----------------------------------------------------------------------------------
-- PERFORMANCE AND LOG TUNING
-- In order to lower down the space needed in the
-- transaction log , and in order to keep good performance (for the sub components
-- that include the large number of servlets), I have
-- divided the data by chunk of 8000 on 12 staging tables
-- If the number of rows that need to be inserted is greater than 12 * 8000
-- ( from_intseq - to_intseq > 12 * 8000) , then we extract data by chunk of 250000
-- if not all the data is inserted into the IZY.STAGE_F_SC5_HOUR
-- The first table IZY.STAGE_F_SC5_HOUR1 may have more than 8000 rows if
-- the total rows is greater than 12 * 8000, but all the subsequent staging tables
-- should have 8000 rows only.
-- the "to_intseq" should always be updated to the max (msmt_id) so that all staging 
-- tables keep a record of the total number of rows inserte into the final Fact table
-------------------------------------------------------------------------------------

-------- PART 1

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SC5_HOUR1;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SC5_HOUR1 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  Node_Comp_ID    integer not null,
  XQ_Node_dttm		timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

        
--#INSERT_INTO_TARGET
-- @D2A Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SC5_HOUR1
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.node_id as Node_Comp_ID,
 max(co1.node_dttm) as XQ_Node_dttm,
 co1.cell_attr_id as cell_attr_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcp5_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR1' and
 m.msmt_id > ec.extctl_from_intseq  and
 m.msmt_id <= ec.extctl_to_intseq  - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 11) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.node_id, co1.node_dttm,
 co1.cell_attr_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;



--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR1 a
where not exists (
select 1 from 
IZY.F_SUBCMP5_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.Node_Comp_ID=b.Node_Comp_ID and
a.XQ_Node_dttm=b.XQ_Node_dttm and
a.cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR1'
;


--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR1;

---------- PART 2

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SC5_HOUR2;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SC5_HOUR2 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID       integer not null,
  Node_Comp_ID      integer not null,
  XQ_Node_dttm	timestamp not null,
  cell_attr_id		integer not null,
  metric_id             integer not null,
  meas_hour             timestamp not null,
  min_value             double,
  max_value             double,
  avg_value             double,
  total_value           double,
  sample_count          integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);


-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D2C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SC5_HOUR2
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.node_id as Node_Comp_ID,
 max(co1.node_dttm) as XQ_Node_dttm,
 co1.cell_attr_id as cell_attr_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D2C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcp5_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR2' and
 m.msmt_id > ec.extctl_to_intseq  - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 11) and
 m.msmt_id <= ec.extctl_to_intseq  - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 10) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.node_id, co1.node_dttm,
 co1.cell_attr_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR2 a
where not exists (
select 1 from 
IZY.F_SUBCMP5_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.Node_Comp_ID=b.Node_Comp_ID and
a.XQ_Node_dttm=b.XQ_Node_dttm and
a.cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR2'
;

--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR2;

--- PART 3

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SC5_HOUR3;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SC5_HOUR3 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  Node_Comp_ID    integer not null,
  XQ_Node_dttm		timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SC5_HOUR3
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.node_id as Node_Comp_ID,
 max(co1.node_dttm) as XQ_Node_dttm,
 co1.cell_attr_id as cell_attr_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcp5_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR3' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 10) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 9) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.node_id, co1.node_dttm,
 co1.cell_attr_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR3 a
where not exists (
select 1 from 
IZY.F_SUBCMP5_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.Node_Comp_ID=b.Node_Comp_ID and
a.XQ_Node_dttm=b.XQ_Node_dttm and
a.cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR3'
;


--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR3;

--- PART 4

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SC5_HOUR4;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SC5_HOUR4 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  Node_Comp_ID    integer not null,
  XQ_Node_dttm		timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SC5_HOUR4
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.node_id as Node_Comp_ID,
 max(co1.node_dttm) as XQ_Node_dttm,
 co1.cell_attr_id as cell_attr_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcp5_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR4' and
 m.msmt_id > ec.extctl_to_intseq -  (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 9) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 8) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.node_id, co1.node_dttm,
 co1.cell_attr_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR4 a
where not exists (
select 1 from 
IZY.F_SUBCMP5_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.Node_Comp_ID=b.Node_Comp_ID and
a.XQ_Node_dttm=b.XQ_Node_dttm and
a.cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR4'
;

--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR4;

--- PART 5

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SC5_HOUR5;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SC5_HOUR5 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  Node_Comp_ID    integer not null,
  XQ_Node_dttm		timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SC5_HOUR5
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.node_id as Node_Comp_ID,
 max(co1.node_dttm) as XQ_Node_dttm,
 co1.cell_attr_id as cell_attr_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcp5_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR5' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 8) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 7) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.node_id, co1.node_dttm,
 co1.cell_attr_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR5 a
where not exists (
select 1 from 
IZY.F_SUBCMP5_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.Node_Comp_ID=b.Node_Comp_ID and
a.XQ_Node_dttm=b.XQ_Node_dttm and
a.cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR5'
;

--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR5;

--- PART 6

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SC5_HOUR6;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SC5_HOUR6 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  Node_Comp_ID    integer not null,
  XQ_Node_dttm		timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SC5_HOUR6
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.node_id as Node_Comp_ID,
 max(co1.node_dttm) as XQ_Node_dttm,
 co1.cell_attr_id as cell_attr_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcp5_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR6' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 7) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 6) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.node_id, co1.node_dttm,
 co1.cell_attr_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR6 a
where not exists (
select 1 from 
IZY.F_SUBCMP5_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.Node_Comp_ID=b.Node_Comp_ID and
a.XQ_Node_dttm=b.XQ_Node_dttm and
a.cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR6'
;


--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR6;

--- PART 7

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SC5_HOUR7;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SC5_HOUR7 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  Node_Comp_ID    integer not null,
  XQ_Node_dttm		timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SC5_HOUR7
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.node_id as Node_Comp_ID,
 max(co1.node_dttm) as XQ_Node_dttm,
 co1.cell_attr_id as cell_attr_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcp5_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR7' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 6) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 5) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.node_id, co1.node_dttm,
 co1.cell_attr_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR7 a
where not exists (
select 1 from 
IZY.F_SUBCMP5_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.Node_Comp_ID=b.Node_Comp_ID and
a.XQ_Node_dttm=b.XQ_Node_dttm and
a.cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR7'
;


--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR7;

--- PART 8

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SC5_HOUR8;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SC5_HOUR8 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  Node_Comp_ID    integer not null,
  XQ_Node_dttm		timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SC5_HOUR8
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.node_id as Node_Comp_ID,
 max(co1.node_dttm) as XQ_Node_dttm,
 co1.cell_attr_id as cell_attr_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcp5_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR8' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 5) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 4) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.node_id, co1.node_dttm,
 co1.cell_attr_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR8 a
where not exists (
select 1 from 
IZY.F_SUBCMP5_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.Node_Comp_ID=b.Node_Comp_ID and
a.XQ_Node_dttm=b.XQ_Node_dttm and
a.cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR8'
;

--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR8;

--- PART 9

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SC5_HOUR9;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SC5_HOUR9 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  Node_Comp_ID    integer not null,
  XQ_Node_dttm		timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SC5_HOUR9
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.node_id as Node_Comp_ID,
 max(co1.node_dttm) as XQ_Node_dttm,
 co1.cell_attr_id as cell_attr_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcp5_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR9' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 4) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 3) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.node_id, co1.node_dttm,
 co1.cell_attr_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR9 a
where not exists (
select 1 from 
IZY.F_SUBCMP5_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.Node_Comp_ID=b.Node_Comp_ID and
a.XQ_Node_dttm=b.XQ_Node_dttm and
a.cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR9'
;

--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR9;

--- PART 10

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SC5_HOUR10;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SC5_HOUR10 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  Node_Comp_ID    integer not null,
  XQ_Node_dttm		timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SC5_HOUR10
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.node_id as Node_Comp_ID,
 max(co1.node_dttm) as XQ_Node_dttm,
 co1.cell_attr_id as cell_attr_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcp5_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR10' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 3) and
 m.msmt_id <= ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 2) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.node_id, co1.node_dttm,
 co1.cell_attr_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR10 a
where not exists (
select 1 from 
IZY.F_SUBCMP5_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.Node_Comp_ID=b.Node_Comp_ID and
a.XQ_Node_dttm=b.XQ_Node_dttm and
a.cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR10'
;


--#EXECUTE_AT_TARGET
insert into IZY.STAGE_F_SBCP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR10;

--- PART 11

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SC5_HOUR11;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SC5_HOUR11 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  Node_Comp_ID    integer not null,
  XQ_Node_dttm		timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SC5_HOUR11
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.node_id as Node_Comp_ID,
 max(co1.node_dttm) as XQ_Node_dttm,
 co1.cell_attr_id as cell_attr_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcp5_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR11' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 2) and
 m.msmt_id <= ec.extctl_to_intseq - ((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.node_id, co1.node_dttm,
 co1.cell_attr_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR11 a
where not exists (
select 1 from 
IZY.F_SUBCMP5_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.Node_Comp_ID=b.Node_Comp_ID and
a.XQ_Node_dttm=b.XQ_Node_dttm and
a.cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR11'
;

--#EXECUTE_AT_TARGET
-- @D5C Add 'where not exists' clauses to prevent failure on duplicates
insert into IZY.STAGE_F_SBCP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR11;

--- PART 12

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table IZY.STAGE_F_SC5_HOUR12;

--#EXECUTE_AT_TARGET
-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SC5_HOUR12 (
  SubCmp_Comp_ID        integer not null,
  ApplCmp_Comp_ID       integer not null,
  ApplSrv_Comp_ID     integer not null,
  Node_Comp_ID    integer not null,
  XQ_Node_dttm		timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);

-- @D3D get the high value for the window: now done up front for all entries

--#INSERT_INTO_TARGET
-- @D1C Change query to use staging tables to improve performance
insert into IZY.STAGE_F_SC5_HOUR12
select 
 m.comp_id as SubComp_Comp_ID, 
 co1.applcmp_id as ApplCmp_Comp_ID, 
 co1.applsvr_id as ApplSrv_Comp_ID,
 co1.node_id as Node_Comp_ID,
 max(co1.node_dttm) as XQ_Node_dttm,
 co1.cell_attr_id as cell_attr_id,  
 m.msmttyp_id as metric_id, 
 timestamp(m.msmt_strt_dt,m.msmt_strt_tm) as meas_hour, 
-- @D1C changed to use min, max and sum for each respectively
 min(m.msmt_min_val) as min_value, 
 max(m.msmt_max_val) as max_value, 
 avg(m.msmt_avg_val) as avg_value, 
 avg(m.msmt_tot_val) as total_value,
 sum(m.msmt_smpl_cnt) as sample_count
from  
 TWG.Msmt m,
 IZY.Stage_sbcp5_All co1,
 TWG.Extract_control ec
where  
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR12' and
 m.msmt_id > ec.extctl_to_intseq - (((ec.extctl_to_intseq-ec.extctl_from_intseq)/12) * 1) and
 m.msmt_id <= ec.extctl_to_intseq and
 m.tmsum_cd='H' and
 co1.subcomp_id=m.comp_id 
 group by
 m.comp_id, co1.applcmp_id, co1.applsvr_id, co1.node_id, co1.node_dttm,
 co1.cell_attr_id, m.msmttyp_id, m.msmt_strt_dt, m.msmt_strt_tm 
;


--#EXECUTE_AT_TARGET
insert into IZY.F_SUBCMP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR12 a
where not exists (
select 1 from 
IZY.F_SUBCMP5_HOUR b
where
a.subcmp_comp_id=b.subcmp_comp_id and
a.applcmp_comp_id=b.applcmp_comp_id and
a.applsrv_comp_id=b.applsrv_comp_id and
a.Node_Comp_ID=b.Node_Comp_ID and
a.XQ_Node_dttm=b.XQ_Node_dttm and
a.cell_attr_id=b.cell_attr_id and
a.metric_id=b.metric_id and
a.meas_hour=b.meas_hour
);


-- confirm that the insertion of
-- the facts for the Subcomponents of the Data Sources and web applications, 
-- ie. Connection Pool and Servlets
-- has succeeded.
-- insert a row in the TWG.EXTRACT_LOG

insert into twg.extract_log
  (extlog_source, extlog_target, extlog_done_dttm, extlog_from_rawseq, extlog_to_rawseq, extlog_from_intseq, extlog_to_intseq, extlog_from_dttm, extlog_to_dttm)
select
 ec.extctl_source ,
 ec.extctl_target ,
 (current timestamp - current timezone) ,
 ec.extctl_from_rawseq ,
 ec.extctl_to_rawseq ,
 ec.extctl_from_intseq ,
 ec.extctl_to_intseq ,
 ec.extctl_from_dttm ,
 ec.extctl_to_dttm 
from 
 TWG.Extract_control ec
where
 ec.extctl_source = 'TWG.MSMT' and
 ec.extctl_target = 'IZY.STAGE_F_SC5_HOUR12'
;

--#EXECUTE_AT_TARGET
-- @D5C Add 'where not exists' clauses to prevent failure on duplicates
insert into IZY.STAGE_F_SBCP5_HOUR
select * from IZY.STAGE_F_SC5_HOUR12;


