-- ==========================================================================
-- Licensed Materials - Property of IBM
-- "Restricted Materials of IBM"
--
-- 5724-C01
-- 5698-WAZ
--
-- (C) COPYRIGHT IBM CORP. 2002, 2003. ALL RIGHTS RESERVED.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- ==========================================================================
--
-- File Information: wsappsvr/src/tedw_apps_etl/fixpack_v1102/izy/mart/ddl/izy_mart_schema.sql, waspac, waspac_512
-- 
-- Revision: 1.3
-- 
-- Date: 7/11/03 13:30:22
-- 
-- Description: This is the IBM Tivoli Monitoring for WebSphere file for creating
--              data mart tables in the TEDW TWH_Mart DB.
-- 
-- ==========================================================================
--  Change Activity:
--  $D0 115192 06/02/03  lmd  New file: Add support for WAS 5.0 (Delta only)
-- ===========================================================================
-- 
--
-- Tables created by IBM Tivoli Manager for WebSphere
-- Tables used in the data mart database
-- The owner of these tables is IZY
-- IZY is the AVA unique code for IBM Tivoli Manager for WebSphere
--
--#iftag fixpack_2        
------------------------------------------------
-- Component dimension tables 
------------------------------------------------
-- WebSphere Application Server dimension table

-- Add Cluster name for WAS 5.x
Alter table IZY.D_WAS_APPLSRV
 ADD COLUMN ApplSrv_Cluster     varchar(254)
;
                 

-- @D0 Start: Add mart tables for WebSphere 5.0.x 
------------------------------------------------
-- Component dimension tables 
------------------------------------------------
                                                                       
-- WebSphere 5.0.x Cell  dimension table

create table IZY.D_WAS_CELL (
 cell_attr_id    	integer not null,
 Cell_Attr_Val   varchar(254) not null,
 primary key (cell_attr_id)
);

-- WebSphere 5.0 NODE dimension table

create table IZY.D_WAS_NODE(
 Node_Comp_ID        integer not null,
 Node_Comp_Name      varchar(254) not null, 
 XQ_Node_dttm		   timestamp not null,
 Node_Host_Name      varchar(254) not null,
 Node_OS_Type       	varchar(254) not null,
 Node_WAS_Ver       	varchar(254) not null,
 centr_nm  		      varchar(120) not NULL,
 cust_nm		         varchar(120) not null,
 primary key (Node_Comp_ID,XQ_Node_dttm )
);

-- WebSphere 5.0.x Cfgmgr (Node Agent)  dimension table

create table IZY.D_WAS_CFGMGR (
 cfgmgr_comp_id    	integer not null,
 cfgmgr_comp_name    varchar(254) not null,
 cfgmgr_TypeCd	      char(17) not null,
 primary key (cfgmgr_comp_id)
);
                   
-- @D0 End: Add mart tables for WebSphere 5.0.x 

------------------------------------------------
-- Staging tables for component dimension 
------------------------------------------------

-- WebSphere Application Server dimension table

create table IZY.STAGE_D_APPLSRV (
 ApplSrv_Comp_ID     integer not null,
-- @D0 Add Cluster name for WAS 5.x
 ApplSrv_Comp_Name   varchar(254) not NULL,
 ApplSrv_Cluster     varchar(254),
 primary key (ApplSrv_Comp_ID)
);
                 


-- @D0 Start: Add staging mart tables for WebSphere 5.0.x 
------------------------------------------------
-- Component dimension tables 
------------------------------------------------
                                                                       
-- WebSphere 5.0.x Cell  dimension table

create table IZY.STAGE_D_CELL (
 cell_attr_id    	integer not null,
 Cell_Attr_Val   varchar(254) not null,
 primary key (cell_attr_id)
);

-- WebSphere 5.0 NODE dimension table

create table IZY.STAGE_D_NODE(
 Node_Comp_ID     integer not null,
 Node_Comp_Name   varchar(254) not null, 
 XQ_Node_dttm	   timestamp not null,
 Node_Host_Name   varchar(254) not null,
 Node_OS_Type     varchar(254) not null,
 Node_WAS_Ver     varchar(254) not null,
 centr_nm  		   varchar(120) not NULL,
 cust_nm		      varchar(120) not null,
 primary key (Node_Comp_ID,XQ_Node_dttm )
);

-- WebSphere 5.0.x Cfgmgr (Node Agent)  dimension table

create table IZY.STAGE_D_CFGMGR (
 cfgmgr_comp_id    	integer not null,
 cfgmgr_comp_name    varchar(254) not null,
 cfgmgr_TypeCd	      char(17) not null,
 primary key (cfgmgr_comp_id)
);
                   
-- @D0 End: Add staging mart tables for WebSphere 5.0.x 

--------------------------------------------------------------------
--
--      fact tables
---
-------------------------------------------------------------------

--------------
-- hour level
--------------

-- @D0 Start: Add fact hour tables for WebSphere 5.0.x 
-- measurement hour fact table for all metrics against Config Manager (Node Agents)
 
create table IZY.F_CfgMgr_HOUR (
  CfgMgr_Comp_ID    integer not null,
  Node_Comp_ID		   integer not null,
  XQ_node_dttm		   timestamp not null,
  cell_attr_id		   integer not null,
  metric_id          integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (CfgMgr_Comp_ID, Node_Comp_ID, XQ_node_dttm, cell_attr_id, metric_id , meas_hour )
);


ALTER TABLE IZY.F_CfgMgr_HOUR
       ADD CONSTRAINT IZY_FH53
              FOREIGN KEY (CfgMgr_Comp_ID)
                             REFERENCES IZY.D_WAS_CFGMGR;

ALTER TABLE IZY.F_CfgMgr_HOUR
       ADD CONSTRAINT IZY_FH52
              FOREIGN KEY (Node_Comp_ID,XQ_node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_CfgMgr_HOUR
       ADD CONSTRAINT IZY_FH51
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;


ALTER TABLE IZY.F_CfgMgr_HOUR
       ADD CONSTRAINT IZY_FH50
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_CgMgr_HOUR_idx1 on IZY.F_CfgMgr_HOUR(CfgMgr_Comp_ID);
create index IZY.F_CgMgr_HOUR_idx2 on IZY.F_CfgMgr_HOUR(Node_Comp_ID);
create index IZY.F_CgMgr_HOUR_idx3 on IZY.F_CfgMgr_HOUR(XQ_node_dttm);
create index IZY.F_CgMgr_HOUR_idx4 on IZY.F_CfgMgr_HOUR(cell_attr_id);
create index IZY.F_CgMgr_HOUR_idx5 on IZY.F_CfgMgr_HOUR(metric_id);
create index IZY.F_CgMgr_HOUR_idx6 on IZY.F_CfgMgr_HOUR(meas_hour);



-- measurement hour fact table for all metrics against Application Server
create table IZY.F_APPLSRV5_HOUR (
   ApplSrv_Comp_ID   integer not null,
   Node_Comp_ID      integer not null,
   XQ_Node_dttm		timestamp not null,
   cell_attr_id		      integer not null,
   metric_id         integer not null,
   meas_hour         timestamp not null,
   min_value         double,
   max_value         double,
   avg_value         double,
   total_value       double,
	sample_count      integer,
	primary key (ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);


ALTER TABLE IZY.F_APPLSRV5_HOUR
       ADD CONSTRAINT IZY_FH63
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLSRV5_HOUR
       ADD CONSTRAINT IZY_FH62
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_APPLSRV5_HOUR
       ADD CONSTRAINT IZY_FH61
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.F_APPLSRV5_HOUR
       ADD CONSTRAINT IZY_FH60
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APSV5_HOUR_idx1 on IZY.F_APPLSRV5_HOUR(ApplSrv_Comp_ID);
create index IZY.F_APSV5_HOUR_idx2 on IZY.F_APPLSRV5_HOUR(Node_Comp_ID);
create index IZY.F_APSV5_HOUR_idx3 on IZY.F_APPLSRV5_HOUR(XQ_node_dttm);
create index IZY.F_APSV5_HOUR_idx4 on IZY.F_APPLSRV5_HOUR(cell_attr_id);
create index IZY.F_APSV5_HOUR_idx5 on IZY.F_APPLSRV5_HOUR(metric_id);
create index IZY.F_APSV5_HOUR_idx6 on IZY.F_APPLSRV5_HOUR(meas_hour);


-- measurement hour fact table for all metrics against SubComponents of Application Server 
create table IZY.F_APPLCMP5_HOUR (
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID integer not null,
  Node_Comp_ID    integer not null,
  XQ_Node_dttm		timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);


ALTER TABLE IZY.F_APPLCMP5_HOUR
       ADD CONSTRAINT IZY_FH74
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_APPLCMP5_HOUR
       ADD CONSTRAINT IZY_FH73
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLCMP5_HOUR
       ADD CONSTRAINT IZY_FH72
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_APPLCMP5_HOUR
       ADD CONSTRAINT IZY_FH71
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.F_APPLCMP5_HOUR
       ADD CONSTRAINT IZY_FH70
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APCP5_HOUR_idx1 on IZY.F_APPLCMP5_HOUR(ApplCmp_Comp_ID);
create index IZY.F_APCP5_HOUR_idx2 on IZY.F_APPLCMP5_HOUR(ApplSrv_Comp_ID);
create index IZY.F_APCP5_HOUR_idx3 on IZY.F_APPLCMP5_HOUR(Node_Comp_ID);
create index IZY.F_APCP5_HOUR_idx4 on IZY.F_APPLCMP5_HOUR(XQ_Node_dttm);
create index IZY.F_APCP5_HOUR_idx5 on IZY.F_APPLCMP5_HOUR(cell_attr_id);
create index IZY.F_APCP5_HOUR_idx6 on IZY.F_APPLCMP5_HOUR(metric_id);
create index IZY.F_APCP5_HOUR_idx7 on IZY.F_APPLCMP5_HOUR(meas_hour);

-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.F_SUBCMP5_HOUR (
  SubCmp_Comp_ID     integer not null,
  ApplCmp_Comp_ID    integer not null,
  ApplSrv_Comp_ID    integer not null,
  Node_Comp_ID       integer not null,
  XQ_Node_dttm		   timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);                

ALTER TABLE IZY.F_SUBCMP5_HOUR
       ADD CONSTRAINT IZY_FH85
              FOREIGN KEY (SubCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_SUBCMP;


ALTER TABLE IZY.F_SUBCMP5_HOUR
       ADD CONSTRAINT IZY_FH84
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_SUBCMP5_HOUR
       ADD CONSTRAINT IZY_FH83
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_SUBCMP5_HOUR
       ADD CONSTRAINT IZY_FH82
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_SUBCMP5_HOUR
       ADD CONSTRAINT IZY_FH81
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.F_SUBCMP5_HOUR
       ADD CONSTRAINT IZY_FH80
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_SBCP5_HOUR_idx1 on IZY.F_SUBCMP5_HOUR(SubCmp_Comp_ID);
create index IZY.F_SBCP5_HOUR_idx2 on IZY.F_SUBCMP5_HOUR(ApplCmp_Comp_ID);
create index IZY.F_SBCP5_HOUR_idx3 on IZY.F_SUBCMP5_HOUR(ApplSrv_Comp_ID);
create index IZY.F_SBCP5_HOUR_idx4 on IZY.F_SUBCMP5_HOUR(Node_Comp_ID);
create index IZY.F_SBCP5_HOUR_idx5 on IZY.F_SUBCMP5_HOUR(XQ_Node_dttm);
create index IZY.F_SBCP5_HOUR_idx6 on IZY.F_SUBCMP5_HOUR(cell_attr_id);
create index IZY.F_SBCP5_HOUR_idx7 on IZY.F_SUBCMP5_HOUR(metric_id);
create index IZY.F_SBCP5_HOUR_idx8 on IZY.F_SUBCMP5_HOUR(meas_hour);

-- @D0 End: Add fact hour tables for WebSphere 5.0.x 

--------------------------------------------------------------------
--
--      Staging tables for fact tables
---
-------------------------------------------------------------------

-- @D0 Start: Add staging hourly fact tables for WebSphere 5.0.x 

-- measurement hour fact table for all metrics against Config Manager (Node Agents)
 
create table IZY.STAGE_F_CgMgr_HOUR (
  CfgMgr_Comp_ID    integer not null,
  Node_Comp_ID		      integer not null,
  XQ_node_dttm		   timestamp not null,
  cell_attr_id		      integer not null,
  metric_id          integer not null,
  meas_hour timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (CfgMgr_Comp_ID, Node_Comp_ID, XQ_node_dttm, cell_attr_id, metric_id , meas_hour )
);


ALTER TABLE IZY.STAGE_F_CgMgr_HOUR
       ADD CONSTRAINT IZY_SH53
              FOREIGN KEY (CfgMgr_Comp_ID)
                             REFERENCES IZY.D_WAS_CFGMGR;

ALTER TABLE IZY.STAGE_F_CgMgr_HOUR
       ADD CONSTRAINT IZY_SH52
              FOREIGN KEY (Node_Comp_ID,XQ_node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.STAGE_F_CgMgr_HOUR
       ADD CONSTRAINT IZY_SH51
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;


ALTER TABLE IZY.STAGE_F_CgMgr_HOUR
       ADD CONSTRAINT IZY_SH50
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

-- measurement hour fact table for all metrics against Application Server
create table IZY.STAGE_F_APPL5_HOUR (
  ApplSrv_Comp_ID    integer not null,
  Node_Comp_ID       integer not null,
  XQ_Node_dttm		   timestamp not null,
  cell_attr_id		      integer not null,
  metric_id          integer not null,
  meas_hour          timestamp not null,
  min_value          double,
  max_value          double,
  avg_value          double,
	total_value       double,
	sample_count      integer,
	primary key (ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);


ALTER TABLE IZY.STAGE_F_APPL5_HOUR
       ADD CONSTRAINT IZY_SH63
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.STAGE_F_APPL5_HOUR
       ADD CONSTRAINT IZY_SH62
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.STAGE_F_APPL5_HOUR
       ADD CONSTRAINT IZY_SH61
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.STAGE_F_APPL5_HOUR
       ADD CONSTRAINT IZY_SH60
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

-- measurement hour fact table for all metrics against SubComponents of Application Server 
create table IZY.STAGE_F_APCP5_HOUR (
  ApplCmp_Comp_ID integer not null,
  ApplSrv_Comp_ID integer not null,
  Node_Comp_ID    integer not null,
  XQ_Node_dttm		timestamp not null,
  cell_attr_id		   integer not null,
  metric_id       integer not null,
  meas_hour       timestamp not null,
  min_value       double,
  max_value       double,
  avg_value       double,
	total_value    double,
	sample_count   integer,
	primary key (ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);


ALTER TABLE IZY.STAGE_F_APCP5_HOUR
       ADD CONSTRAINT IZY_SH74
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.STAGE_F_APCP5_HOUR
       ADD CONSTRAINT IZY_SH73
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.STAGE_F_APCP5_HOUR
       ADD CONSTRAINT IZY_SH72
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.STAGE_F_APCP5_HOUR
       ADD CONSTRAINT IZY_SH71
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.STAGE_F_APCP5_HOUR
       ADD CONSTRAINT IZY_SH70
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;


-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.STAGE_F_SBCP5_HOUR (
  SubCmp_Comp_ID     integer not null,
  ApplCmp_Comp_ID    integer not null,
  ApplSrv_Comp_ID    integer not null,
  Node_Comp_ID       integer not null,
  XQ_Node_dttm		   timestamp not null,
  cell_attr_id		      integer not null,
  metric_id          integer not null,
  meas_hour          timestamp not null,
  min_value          double,
  max_value          double,
  avg_value          double,
	total_value       double,
	sample_count      integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_hour )
);                

ALTER TABLE IZY.STAGE_F_SBCP5_HOUR
       ADD CONSTRAINT IZY_SH85
              FOREIGN KEY (SubCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_SUBCMP;


ALTER TABLE IZY.STAGE_F_SBCP5_HOUR
       ADD CONSTRAINT IZY_SH84
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.STAGE_F_SBCP5_HOUR
       ADD CONSTRAINT IZY_FH83
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.STAGE_F_SBCP5_HOUR
       ADD CONSTRAINT IZY_FH82
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.STAGE_F_SBCP5_HOUR
       ADD CONSTRAINT IZY_FH81
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.STAGE_F_SBCP5_HOUR
       ADD CONSTRAINT IZY_FH80
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;
                                                              
-- @D0 End: Add staging hourly fact tables for WebSphere 5.0.x 

--------------
-- day level
--------------

-- FACT DAY table
-- The day, week, and month tables are populated by the aggregation UDP
-- @D0 Start: Add fact day tables for WebSphere 5.0.x 

-- measurement day fact table for all metrics against Config Manager (Node Agents)
 
create table IZY.F_CfgMgr_DAY (
   CfgMgr_Comp_ID    integer not null,
   Node_Comp_ID		      integer not null,
   XQ_node_dttm		timestamp not null,
   cell_attr_id		      integer not null,
   metric_id         integer not null,
   meas_date         timestamp not null,
   min_value         double,
   max_value         double,
   avg_value         double,
   total_value       double,
	sample_count      integer,
	primary key (CfgMgr_Comp_ID, Node_Comp_ID, XQ_node_dttm, cell_attr_id, metric_id , meas_date )
);


ALTER TABLE IZY.F_CfgMgr_DAY
       ADD CONSTRAINT IZY_FD53
              FOREIGN KEY (CfgMgr_Comp_ID)
                             REFERENCES IZY.D_WAS_CFGMGR;

ALTER TABLE IZY.F_CfgMgr_DAY
       ADD CONSTRAINT IZY_FD52
              FOREIGN KEY (Node_Comp_ID,XQ_node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_CfgMgr_DAY
       ADD CONSTRAINT IZY_FD51
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;


ALTER TABLE IZY.F_CfgMgr_DAY
       ADD CONSTRAINT IZY_FD50
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_CgMgr_DAY_idx1 on IZY.F_CfgMgr_DAY(CfgMgr_Comp_ID);
create index IZY.F_CgMgr_DAY_idx3 on IZY.F_CfgMgr_DAY(Node_Comp_ID);
create index IZY.F_CgMgr_DAY_idx2 on IZY.F_CfgMgr_DAY(XQ_node_dttm);
create index IZY.F_CgMgr_DAY_idx4 on IZY.F_CfgMgr_DAY(cell_attr_id);
create index IZY.F_CgMgr_DAY_idx5 on IZY.F_CfgMgr_DAY(metric_id);
create index IZY.F_CgMgr_DAY_idx6 on IZY.F_CfgMgr_DAY(meas_date);

-- measurement hour fact table for all metrics against Application Server
create table IZY.F_APPLSRV5_DAY (
  ApplSrv_Comp_ID    integer not null,
  Node_Comp_ID       integer not null,
  XQ_Node_dttm		   timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_date)
);


ALTER TABLE IZY.F_APPLSRV5_DAY
       ADD CONSTRAINT IZY_FD63
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLSRV5_DAY
       ADD CONSTRAINT IZY_FD62
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_APPLSRV5_DAY
       ADD CONSTRAINT IZY_FD61
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.F_APPLSRV5_DAY
       ADD CONSTRAINT IZY_FD60
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APSV5_DAY_idx1 on IZY.F_APPLSRV5_DAY(ApplSrv_Comp_ID);
create index IZY.F_APSV5_DAY_idx2 on IZY.F_APPLSRV5_DAY(Node_Comp_ID);
create index IZY.F_APSV5_DAY_idx3 on IZY.F_APPLSRV5_DAY(XQ_node_dttm);
create index IZY.F_APSV5_DAY_idx4 on IZY.F_APPLSRV5_DAY(cell_attr_id);
create index IZY.F_APSV5_DAY_idx5 on IZY.F_APPLSRV5_DAY(metric_id);
create index IZY.F_APSV5_DAY_idx6 on IZY.F_APPLSRV5_DAY(meas_date);


-- measurement hour fact table for all metrics against SubComponents of Application Server 
create table IZY.F_APPLCMP5_DAY (
   ApplCmp_Comp_ID   integer not null,
   ApplSrv_Comp_ID   integer not null,
   Node_Comp_ID      integer not null,
   XQ_Node_dttm		timestamp not null,
   cell_attr_id		      integer not null,
   metric_id         integer not null,
   meas_date         timestamp not null,
   min_value         double,
   max_value         double,
   avg_value         double,
	total_value       double,
	sample_count      integer,
	primary key (ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_date )
);


ALTER TABLE IZY.F_APPLCMP5_DAY
       ADD CONSTRAINT IZY_FD74
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_APPLCMP5_DAY
       ADD CONSTRAINT IZY_FD73
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLCMP5_DAY
       ADD CONSTRAINT IZY_FD72
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_APPLCMP5_DAY
       ADD CONSTRAINT IZY_FD71
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.F_APPLCMP5_DAY
       ADD CONSTRAINT IZY_FD70
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APCP5_DAY_idx1 on IZY.F_APPLCMP5_DAY(ApplCmp_Comp_ID);
create index IZY.F_APCP5_DAY_idx2 on IZY.F_APPLCMP5_DAY(ApplSrv_Comp_ID);
create index IZY.F_APCP5_DAY_idx3 on IZY.F_APPLCMP5_DAY(Node_Comp_ID);
create index IZY.F_APCP5_DAY_idx4 on IZY.F_APPLCMP5_DAY(XQ_Node_dttm);
create index IZY.F_APCP5_DAY_idx5 on IZY.F_APPLCMP5_DAY(cell_attr_id);
create index IZY.F_APCP5_DAY_idx6 on IZY.F_APPLCMP5_DAY(metric_id);
create index IZY.F_APCP5_DAY_idx7 on IZY.F_APPLCMP5_DAY(meas_date);

-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.F_SUBCMP5_DAY (
   SubCmp_Comp_ID       integer not null,
   ApplCmp_Comp_ID      integer not null,
   ApplSrv_Comp_ID      integer not null,
   Node_Comp_ID         integer not null,
   XQ_Node_dttm		   timestamp not null,
   cell_attr_id		         integer not null,
   metric_id            integer not null,
   meas_date            timestamp not null,
   min_value            double,
   max_value            double,
   avg_value            double,
	total_value          double,
	sample_count         integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_date )
);                

ALTER TABLE IZY.F_SUBCMP5_DAY
       ADD CONSTRAINT IZY_FD85
              FOREIGN KEY (SubCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_SUBCMP;


ALTER TABLE IZY.F_SUBCMP5_DAY
       ADD CONSTRAINT IZY_FD84
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_SUBCMP5_DAY
       ADD CONSTRAINT IZY_FD83
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_SUBCMP5_DAY
       ADD CONSTRAINT IZY_FD82
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_SUBCMP5_DAY
       ADD CONSTRAINT IZY_FD81
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.F_SUBCMP5_DAY
       ADD CONSTRAINT IZY_FD80
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_SBCP5_DAY_idx1 on IZY.F_SUBCMP5_DAY(SubCmp_Comp_ID);
create index IZY.F_SBCP5_DAY_idx2 on IZY.F_SUBCMP5_DAY(ApplCmp_Comp_ID);
create index IZY.F_SBCP5_DAY_idx3 on IZY.F_SUBCMP5_DAY(ApplSrv_Comp_ID);
create index IZY.F_SBCP5_DAY_idx4 on IZY.F_SUBCMP5_DAY(Node_Comp_ID);
create index IZY.F_SBCP5_DAY_idx5 on IZY.F_SUBCMP5_DAY(XQ_Node_dttm);
create index IZY.F_SBCP5_DAY_idx6 on IZY.F_SUBCMP5_DAY(cell_attr_id);
create index IZY.F_SBCP5_DAY_idx7 on IZY.F_SUBCMP5_DAY(metric_id);
create index IZY.F_SBCP5_DAY_idx8 on IZY.F_SUBCMP5_DAY(meas_date);

-- @D0 End: Add fact day tables for WebSphere 5.0.x 
                                                              

--------------------
--- Fact WEEK level
--------------------
-- @D0 Start: Add fact week tables for WebSphere 5.0.x 
-- measurement weekly fact table for all metrics against Config Manager (Node Agents)
 
create table IZY.F_CfgMgr_WEEK (
   CfgMgr_Comp_ID    integer not null,
   Node_Comp_ID		      integer not null,
   XQ_node_dttm		timestamp not null,
   cell_attr_id		      integer not null,
   metric_id         integer not null,
   meas_date         timestamp not null,
   min_value         double,
   max_value         double,
   avg_value         double,
   total_value       double,
	sample_count      integer,
	primary key (CfgMgr_Comp_ID, Node_Comp_ID, XQ_node_dttm, cell_attr_id, metric_id , meas_date )
);


ALTER TABLE IZY.F_CfgMgr_WEEK
       ADD CONSTRAINT IZY_FW53
              FOREIGN KEY (CfgMgr_Comp_ID)
                             REFERENCES IZY.D_WAS_CFGMGR;

ALTER TABLE IZY.F_CfgMgr_WEEK
       ADD CONSTRAINT IZY_FW52
              FOREIGN KEY (Node_Comp_ID,XQ_node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_CfgMgr_WEEK
       ADD CONSTRAINT IZY_FW51
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;


ALTER TABLE IZY.F_CfgMgr_WEEK
       ADD CONSTRAINT IZY_FW50
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_CgMgr_WEEK_idx1 on IZY.F_CfgMgr_WEEK(CfgMgr_Comp_ID);
create index IZY.F_CgMgr_WEEK_idx3 on IZY.F_CfgMgr_WEEK(Node_Comp_ID);
create index IZY.F_CgMgr_WEEK_idx2 on IZY.F_CfgMgr_WEEK(XQ_node_dttm);
create index IZY.F_CgMgr_WEEK_idx4 on IZY.F_CfgMgr_WEEK(cell_attr_id);
create index IZY.F_CgMgr_WEEK_idx5 on IZY.F_CfgMgr_WEEK(metric_id);
create index IZY.F_CgMgr_WEEK_idx6 on IZY.F_CfgMgr_WEEK(meas_date);



-- measurement hour fact table for all metrics against Application Server
create table IZY.F_APPLSRV5_WEEK (
  ApplSrv_Comp_ID    integer not null,
  Node_Comp_ID       integer not null,
  XQ_Node_dttm		   timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_date)
);


ALTER TABLE IZY.F_APPLSRV5_WEEK
       ADD CONSTRAINT IZY_FW63
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLSRV5_WEEK
       ADD CONSTRAINT IZY_FW62
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_APPLSRV5_WEEK
       ADD CONSTRAINT IZY_FW61
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.F_APPLSRV5_WEEK
       ADD CONSTRAINT IZY_FW60
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APSV5_WEEK_idx1 on IZY.F_APPLSRV5_WEEK(ApplSrv_Comp_ID);
create index IZY.F_APSV5_WEEK_idx2 on IZY.F_APPLSRV5_WEEK(Node_Comp_ID);
create index IZY.F_APSV5_WEEK_idx3 on IZY.F_APPLSRV5_WEEK(XQ_node_dttm);
create index IZY.F_APSV5_WEEK_idx4 on IZY.F_APPLSRV5_WEEK(cell_attr_id);
create index IZY.F_APSV5_WEEK_idx5 on IZY.F_APPLSRV5_WEEK(metric_id);
create index IZY.F_APSV5_WEEK_idx6 on IZY.F_APPLSRV5_WEEK(meas_date);


-- measurement hour fact table for all metrics against SubComponents of Application Server 
create table IZY.F_APPLCMP5_WEEK (
   ApplCmp_Comp_ID   integer not null,
   ApplSrv_Comp_ID   integer not null,
   Node_Comp_ID      integer not null,
   XQ_Node_dttm		timestamp not null,
   cell_attr_id		      integer not null,
   metric_id         integer not null,
   meas_date         timestamp not null,
   min_value         double,
   max_value         double,
   avg_value         double,
	total_value       double,
	sample_count      integer,
	primary key (ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_date )
);


ALTER TABLE IZY.F_APPLCMP5_WEEK
       ADD CONSTRAINT IZY_FW74
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_APPLCMP5_WEEK
       ADD CONSTRAINT IZY_FW73
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLCMP5_WEEK
       ADD CONSTRAINT IZY_FW72
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_APPLCMP5_WEEK
       ADD CONSTRAINT IZY_FW71
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.F_APPLCMP5_WEEK
       ADD CONSTRAINT IZY_FW70
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APCP5_WEEK_idx1 on IZY.F_APPLCMP5_WEEK(ApplCmp_Comp_ID);
create index IZY.F_APCP5_WEEK_idx2 on IZY.F_APPLCMP5_WEEK(ApplSrv_Comp_ID);
create index IZY.F_APCP5_WEEK_idx3 on IZY.F_APPLCMP5_WEEK(Node_Comp_ID);
create index IZY.F_APCP5_WEEK_idx4 on IZY.F_APPLCMP5_WEEK(XQ_Node_dttm);
create index IZY.F_APCP5_WEEK_idx5 on IZY.F_APPLCMP5_WEEK(cell_attr_id);
create index IZY.F_APCP5_WEEK_idx6 on IZY.F_APPLCMP5_WEEK(metric_id);
create index IZY.F_APCP5_WEEK_idx7 on IZY.F_APPLCMP5_WEEK(meas_date);

-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.F_SUBCMP5_WEEK (
   SubCmp_Comp_ID       integer not null,
   ApplCmp_Comp_ID      integer not null,
   ApplSrv_Comp_ID      integer not null,
   Node_Comp_ID         integer not null,
   XQ_Node_dttm		   timestamp not null,
   cell_attr_id		         integer not null,
   metric_id            integer not null,
   meas_date            timestamp not null,
   min_value            double,
   max_value            double,
   avg_value            double,
	total_value          double,
	sample_count         integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_date )
);                

ALTER TABLE IZY.F_SUBCMP5_WEEK
       ADD CONSTRAINT IZY_FW85
              FOREIGN KEY (SubCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_SUBCMP;


ALTER TABLE IZY.F_SUBCMP5_WEEK
       ADD CONSTRAINT IZY_FW84
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_SUBCMP5_WEEK
       ADD CONSTRAINT IZY_FW83
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_SUBCMP5_WEEK
       ADD CONSTRAINT IZY_FW82
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_SUBCMP5_WEEK
       ADD CONSTRAINT IZY_FW81
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.F_SUBCMP5_WEEK
       ADD CONSTRAINT IZY_FW80
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_SBCP5_WEEK_idx1 on IZY.F_SUBCMP5_WEEK(SubCmp_Comp_ID);
create index IZY.F_SBCP5_WEEK_idx2 on IZY.F_SUBCMP5_WEEK(ApplCmp_Comp_ID);
create index IZY.F_SBCP5_WEEK_idx3 on IZY.F_SUBCMP5_WEEK(ApplSrv_Comp_ID);
create index IZY.F_SBCP5_WEEK_idx4 on IZY.F_SUBCMP5_WEEK(Node_Comp_ID);
create index IZY.F_SBCP5_WEEK_idx5 on IZY.F_SUBCMP5_WEEK(XQ_Node_dttm);
create index IZY.F_SBCP5_WEEK_idx6 on IZY.F_SUBCMP5_WEEK(cell_attr_id);
create index IZY.F_SBCP5_WEEK_idx7 on IZY.F_SUBCMP5_WEEK(metric_id);
create index IZY.F_SBCP5_WEEK_idx8 on IZY.F_SUBCMP5_WEEK(meas_date);

-- @D0 End: Add fact Week tables for WebSphere 5.0.x 
                                                              

--------------------
-- FACT MONTH table
--------------------
-- @D0 Start: Add monthly fact tables for WebSphere 5.0.x 

-- measurement monthly fact table for all metrics against Config Manager (Node Agents)
 
create table IZY.F_CfgMgr_MONTH (
   CfgMgr_Comp_ID    integer not null,
   Node_Comp_ID		      integer not null,
   XQ_node_dttm		timestamp not null,
   cell_attr_id		      integer not null,
   metric_id         integer not null,
   meas_date         timestamp not null,
   min_value         double,
   max_value         double,
   avg_value         double,
   total_value       double,
	sample_count      integer,
	primary key (CfgMgr_Comp_ID, Node_Comp_ID, XQ_node_dttm, cell_attr_id, metric_id , meas_date )
);


ALTER TABLE IZY.F_CfgMgr_MONTH
       ADD CONSTRAINT IZY_FM53
              FOREIGN KEY (CfgMgr_Comp_ID)
                             REFERENCES IZY.D_WAS_CFGMGR;

ALTER TABLE IZY.F_CfgMgr_MONTH
       ADD CONSTRAINT IZY_FM52
              FOREIGN KEY (Node_Comp_ID,XQ_node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_CfgMgr_MONTH
       ADD CONSTRAINT IZY_FM51
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;


ALTER TABLE IZY.F_CfgMgr_MONTH
       ADD CONSTRAINT IZY_FM50
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_CgMgr_MONTH_idx1 on IZY.F_CfgMgr_MONTH(CfgMgr_Comp_ID);
create index IZY.F_CgMgr_MONTH_idx3 on IZY.F_CfgMgr_MONTH(Node_Comp_ID);
create index IZY.F_CgMgr_MONTH_idx2 on IZY.F_CfgMgr_MONTH(XQ_node_dttm);
create index IZY.F_CgMgr_MONTH_idx4 on IZY.F_CfgMgr_MONTH(cell_attr_id);
create index IZY.F_CgMgr_MONTH_idx5 on IZY.F_CfgMgr_MONTH(metric_id);
create index IZY.F_CgMgr_MONTH_idx6 on IZY.F_CfgMgr_MONTH(meas_date);

-- measurement hour fact table for all metrics against Application Server
create table IZY.F_APPLSRV5_MONTH (
  ApplSrv_Comp_ID    integer not null,
  Node_Comp_ID       integer not null,
  XQ_Node_dttm		   timestamp not null,
  cell_attr_id		integer not null,
  metric_id integer not null,
  meas_date timestamp not null,
  min_value double,
  max_value double,
  avg_value double,
	total_value double,
	sample_count integer,
	primary key (ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_date)
);


ALTER TABLE IZY.F_APPLSRV5_MONTH
       ADD CONSTRAINT IZY_FM63
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLSRV5_MONTH
       ADD CONSTRAINT IZY_FM62
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_APPLSRV5_MONTH
       ADD CONSTRAINT IZY_FM61
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.F_APPLSRV5_MONTH
       ADD CONSTRAINT IZY_FM60
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APSV5_MONTH_idx1 on IZY.F_APPLSRV5_MONTH(ApplSrv_Comp_ID);
create index IZY.F_APSV5_MONTH_idx2 on IZY.F_APPLSRV5_MONTH(Node_Comp_ID);
create index IZY.F_APSV5_MONTH_idx3 on IZY.F_APPLSRV5_MONTH(XQ_node_dttm);
create index IZY.F_APSV5_MONTH_idx4 on IZY.F_APPLSRV5_MONTH(cell_attr_id);
create index IZY.F_APSV5_MONTH_idx5 on IZY.F_APPLSRV5_MONTH(metric_id);
create index IZY.F_APSV5_MONTH_idx6 on IZY.F_APPLSRV5_MONTH(meas_date);

-- measurement hour fact table for all metrics against SubComponents of Application Server 
create table IZY.F_APPLCMP5_MONTH (
   ApplCmp_Comp_ID   integer not null,
   ApplSrv_Comp_ID   integer not null,
   Node_Comp_ID      integer not null,
   XQ_Node_dttm		timestamp not null,
   cell_attr_id		      integer not null,
   metric_id         integer not null,
   meas_date         timestamp not null,
   min_value         double,
   max_value         double,
   avg_value         double,
	total_value       double,
	sample_count      integer,
	primary key (ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_date )
);


ALTER TABLE IZY.F_APPLCMP5_MONTH
       ADD CONSTRAINT IZY_FM74
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_APPLCMP5_MONTH
       ADD CONSTRAINT IZY_FM73
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_APPLCMP5_MONTH
       ADD CONSTRAINT IZY_FM72
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_APPLCMP5_MONTH
       ADD CONSTRAINT IZY_FM71
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.F_APPLCMP5_MONTH
       ADD CONSTRAINT IZY_FM70
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_APCP5_MONTH_idx1 on IZY.F_APPLCMP5_MONTH(ApplCmp_Comp_ID);
create index IZY.F_APCP5_MONTH_idx2 on IZY.F_APPLCMP5_MONTH(ApplSrv_Comp_ID);
create index IZY.F_APCP5_MONTH_idx3 on IZY.F_APPLCMP5_MONTH(Node_Comp_ID);
create index IZY.F_APCP5_MONTH_idx4 on IZY.F_APPLCMP5_MONTH(XQ_Node_dttm);
create index IZY.F_APCP5_MONTH_idx5 on IZY.F_APPLCMP5_MONTH(cell_attr_id);
create index IZY.F_APCP5_MONTH_idx6 on IZY.F_APPLCMP5_MONTH(metric_id);
create index IZY.F_APCP5_MONTH_idx7 on IZY.F_APPLCMP5_MONTH(meas_date);

-- measurement hour fact table for all metrics against SubComponents Items of Application Server 
-- ie. connection pools, and servlets 
create table IZY.F_SUBCMP5_MONTH (
   SubCmp_Comp_ID       integer not null,
   ApplCmp_Comp_ID      integer not null,
   ApplSrv_Comp_ID      integer not null,
   Node_Comp_ID         integer not null,
   XQ_Node_dttm		   timestamp not null,
   cell_attr_id		         integer not null,
   metric_id            integer not null,
   meas_date            timestamp not null,
   min_value            double,
   max_value            double,
   avg_value            double,
	total_value          double,
	sample_count         integer,
	primary key (SubCmp_Comp_ID, ApplCmp_Comp_ID, ApplSrv_Comp_ID, Node_Comp_ID, XQ_Node_dttm, cell_attr_id, metric_id , meas_date )
);                

ALTER TABLE IZY.F_SUBCMP5_MONTH
       ADD CONSTRAINT IZY_FM85
              FOREIGN KEY (SubCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_SUBCMP;


ALTER TABLE IZY.F_SUBCMP5_MONTH
       ADD CONSTRAINT IZY_FM84
              FOREIGN KEY (ApplCmp_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLCMP;


ALTER TABLE IZY.F_SUBCMP5_MONTH
       ADD CONSTRAINT IZY_FM83
              FOREIGN KEY (ApplSrv_Comp_ID)
                             REFERENCES IZY.D_WAS_APPLSRV;


ALTER TABLE IZY.F_SUBCMP5_MONTH
       ADD CONSTRAINT IZY_FM82
              FOREIGN KEY (Node_Comp_ID,XQ_Node_dttm)
                             REFERENCES IZY.D_WAS_NODE;

ALTER TABLE IZY.F_SUBCMP5_MONTH
       ADD CONSTRAINT IZY_FM81
              FOREIGN KEY (cell_attr_id)
                             REFERENCES IZY.D_WAS_CELL;

ALTER TABLE IZY.F_SUBCMP5_MONTH
       ADD CONSTRAINT IZY_FM80
              FOREIGN KEY (metric_id)
                             REFERENCES IZY.D_WAS_METRIC;

create index IZY.F_SBCP5_MONTH_idx1 on IZY.F_SUBCMP5_MONTH(SubCmp_Comp_ID);
create index IZY.F_SBCP5_MONTH_idx2 on IZY.F_SUBCMP5_MONTH(ApplCmp_Comp_ID);
create index IZY.F_SBCP5_MONTH_idx3 on IZY.F_SUBCMP5_MONTH(ApplSrv_Comp_ID);
create index IZY.F_SBCP5_MONTH_idx4 on IZY.F_SUBCMP5_MONTH(Node_Comp_ID);
create index IZY.F_SBCP5_MONTH_idx5 on IZY.F_SUBCMP5_MONTH(XQ_Node_dttm);
create index IZY.F_SBCP5_MONTH_idx6 on IZY.F_SUBCMP5_MONTH(cell_attr_id);
create index IZY.F_SBCP5_MONTH_idx7 on IZY.F_SUBCMP5_MONTH(metric_id);
create index IZY.F_SBCP5_MONTH_idx8 on IZY.F_SUBCMP5_MONTH(meas_date);

-- @D0 End: Add monthly fact tables for WebSphere 5.0.x 
--#endtag fixpack_2
