-- ==========================================================================
-- Licensed Materials - Property of IBM
-- "Restricted Materials of IBM"
--
-- 5724-C01
-- 5698-WAZ
--
-- (C) COPYRIGHT IBM CORP. 2003. ALL RIGHTS RESERVED.
-- 
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- ==========================================================================
--
-- File Information: wsappsvr/src/tedw_apps_etl/fixpack_v1103/izy/mart/dml/izy_mart_data.sql, waspac, waspac_512, 200403120044
-- 
-- Revision: 1.2
-- 
-- Date: 3/9/04 17:55:23
-- 
-- Description: IBM Tivoli Monitoring for WebSphere file for inserting 
--              static data into the TWH_Mart database tables for pruning purposes.
-- 
--  ==========================================================================
--  Change Activity:
--  $D0 115192 06/04/03  lmd  New file:Add support for WAS 5.0 (delta only)
--  $D1 119948 09/03/03  lmd  Change EJB_request_rate to Min, Max, Avg per 5.1.1 chg
--  $D2 128430 03/09/04  lmd  Change Total_JVM_memory, Servlet_request_rate, 
--                            transaction_exceptions, transaction_<global,local>_exception
--                            to Min, Max, Avg from totalsss
-- ===========================================================================
-- 
--#iftag fixpack_2        
-- 
-- @D0A EJB_request_rate was corrected to be a Min, Max, Avg value in fixpack_1.
--      That change did not account for existing data in the D_WAS_Metric table.
update  IZY.D_WAS_Metric mt
   SET mt.MIN_EXISTS =  'Y',
       mt.MAX_EXISTS =  'Y',
       mt.AVG_EXISTs =  'Y',
       mt.TOTAL_EXISTS =  'N'
      WHERE mt.MET_NAME = 'EJB_request_rate';           
-----------------------------------------------------------------------
-- Insert data into control table for pruning obsolete data from all 
-- Monitoring for WebSphere Application Server fact tables.
-- A date duration is decimal(8,0) and has the format yyyymmdd.
-----------------------------------------------------------------------

-- create temporary table for prune mart control
CREATE TABLE IZY.STAGE_Prune_Mart(
       Table_Name           VARCHAR(120) NOT NULL,
       PMartC_Duration      DECIMAL(8,0) NOT NULL
) 
;

-- @D0 Start: Add pruning for WebSphere 5.0.x       
INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_CFGMGR_HOUR', 00000300);
INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_CFGMGR_DAY', 00000300);
INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_CFGMGR_WEEK', 00010000);
INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_CFGMGR_MONTH', 00010000);

INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_APPLSRV5_HOUR', 00000300);
INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_APPLSRV5_DAY', 00000300);
INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_APPLSRV5_WEEK', 00010000);
INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_APPLSRV5_MONTH', 00010000);

INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_APPLCMP5_HOUR', 00000300);
INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_APPLCMP5_DAY', 00000300);
INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_APPLCMP5_WEEK', 00010000);
INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_APPLCMP5_MONTH', 00010000);


INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_SUBCMP5_HOUR', 00000300);
INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_SUBCMP5_DAY', 00000300);
INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_SUBCMP5_WEEK', 00010000);
INSERT INTO IZY.STAGE_Prune_Mart VALUES ('IZY.F_SUBCMP5_MONTH', 00010000);
-- @D0 End: Add pruning for WebSphere 5.0.x 

INSERT INTO IZY.Prune_Mart_Control
SELECT 
   s.Table_Name AS Table_Name,
   s.PMartC_Duration AS PMartC_Duration
FROM 
   IZY.STAGE_Prune_Mart s
WHERE NOT EXISTS
( 
  SELECT 1 FROM
  IZY.Prune_Mart_Control t
  WHERE
  t.Table_Name = s.Table_Name 
);

-----------------------------------------------------------------------
-- Drop temporary session tables 
-----------------------------------------------------------------------

-- drop temporary table for prune mart control
DROP TABLE IZY.STAGE_Prune_Mart;

--#endtag fixpack_2

-- 
--#iftag fixpack_3
-- 
-- @D2A Update Total_JVM_memory,Servlet_request_rate,Transaction_exceptions, Transaction_Global_Exceptions,Transaction_Local_Exceptions
--     to be a Min, Max, Avg value, instead of a total. 
update  IZY.D_WAS_Metric mt
   SET mt.MIN_EXISTS =  'Y',
       mt.MAX_EXISTS =  'Y',
       mt.AVG_EXISTs =  'Y',
       mt.TOTAL_EXISTS =  'N'
      WHERE mt.MET_NAME IN ('Total_JVM_memory',
                            'Servlet_request_rate',
                            'Transaction_exceptions',
                            'Transaction_Global_Exceptions',
                            'Transaction_Local_Exceptions');           


--#endtag fixpack_3
