#!/bin/sh
#########################################################################
#
# Licensed Materials - Property of IBM
# 
# 5724-C01           
# 5698-WAZ
#
# (C) COPYRIGHT IBM CORP. 2003. ALL RIGHTS RESERVED.
# 
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
# ==========================================================================
#
# File Information: wsappsvr/src/tedw_apps_etl/fixpack_v1103/izy/misc/izy_before.sh, waspac, waspac_512, 200401161514
# 
# Revision: 1.1
# 
# Date: 12/17/03 11:19:06
#
# ==========================================================================
#  Change Activity:
#  $D0 119858 09/03/03  lmd  Delete all reports and reinstall all 
#  $D1 123876 11/17/03  lmd  Check if RPI tables exist before removing reports
#
#  ==========================================================================
#
############################################################################
# Command Line Args:
#   1 = the path and name of the TWH Application config file
#   2 = Application working directory or install base directory
#       $TWH_TOPDIR/apps/ava_code_for_app/vapp_version (look at install tree)
#
# Required Config File:
#       twh_app_install.cfg
#
# Installation Logs (Default names):
#       A log will be generated for this script called izy_before.sh.log
#
# Required Env Vars:
#       None.
#
# Return Codes:
#       0 = Success
#       255 = Failure
#
# Interpreter Required:
#       NT/2000 = BASH
#       Unix    = SH (Bourne Shell)
#
# Message Types:
#       (I) - Informational
#       (W) - Warning
#       (F) - Fatal
#
# Install Steps Required Before this Script Executes:
#        - TWH Core tools and application components must be
#          successfully installed
#
# What is accomplished:
#  * Remove all existing reports which will be re-installed with this
#    fixpack. Previously only changed reports were installed.
#    This is  required for compatability with future TEDW.                       
#
# Note - Caution needs to be taken for NT paths that have a space.  This
#        is a limitation that requires double quoting around all
#        variables that contain a path.  Testing should be done to ensure
#        this script runs with a space in any of the paths that are used.
#########################################################################

echo "        ** Before Script Log **          "
echo ""
echo "****************************************"
echo "* Application Before Script Start point *"
echo "****************************************"
echo ""

# Pulls in the generic shared routines

# Set parms
echo "      Parm 1 = $1"; TWH_CONFIG_FILE="$1"; export TWH_CONFIG_FILE
echo "      Parm 2 = $2"; APP_WORK_DIR="$2"; export APP_WORK_DIR
echo ""

# TWH_TOPDIR needs to always be in the environment
if [ -z "$TWH_TOPDIR" ]; then
  echo "      (F) Could not locate Env var TWH_TOPDIR"
  exit 255
fi

# Execute startup driver for beforescript
. "$TWH_TOPDIR"/install/bin/twh_core_startup_after.sh
exec_startup_driver;

#####################################################
######## Add application code below here ONLY #######
#####################################################

#
# Define local variables used by the before script
#
set_izy_program_vars()
{
  IZY_MISC_DIR="$APP_WORK_DIR/misc"
  tmp_sql_file="izy_tmp_sql.sql"        # name of the temporary sql file
  return 0;
}

# Remove obsolete rpi data
remove_obsolete_rpi_data()
{

  # Test a connection
  echo "      (I) Testing the DB connection"
  err_txt=`$DB2EXEC_LOG connect to "$TWH_CTRL_DB" user "$COPT_CTRL_DB2USER" using "$COPT_CTRL_DB2PASS" 2>&1 `
  if [ $? -ne 0 ]; then
    echo "      (F) Unable to connect to database ($TWH_CTRL_DB)."
    echo "          Error is:"
    echo "          $err_txt"
    echo "          Exiting..."
    exit 255
  fi

  echo "==> Removing the obsolete IZY data marts and reports"

  echo "      (I) Connecting to the TWH Control DB"
  echo "connect to $TWH_CTRL_DB user $COPT_CTRL_DB2USER using $COPT_CTRL_DB2PASS;" > "$TMPDIR/$tmp_sql_file";
  cat "$IZY_MISC_DIR/rpi_izy_data_delete.sql" >> "$TMPDIR/$tmp_sql_file"
  $DB2EXEC -xtf "$TMPDIR/$tmp_sql_file"

  ret=$?
  if [ $ret -gt 2 ] ; then
      echo "      (F) Unable to remove the obsoleted IZY data marts and reports"
      echo "          Exiting..."
      exit 255
  fi


  rm -f "$TMPDIR/$tmp_sql_file"

echo "      (I) Obsoleted IZY data marts and reports deleted. Program will continue."
return 0;
}


############
### Main ###
############

echo "==> Processing main WPack routines"
echo ""

  set_izy_program_vars;
  
echo $TWH_RPI_HOST  
if [ "$TWH_RPI_HOST" != "RPI_NULL_HOST" ]; then                 # D1A Added if check for tables
    remove_obsolete_rpi_data;
fi

echo ""
echo "      (I) Done processing main WPack routines"
echo ""

#####################################
## Stop adding application code #####
#####################################

echo "==> Completed executing application before script"

exit 0
